{% extends 'flask_user/_public_base.html' %}

{% block content %}
{% from "flask_user/_macros.html" import render_field, render_submit_field %}
<h1>{%trans%}Resend Confirmation Email{%endtrans%}</h1>

<form action="" method="POST" class="form" role="form">
    {{ form.hidden_tag() }}
    {{ render_field(form.email, tabindex=10) }}
    {{ render_submit_field(form.submit, tabindex=90) }}
</form>

{% endblock %}