{% extends 'flask_user/_authorized_base.html' %}

{% block content %}
{% from "flask_user/_macros.html" import render_field, render_submit_field %}
<h1>{%trans%}Change password{%endtrans%}</h1>

<form action="" method="POST" class="form">
    {{ form.hidden_tag() }}
    {{ render_field(form.old_password, tabindex=10) }}
    {{ render_field(form.new_password, tabindex=20) }}
    {% if user_manager.USER_REQUIRE_RETYPE_PASSWORD %}
        {{ render_field(form.retype_password, tabindex=30) }}
    {% endif %}
    {{ render_submit_field(form.submit, tabindex=90) }}
</form>

{% endblock %}