{% extends 'flask_user/emails/base.html' %}

{% block message %}

<p>We have received your password reset request.</p>

<p>To change your password, please click on the link below:<br/>
&nbsp;&nbsp;&nbsp;&nbsp;<a href="{{ reset_password_link }}">Reset password</a>.</p>

<p>If you did not initiate this password reset, you may safely ignore this email.</p>

{% endblock %}