<!DOCTYPE html>
<html lang="en">
    <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="description" content="">
    <meta name="author" content="Coding Minds">
    <title>{{ user_manager.USER_APP_NAME }} Error</title>
    <!-- Custom fonts for this template-->
    <script src="https://kit.fontawesome.com/183ab5233b.js" crossorigin="anonymous"></script>
    <!-- Custom styles for this template -->
        <style>
            .container-fluid,
            .d-flex {
                 display: flex !important;
            }
            .flex-column {
                flex-direction: column !important;
            }
            .lead {
                font-size: 1.25rem;
                font-weight: 300;
            }
            .text-gray-800 {
                color: #5a5c69 !important;
            }
            .text-gray-500 {
                color: #b7b9cc !important;
            }
            .text-center {
                 text-align: center !important;
            }
        </style>
    </head>
    <body>
    <div id="wrapper">
    <div id="content-wrapper" class="d-flex flex-column">
        <!-- Begin Page Content -->
        <div class="container-fluid">
            <div class="text-center">
                <p class="lead text-gray-800 mb-5"><em class="fas fa-bug"></em> Internal Error</p>
                <p class="text-gray-500 mb-0">Sorry... something went wrong...</p>
                <p class="text-gray-500 mb-0">We logged this problem under {{ error_id }}</p>
            </div>
        </div>
    </div>
            </div>
    </body>
</html>