{% extends 'flask_user/emails/base.html' %}

{% block message %}
Please <a href="{{ confirm_email_link }}">confirm your email</a>.</p>

<p>If you did not initiate this confirmation, you may safely ignore this email.</p>

{% endblock %}