{% block extra_head %}
{% endblock %}

{% extends 'local/layout.html' %}

{% block main %}
    <h4>Sorry, We are closed</h4>
    Sorry, we are closed. Our website is still under construction. Please come back later.
{% endblock %}

{% block extra_js %}
{% endblock %}