{% extends 'flask_user/emails/base.html' %}

{% block message %}
<p>Your password has been changed.</p>
{% if user_manager.USER_ENABLE_FORGOT_PASSWORD %}
<p>Please <a href="{{ url_for('user.forgot_password', _external=True) }}">click here to reset it</a>.</p>
{% endif %}
{% endblock %}
