{% extends 'flask_user/_authorized_base.html' %}

{% block content %}
{% from "flask_user/_macros.html" import render_field, render_checkbox_field, render_submit_field %}
<h1>{%trans%}User profile{%endtrans%}</h1>

<form action="" method="POST" class="form" role="form">
    {{ form.hidden_tag() }}
    {% for field in form %}
        {% if not field.flags.hidden %}
            {% if field.type=='SubmitField' %}
                {{ render_submit_field(field, tabindex=loop.index*10) }}
            {% else %}
                {{ render_field(field, tabindex=loop.index*10) }}
            {% endif %}
        {% endif %}
    {% endfor %}
</form>
<br/>

{% if not user_manager.USER_ENABLE_AUTH0 %}
    {% if user_manager.USER_ENABLE_CHANGE_USERNAME %}
        <p><a href="{{ url_for('user.change_username') }}">{%trans%}Change username{%endtrans%}</a></p>
    {% endif %}
    {% if user_manager.USER_ENABLE_CHANGE_PASSWORD %}
        <p><a href="{{ url_for('user.change_password') }}">{%trans%}Change password{%endtrans%}</a></p>
    {% endif %}
{% endif %}

{% endblock %}