{% extends 'ssk/emails/base.html' %}

{% block message %}
<p>This is  {{ app_name }} (v. {{ app_version }}) speaking.</p>

<p>This is a test message used to check the email integration</p>

{% endblock %}