{% extends 'ssk/emails/base.html' %}

{% block message %}
<p>Thank you for your order!</p>

    product name, order id, amount, date

<p>Your payment of $XX was processed successfully on DD/MM/YY.</p>

{% endblock %}