{% block extra_head %}
{% endblock %}

{% extends 'local/layout.html' %}

{% block main %}
    <h4>Not Found</h4>
    Sorry, the file you are looking for does not exist.
{% endblock %}

{% block extra_js %}
{% endblock %}