{% extends 'flask_user/emails/base.html' %}

{% block message %}

<p>Thank you for registering with {{ app_name }}.</p>

{% if confirm_email_link -%}
Please <a href="{{ confirm_email_link }}">Confirm your email</a>.

<p>If you did not initiate this registration, you may safely ignore this email.</p>
{%- endif %}

{% endblock %}