{% extends "local/layout.html" %}

{% block main %}
<div class="container">
    <div class="row">
        <div class="col-sm-7 col-md-6 col-lg-5 col-centered">
            {% block content %}{% endblock %}
        </div>
    </div>
</div>
{% endblock %}