/*
 * Autogenerated by mkemoji script from jQuery Terminal
 * Copyright (C) Jakub T. Jankiewicz <https://jcubic.pl>
 * ship with version: 2.34.0
 * build: Sun, 10 Jul 2022 21:53:26 GMT
 */
.terminal-output .emoji.hash,.cmd .emoji.hash{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0023-fe0f-20e3.png);}
.terminal-output .emoji.keycap_star,.cmd .emoji.keycap_star{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/002a-fe0f-20e3.png);}
.terminal-output .emoji.zero,.cmd .emoji.zero{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0030-fe0f-20e3.png);}
.terminal-output .emoji.one,.cmd .emoji.one{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0031-fe0f-20e3.png);}
.terminal-output .emoji.two,.cmd .emoji.two{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0032-fe0f-20e3.png);}
.terminal-output .emoji.three,.cmd .emoji.three{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0033-fe0f-20e3.png);}
.terminal-output .emoji.four,.cmd .emoji.four{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0034-fe0f-20e3.png);}
.terminal-output .emoji.five,.cmd .emoji.five{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0035-fe0f-20e3.png);}
.terminal-output .emoji.six,.cmd .emoji.six{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0036-fe0f-20e3.png);}
.terminal-output .emoji.seven,.cmd .emoji.seven{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0037-fe0f-20e3.png);}
.terminal-output .emoji.eight,.cmd .emoji.eight{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0038-fe0f-20e3.png);}
.terminal-output .emoji.nine,.cmd .emoji.nine{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/0039-fe0f-20e3.png);}
.terminal-output .emoji.copyright,.cmd .emoji.copyright{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/00a9-fe0f.png);}
.terminal-output .emoji.registered,.cmd .emoji.registered{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/00ae-fe0f.png);}
.terminal-output .emoji.mahjong,.cmd .emoji.mahjong{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f004.png);}
.terminal-output .emoji.black_joker,.cmd .emoji.black_joker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f0cf.png);}
.terminal-output .emoji.a,.cmd .emoji.a{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f170-fe0f.png);}
.terminal-output .emoji.b,.cmd .emoji.b{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f171-fe0f.png);}
.terminal-output .emoji.o2,.cmd .emoji.o2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f17e-fe0f.png);}
.terminal-output .emoji.parking,.cmd .emoji.parking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f17f-fe0f.png);}
.terminal-output .emoji.ab,.cmd .emoji.ab{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f18e.png);}
.terminal-output .emoji.cl,.cmd .emoji.cl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f191.png);}
.terminal-output .emoji.cool,.cmd .emoji.cool{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f192.png);}
.terminal-output .emoji.free,.cmd .emoji.free{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f193.png);}
.terminal-output .emoji.id,.cmd .emoji.id{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f194.png);}
.terminal-output .emoji.new,.cmd .emoji.new{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f195.png);}
.terminal-output .emoji.ng,.cmd .emoji.ng{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f196.png);}
.terminal-output .emoji.ok,.cmd .emoji.ok{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f197.png);}
.terminal-output .emoji.sos,.cmd .emoji.sos{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f198.png);}
.terminal-output .emoji.up,.cmd .emoji.up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f199.png);}
.terminal-output .emoji.vs,.cmd .emoji.vs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f19a.png);}
.terminal-output .emoji.flag-ac,.cmd .emoji.flag-ac{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1e8.png);}
.terminal-output .emoji.flag-ad,.cmd .emoji.flag-ad{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1e9.png);}
.terminal-output .emoji.flag-ae,.cmd .emoji.flag-ae{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1ea.png);}
.terminal-output .emoji.flag-af,.cmd .emoji.flag-af{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1eb.png);}
.terminal-output .emoji.flag-ag,.cmd .emoji.flag-ag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1ec.png);}
.terminal-output .emoji.flag-ai,.cmd .emoji.flag-ai{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1ee.png);}
.terminal-output .emoji.flag-al,.cmd .emoji.flag-al{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f1.png);}
.terminal-output .emoji.flag-am,.cmd .emoji.flag-am{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f2.png);}
.terminal-output .emoji.flag-ao,.cmd .emoji.flag-ao{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f4.png);}
.terminal-output .emoji.flag-aq,.cmd .emoji.flag-aq{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f6.png);}
.terminal-output .emoji.flag-ar,.cmd .emoji.flag-ar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f7.png);}
.terminal-output .emoji.flag-as,.cmd .emoji.flag-as{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f8.png);}
.terminal-output .emoji.flag-at,.cmd .emoji.flag-at{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1f9.png);}
.terminal-output .emoji.flag-au,.cmd .emoji.flag-au{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1fa.png);}
.terminal-output .emoji.flag-aw,.cmd .emoji.flag-aw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1fc.png);}
.terminal-output .emoji.flag-ax,.cmd .emoji.flag-ax{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1fd.png);}
.terminal-output .emoji.flag-az,.cmd .emoji.flag-az{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e6-1f1ff.png);}
.terminal-output .emoji.flag-ba,.cmd .emoji.flag-ba{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1e6.png);}
.terminal-output .emoji.flag-bb,.cmd .emoji.flag-bb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1e7.png);}
.terminal-output .emoji.flag-bd,.cmd .emoji.flag-bd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1e9.png);}
.terminal-output .emoji.flag-be,.cmd .emoji.flag-be{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ea.png);}
.terminal-output .emoji.flag-bf,.cmd .emoji.flag-bf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1eb.png);}
.terminal-output .emoji.flag-bg,.cmd .emoji.flag-bg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ec.png);}
.terminal-output .emoji.flag-bh,.cmd .emoji.flag-bh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ed.png);}
.terminal-output .emoji.flag-bi,.cmd .emoji.flag-bi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ee.png);}
.terminal-output .emoji.flag-bj,.cmd .emoji.flag-bj{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ef.png);}
.terminal-output .emoji.flag-bl,.cmd .emoji.flag-bl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f1.png);}
.terminal-output .emoji.flag-bm,.cmd .emoji.flag-bm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f2.png);}
.terminal-output .emoji.flag-bn,.cmd .emoji.flag-bn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f3.png);}
.terminal-output .emoji.flag-bo,.cmd .emoji.flag-bo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f4.png);}
.terminal-output .emoji.flag-bq,.cmd .emoji.flag-bq{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f6.png);}
.terminal-output .emoji.flag-br,.cmd .emoji.flag-br{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f7.png);}
.terminal-output .emoji.flag-bs,.cmd .emoji.flag-bs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f8.png);}
.terminal-output .emoji.flag-bt,.cmd .emoji.flag-bt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1f9.png);}
.terminal-output .emoji.flag-bv,.cmd .emoji.flag-bv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1fb.png);}
.terminal-output .emoji.flag-bw,.cmd .emoji.flag-bw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1fc.png);}
.terminal-output .emoji.flag-by,.cmd .emoji.flag-by{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1fe.png);}
.terminal-output .emoji.flag-bz,.cmd .emoji.flag-bz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e7-1f1ff.png);}
.terminal-output .emoji.flag-ca,.cmd .emoji.flag-ca{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1e6.png);}
.terminal-output .emoji.flag-cc,.cmd .emoji.flag-cc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1e8.png);}
.terminal-output .emoji.flag-cd,.cmd .emoji.flag-cd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1e9.png);}
.terminal-output .emoji.flag-cf,.cmd .emoji.flag-cf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1eb.png);}
.terminal-output .emoji.flag-cg,.cmd .emoji.flag-cg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1ec.png);}
.terminal-output .emoji.flag-ch,.cmd .emoji.flag-ch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1ed.png);}
.terminal-output .emoji.flag-ci,.cmd .emoji.flag-ci{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1ee.png);}
.terminal-output .emoji.flag-ck,.cmd .emoji.flag-ck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f0.png);}
.terminal-output .emoji.flag-cl,.cmd .emoji.flag-cl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f1.png);}
.terminal-output .emoji.flag-cm,.cmd .emoji.flag-cm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f2.png);}
.terminal-output .emoji.cn,.cmd .emoji.cn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f3.png);}
.terminal-output .emoji.flag-co,.cmd .emoji.flag-co{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f4.png);}
.terminal-output .emoji.flag-cp,.cmd .emoji.flag-cp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f5.png);}
.terminal-output .emoji.flag-cr,.cmd .emoji.flag-cr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1f7.png);}
.terminal-output .emoji.flag-cu,.cmd .emoji.flag-cu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1fa.png);}
.terminal-output .emoji.flag-cv,.cmd .emoji.flag-cv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1fb.png);}
.terminal-output .emoji.flag-cw,.cmd .emoji.flag-cw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1fc.png);}
.terminal-output .emoji.flag-cx,.cmd .emoji.flag-cx{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1fd.png);}
.terminal-output .emoji.flag-cy,.cmd .emoji.flag-cy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1fe.png);}
.terminal-output .emoji.flag-cz,.cmd .emoji.flag-cz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e8-1f1ff.png);}
.terminal-output .emoji.de,.cmd .emoji.de{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1ea.png);}
.terminal-output .emoji.flag-dg,.cmd .emoji.flag-dg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1ec.png);}
.terminal-output .emoji.flag-dj,.cmd .emoji.flag-dj{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1ef.png);}
.terminal-output .emoji.flag-dk,.cmd .emoji.flag-dk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1f0.png);}
.terminal-output .emoji.flag-dm,.cmd .emoji.flag-dm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1f2.png);}
.terminal-output .emoji.flag-do,.cmd .emoji.flag-do{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1f4.png);}
.terminal-output .emoji.flag-dz,.cmd .emoji.flag-dz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1e9-1f1ff.png);}
.terminal-output .emoji.flag-ea,.cmd .emoji.flag-ea{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1e6.png);}
.terminal-output .emoji.flag-ec,.cmd .emoji.flag-ec{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1e8.png);}
.terminal-output .emoji.flag-ee,.cmd .emoji.flag-ee{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1ea.png);}
.terminal-output .emoji.flag-eg,.cmd .emoji.flag-eg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1ec.png);}
.terminal-output .emoji.flag-eh,.cmd .emoji.flag-eh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1ed.png);}
.terminal-output .emoji.flag-er,.cmd .emoji.flag-er{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1f7.png);}
.terminal-output .emoji.es,.cmd .emoji.es{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1f8.png);}
.terminal-output .emoji.flag-et,.cmd .emoji.flag-et{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1f9.png);}
.terminal-output .emoji.flag-eu,.cmd .emoji.flag-eu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ea-1f1fa.png);}
.terminal-output .emoji.flag-fi,.cmd .emoji.flag-fi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1ee.png);}
.terminal-output .emoji.flag-fj,.cmd .emoji.flag-fj{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1ef.png);}
.terminal-output .emoji.flag-fk,.cmd .emoji.flag-fk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1f0.png);}
.terminal-output .emoji.flag-fm,.cmd .emoji.flag-fm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1f2.png);}
.terminal-output .emoji.flag-fo,.cmd .emoji.flag-fo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1f4.png);}
.terminal-output .emoji.fr,.cmd .emoji.fr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1eb-1f1f7.png);}
.terminal-output .emoji.flag-ga,.cmd .emoji.flag-ga{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1e6.png);}
.terminal-output .emoji.gb,.cmd .emoji.gb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1e7.png);}
.terminal-output .emoji.flag-gd,.cmd .emoji.flag-gd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1e9.png);}
.terminal-output .emoji.flag-ge,.cmd .emoji.flag-ge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1ea.png);}
.terminal-output .emoji.flag-gf,.cmd .emoji.flag-gf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1eb.png);}
.terminal-output .emoji.flag-gg,.cmd .emoji.flag-gg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1ec.png);}
.terminal-output .emoji.flag-gh,.cmd .emoji.flag-gh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1ed.png);}
.terminal-output .emoji.flag-gi,.cmd .emoji.flag-gi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1ee.png);}
.terminal-output .emoji.flag-gl,.cmd .emoji.flag-gl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f1.png);}
.terminal-output .emoji.flag-gm,.cmd .emoji.flag-gm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f2.png);}
.terminal-output .emoji.flag-gn,.cmd .emoji.flag-gn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f3.png);}
.terminal-output .emoji.flag-gp,.cmd .emoji.flag-gp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f5.png);}
.terminal-output .emoji.flag-gq,.cmd .emoji.flag-gq{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f6.png);}
.terminal-output .emoji.flag-gr,.cmd .emoji.flag-gr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f7.png);}
.terminal-output .emoji.flag-gs,.cmd .emoji.flag-gs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f8.png);}
.terminal-output .emoji.flag-gt,.cmd .emoji.flag-gt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1f9.png);}
.terminal-output .emoji.flag-gu,.cmd .emoji.flag-gu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1fa.png);}
.terminal-output .emoji.flag-gw,.cmd .emoji.flag-gw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1fc.png);}
.terminal-output .emoji.flag-gy,.cmd .emoji.flag-gy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ec-1f1fe.png);}
.terminal-output .emoji.flag-hk,.cmd .emoji.flag-hk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1f0.png);}
.terminal-output .emoji.flag-hm,.cmd .emoji.flag-hm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1f2.png);}
.terminal-output .emoji.flag-hn,.cmd .emoji.flag-hn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1f3.png);}
.terminal-output .emoji.flag-hr,.cmd .emoji.flag-hr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1f7.png);}
.terminal-output .emoji.flag-ht,.cmd .emoji.flag-ht{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1f9.png);}
.terminal-output .emoji.flag-hu,.cmd .emoji.flag-hu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ed-1f1fa.png);}
.terminal-output .emoji.flag-ic,.cmd .emoji.flag-ic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1e8.png);}
.terminal-output .emoji.flag-id,.cmd .emoji.flag-id{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1e9.png);}
.terminal-output .emoji.flag-ie,.cmd .emoji.flag-ie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1ea.png);}
.terminal-output .emoji.flag-il,.cmd .emoji.flag-il{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f1.png);}
.terminal-output .emoji.flag-im,.cmd .emoji.flag-im{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f2.png);}
.terminal-output .emoji.flag-in,.cmd .emoji.flag-in{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f3.png);}
.terminal-output .emoji.flag-io,.cmd .emoji.flag-io{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f4.png);}
.terminal-output .emoji.flag-iq,.cmd .emoji.flag-iq{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f6.png);}
.terminal-output .emoji.flag-ir,.cmd .emoji.flag-ir{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f7.png);}
.terminal-output .emoji.flag-is,.cmd .emoji.flag-is{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f8.png);}
.terminal-output .emoji.it,.cmd .emoji.it{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ee-1f1f9.png);}
.terminal-output .emoji.flag-je,.cmd .emoji.flag-je{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ef-1f1ea.png);}
.terminal-output .emoji.flag-jm,.cmd .emoji.flag-jm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ef-1f1f2.png);}
.terminal-output .emoji.flag-jo,.cmd .emoji.flag-jo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ef-1f1f4.png);}
.terminal-output .emoji.jp,.cmd .emoji.jp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ef-1f1f5.png);}
.terminal-output .emoji.flag-ke,.cmd .emoji.flag-ke{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1ea.png);}
.terminal-output .emoji.flag-kg,.cmd .emoji.flag-kg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1ec.png);}
.terminal-output .emoji.flag-kh,.cmd .emoji.flag-kh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1ed.png);}
.terminal-output .emoji.flag-ki,.cmd .emoji.flag-ki{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1ee.png);}
.terminal-output .emoji.flag-km,.cmd .emoji.flag-km{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1f2.png);}
.terminal-output .emoji.flag-kn,.cmd .emoji.flag-kn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1f3.png);}
.terminal-output .emoji.flag-kp,.cmd .emoji.flag-kp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1f5.png);}
.terminal-output .emoji.kr,.cmd .emoji.kr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1f7.png);}
.terminal-output .emoji.flag-kw,.cmd .emoji.flag-kw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1fc.png);}
.terminal-output .emoji.flag-ky,.cmd .emoji.flag-ky{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1fe.png);}
.terminal-output .emoji.flag-kz,.cmd .emoji.flag-kz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f0-1f1ff.png);}
.terminal-output .emoji.flag-la,.cmd .emoji.flag-la{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1e6.png);}
.terminal-output .emoji.flag-lb,.cmd .emoji.flag-lb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1e7.png);}
.terminal-output .emoji.flag-lc,.cmd .emoji.flag-lc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1e8.png);}
.terminal-output .emoji.flag-li,.cmd .emoji.flag-li{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1ee.png);}
.terminal-output .emoji.flag-lk,.cmd .emoji.flag-lk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1f0.png);}
.terminal-output .emoji.flag-lr,.cmd .emoji.flag-lr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1f7.png);}
.terminal-output .emoji.flag-ls,.cmd .emoji.flag-ls{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1f8.png);}
.terminal-output .emoji.flag-lt,.cmd .emoji.flag-lt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1f9.png);}
.terminal-output .emoji.flag-lu,.cmd .emoji.flag-lu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1fa.png);}
.terminal-output .emoji.flag-lv,.cmd .emoji.flag-lv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1fb.png);}
.terminal-output .emoji.flag-ly,.cmd .emoji.flag-ly{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f1-1f1fe.png);}
.terminal-output .emoji.flag-ma,.cmd .emoji.flag-ma{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1e6.png);}
.terminal-output .emoji.flag-mc,.cmd .emoji.flag-mc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1e8.png);}
.terminal-output .emoji.flag-md,.cmd .emoji.flag-md{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1e9.png);}
.terminal-output .emoji.flag-me,.cmd .emoji.flag-me{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1ea.png);}
.terminal-output .emoji.flag-mf,.cmd .emoji.flag-mf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1eb.png);}
.terminal-output .emoji.flag-mg,.cmd .emoji.flag-mg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1ec.png);}
.terminal-output .emoji.flag-mh,.cmd .emoji.flag-mh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1ed.png);}
.terminal-output .emoji.flag-mk,.cmd .emoji.flag-mk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f0.png);}
.terminal-output .emoji.flag-ml,.cmd .emoji.flag-ml{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f1.png);}
.terminal-output .emoji.flag-mm,.cmd .emoji.flag-mm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f2.png);}
.terminal-output .emoji.flag-mn,.cmd .emoji.flag-mn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f3.png);}
.terminal-output .emoji.flag-mo,.cmd .emoji.flag-mo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f4.png);}
.terminal-output .emoji.flag-mp,.cmd .emoji.flag-mp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f5.png);}
.terminal-output .emoji.flag-mq,.cmd .emoji.flag-mq{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f6.png);}
.terminal-output .emoji.flag-mr,.cmd .emoji.flag-mr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f7.png);}
.terminal-output .emoji.flag-ms,.cmd .emoji.flag-ms{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f8.png);}
.terminal-output .emoji.flag-mt,.cmd .emoji.flag-mt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1f9.png);}
.terminal-output .emoji.flag-mu,.cmd .emoji.flag-mu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1fa.png);}
.terminal-output .emoji.flag-mv,.cmd .emoji.flag-mv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1fb.png);}
.terminal-output .emoji.flag-mw,.cmd .emoji.flag-mw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1fc.png);}
.terminal-output .emoji.flag-mx,.cmd .emoji.flag-mx{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1fd.png);}
.terminal-output .emoji.flag-my,.cmd .emoji.flag-my{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1fe.png);}
.terminal-output .emoji.flag-mz,.cmd .emoji.flag-mz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f2-1f1ff.png);}
.terminal-output .emoji.flag-na,.cmd .emoji.flag-na{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1e6.png);}
.terminal-output .emoji.flag-nc,.cmd .emoji.flag-nc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1e8.png);}
.terminal-output .emoji.flag-ne,.cmd .emoji.flag-ne{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1ea.png);}
.terminal-output .emoji.flag-nf,.cmd .emoji.flag-nf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1eb.png);}
.terminal-output .emoji.flag-ng,.cmd .emoji.flag-ng{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1ec.png);}
.terminal-output .emoji.flag-ni,.cmd .emoji.flag-ni{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1ee.png);}
.terminal-output .emoji.flag-nl,.cmd .emoji.flag-nl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1f1.png);}
.terminal-output .emoji.flag-no,.cmd .emoji.flag-no{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1f4.png);}
.terminal-output .emoji.flag-np,.cmd .emoji.flag-np{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1f5.png);}
.terminal-output .emoji.flag-nr,.cmd .emoji.flag-nr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1f7.png);}
.terminal-output .emoji.flag-nu,.cmd .emoji.flag-nu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1fa.png);}
.terminal-output .emoji.flag-nz,.cmd .emoji.flag-nz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f3-1f1ff.png);}
.terminal-output .emoji.flag-om,.cmd .emoji.flag-om{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f4-1f1f2.png);}
.terminal-output .emoji.flag-pa,.cmd .emoji.flag-pa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1e6.png);}
.terminal-output .emoji.flag-pe,.cmd .emoji.flag-pe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1ea.png);}
.terminal-output .emoji.flag-pf,.cmd .emoji.flag-pf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1eb.png);}
.terminal-output .emoji.flag-pg,.cmd .emoji.flag-pg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1ec.png);}
.terminal-output .emoji.flag-ph,.cmd .emoji.flag-ph{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1ed.png);}
.terminal-output .emoji.flag-pk,.cmd .emoji.flag-pk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f0.png);}
.terminal-output .emoji.flag-pl,.cmd .emoji.flag-pl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f1.png);}
.terminal-output .emoji.flag-pm,.cmd .emoji.flag-pm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f2.png);}
.terminal-output .emoji.flag-pn,.cmd .emoji.flag-pn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f3.png);}
.terminal-output .emoji.flag-pr,.cmd .emoji.flag-pr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f7.png);}
.terminal-output .emoji.flag-ps,.cmd .emoji.flag-ps{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f8.png);}
.terminal-output .emoji.flag-pt,.cmd .emoji.flag-pt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1f9.png);}
.terminal-output .emoji.flag-pw,.cmd .emoji.flag-pw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1fc.png);}
.terminal-output .emoji.flag-py,.cmd .emoji.flag-py{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f5-1f1fe.png);}
.terminal-output .emoji.flag-qa,.cmd .emoji.flag-qa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f6-1f1e6.png);}
.terminal-output .emoji.flag-re,.cmd .emoji.flag-re{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f7-1f1ea.png);}
.terminal-output .emoji.flag-ro,.cmd .emoji.flag-ro{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f7-1f1f4.png);}
.terminal-output .emoji.flag-rs,.cmd .emoji.flag-rs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f7-1f1f8.png);}
.terminal-output .emoji.ru,.cmd .emoji.ru{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f7-1f1fa.png);}
.terminal-output .emoji.flag-rw,.cmd .emoji.flag-rw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f7-1f1fc.png);}
.terminal-output .emoji.flag-sa,.cmd .emoji.flag-sa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1e6.png);}
.terminal-output .emoji.flag-sb,.cmd .emoji.flag-sb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1e7.png);}
.terminal-output .emoji.flag-sc,.cmd .emoji.flag-sc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1e8.png);}
.terminal-output .emoji.flag-sd,.cmd .emoji.flag-sd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1e9.png);}
.terminal-output .emoji.flag-se,.cmd .emoji.flag-se{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ea.png);}
.terminal-output .emoji.flag-sg,.cmd .emoji.flag-sg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ec.png);}
.terminal-output .emoji.flag-sh,.cmd .emoji.flag-sh{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ed.png);}
.terminal-output .emoji.flag-si,.cmd .emoji.flag-si{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ee.png);}
.terminal-output .emoji.flag-sj,.cmd .emoji.flag-sj{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ef.png);}
.terminal-output .emoji.flag-sk,.cmd .emoji.flag-sk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f0.png);}
.terminal-output .emoji.flag-sl,.cmd .emoji.flag-sl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f1.png);}
.terminal-output .emoji.flag-sm,.cmd .emoji.flag-sm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f2.png);}
.terminal-output .emoji.flag-sn,.cmd .emoji.flag-sn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f3.png);}
.terminal-output .emoji.flag-so,.cmd .emoji.flag-so{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f4.png);}
.terminal-output .emoji.flag-sr,.cmd .emoji.flag-sr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f7.png);}
.terminal-output .emoji.flag-ss,.cmd .emoji.flag-ss{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f8.png);}
.terminal-output .emoji.flag-st,.cmd .emoji.flag-st{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1f9.png);}
.terminal-output .emoji.flag-sv,.cmd .emoji.flag-sv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1fb.png);}
.terminal-output .emoji.flag-sx,.cmd .emoji.flag-sx{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1fd.png);}
.terminal-output .emoji.flag-sy,.cmd .emoji.flag-sy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1fe.png);}
.terminal-output .emoji.flag-sz,.cmd .emoji.flag-sz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f8-1f1ff.png);}
.terminal-output .emoji.flag-ta,.cmd .emoji.flag-ta{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1e6.png);}
.terminal-output .emoji.flag-tc,.cmd .emoji.flag-tc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1e8.png);}
.terminal-output .emoji.flag-td,.cmd .emoji.flag-td{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1e9.png);}
.terminal-output .emoji.flag-tf,.cmd .emoji.flag-tf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1eb.png);}
.terminal-output .emoji.flag-tg,.cmd .emoji.flag-tg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1ec.png);}
.terminal-output .emoji.flag-th,.cmd .emoji.flag-th{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1ed.png);}
.terminal-output .emoji.flag-tj,.cmd .emoji.flag-tj{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1ef.png);}
.terminal-output .emoji.flag-tk,.cmd .emoji.flag-tk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f0.png);}
.terminal-output .emoji.flag-tl,.cmd .emoji.flag-tl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f1.png);}
.terminal-output .emoji.flag-tm,.cmd .emoji.flag-tm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f2.png);}
.terminal-output .emoji.flag-tn,.cmd .emoji.flag-tn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f3.png);}
.terminal-output .emoji.flag-to,.cmd .emoji.flag-to{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f4.png);}
.terminal-output .emoji.flag-tr,.cmd .emoji.flag-tr{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f7.png);}
.terminal-output .emoji.flag-tt,.cmd .emoji.flag-tt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1f9.png);}
.terminal-output .emoji.flag-tv,.cmd .emoji.flag-tv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1fb.png);}
.terminal-output .emoji.flag-tw,.cmd .emoji.flag-tw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1fc.png);}
.terminal-output .emoji.flag-tz,.cmd .emoji.flag-tz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1f9-1f1ff.png);}
.terminal-output .emoji.flag-ua,.cmd .emoji.flag-ua{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1e6.png);}
.terminal-output .emoji.flag-ug,.cmd .emoji.flag-ug{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1ec.png);}
.terminal-output .emoji.flag-um,.cmd .emoji.flag-um{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1f2.png);}
.terminal-output .emoji.flag-un,.cmd .emoji.flag-un{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1f3.png);}
.terminal-output .emoji.us,.cmd .emoji.us{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1f8.png);}
.terminal-output .emoji.flag-uy,.cmd .emoji.flag-uy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1fe.png);}
.terminal-output .emoji.flag-uz,.cmd .emoji.flag-uz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fa-1f1ff.png);}
.terminal-output .emoji.flag-va,.cmd .emoji.flag-va{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1e6.png);}
.terminal-output .emoji.flag-vc,.cmd .emoji.flag-vc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1e8.png);}
.terminal-output .emoji.flag-ve,.cmd .emoji.flag-ve{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1ea.png);}
.terminal-output .emoji.flag-vg,.cmd .emoji.flag-vg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1ec.png);}
.terminal-output .emoji.flag-vi,.cmd .emoji.flag-vi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1ee.png);}
.terminal-output .emoji.flag-vn,.cmd .emoji.flag-vn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1f3.png);}
.terminal-output .emoji.flag-vu,.cmd .emoji.flag-vu{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fb-1f1fa.png);}
.terminal-output .emoji.flag-wf,.cmd .emoji.flag-wf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fc-1f1eb.png);}
.terminal-output .emoji.flag-ws,.cmd .emoji.flag-ws{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fc-1f1f8.png);}
.terminal-output .emoji.flag-xk,.cmd .emoji.flag-xk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fd-1f1f0.png);}
.terminal-output .emoji.flag-ye,.cmd .emoji.flag-ye{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fe-1f1ea.png);}
.terminal-output .emoji.flag-yt,.cmd .emoji.flag-yt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1fe-1f1f9.png);}
.terminal-output .emoji.flag-za,.cmd .emoji.flag-za{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ff-1f1e6.png);}
.terminal-output .emoji.flag-zm,.cmd .emoji.flag-zm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ff-1f1f2.png);}
.terminal-output .emoji.flag-zw,.cmd .emoji.flag-zw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f1ff-1f1fc.png);}
.terminal-output .emoji.koko,.cmd .emoji.koko{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f201.png);}
.terminal-output .emoji.sa,.cmd .emoji.sa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f202-fe0f.png);}
.terminal-output .emoji.u7121,.cmd .emoji.u7121{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f21a.png);}
.terminal-output .emoji.u6307,.cmd .emoji.u6307{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f22f.png);}
.terminal-output .emoji.u7981,.cmd .emoji.u7981{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f232.png);}
.terminal-output .emoji.u7a7a,.cmd .emoji.u7a7a{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f233.png);}
.terminal-output .emoji.u5408,.cmd .emoji.u5408{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f234.png);}
.terminal-output .emoji.u6e80,.cmd .emoji.u6e80{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f235.png);}
.terminal-output .emoji.u6709,.cmd .emoji.u6709{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f236.png);}
.terminal-output .emoji.u6708,.cmd .emoji.u6708{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f237-fe0f.png);}
.terminal-output .emoji.u7533,.cmd .emoji.u7533{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f238.png);}
.terminal-output .emoji.u5272,.cmd .emoji.u5272{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f239.png);}
.terminal-output .emoji.u55b6,.cmd .emoji.u55b6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f23a.png);}
.terminal-output .emoji.ideograph_advantage,.cmd .emoji.ideograph_advantage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f250.png);}
.terminal-output .emoji.accept,.cmd .emoji.accept{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f251.png);}
.terminal-output .emoji.cyclone,.cmd .emoji.cyclone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f300.png);}
.terminal-output .emoji.foggy,.cmd .emoji.foggy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f301.png);}
.terminal-output .emoji.closed_umbrella,.cmd .emoji.closed_umbrella{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f302.png);}
.terminal-output .emoji.night_with_stars,.cmd .emoji.night_with_stars{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f303.png);}
.terminal-output .emoji.sunrise_over_mountains,.cmd .emoji.sunrise_over_mountains{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f304.png);}
.terminal-output .emoji.sunrise,.cmd .emoji.sunrise{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f305.png);}
.terminal-output .emoji.city_sunset,.cmd .emoji.city_sunset{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f306.png);}
.terminal-output .emoji.city_sunrise,.cmd .emoji.city_sunrise{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f307.png);}
.terminal-output .emoji.rainbow,.cmd .emoji.rainbow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f308.png);}
.terminal-output .emoji.bridge_at_night,.cmd .emoji.bridge_at_night{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f309.png);}
.terminal-output .emoji.ocean,.cmd .emoji.ocean{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30a.png);}
.terminal-output .emoji.volcano,.cmd .emoji.volcano{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30b.png);}
.terminal-output .emoji.milky_way,.cmd .emoji.milky_way{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30c.png);}
.terminal-output .emoji.earth_africa,.cmd .emoji.earth_africa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30d.png);}
.terminal-output .emoji.earth_americas,.cmd .emoji.earth_americas{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30e.png);}
.terminal-output .emoji.earth_asia,.cmd .emoji.earth_asia{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f30f.png);}
.terminal-output .emoji.globe_with_meridians,.cmd .emoji.globe_with_meridians{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f310.png);}
.terminal-output .emoji.new_moon,.cmd .emoji.new_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f311.png);}
.terminal-output .emoji.waxing_crescent_moon,.cmd .emoji.waxing_crescent_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f312.png);}
.terminal-output .emoji.first_quarter_moon,.cmd .emoji.first_quarter_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f313.png);}
.terminal-output .emoji.moon,.cmd .emoji.moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f314.png);}
.terminal-output .emoji.full_moon,.cmd .emoji.full_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f315.png);}
.terminal-output .emoji.waning_gibbous_moon,.cmd .emoji.waning_gibbous_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f316.png);}
.terminal-output .emoji.last_quarter_moon,.cmd .emoji.last_quarter_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f317.png);}
.terminal-output .emoji.waning_crescent_moon,.cmd .emoji.waning_crescent_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f318.png);}
.terminal-output .emoji.crescent_moon,.cmd .emoji.crescent_moon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f319.png);}
.terminal-output .emoji.new_moon_with_face,.cmd .emoji.new_moon_with_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31a.png);}
.terminal-output .emoji.first_quarter_moon_with_face,.cmd .emoji.first_quarter_moon_with_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31b.png);}
.terminal-output .emoji.last_quarter_moon_with_face,.cmd .emoji.last_quarter_moon_with_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31c.png);}
.terminal-output .emoji.full_moon_with_face,.cmd .emoji.full_moon_with_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31d.png);}
.terminal-output .emoji.sun_with_face,.cmd .emoji.sun_with_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31e.png);}
.terminal-output .emoji.star2,.cmd .emoji.star2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f31f.png);}
.terminal-output .emoji.stars,.cmd .emoji.stars{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f320.png);}
.terminal-output .emoji.thermometer,.cmd .emoji.thermometer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f321-fe0f.png);}
.terminal-output .emoji.mostly_sunny,.cmd .emoji.mostly_sunny{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f324-fe0f.png);}
.terminal-output .emoji.barely_sunny,.cmd .emoji.barely_sunny{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f325-fe0f.png);}
.terminal-output .emoji.partly_sunny_rain,.cmd .emoji.partly_sunny_rain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f326-fe0f.png);}
.terminal-output .emoji.rain_cloud,.cmd .emoji.rain_cloud{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f327-fe0f.png);}
.terminal-output .emoji.snow_cloud,.cmd .emoji.snow_cloud{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f328-fe0f.png);}
.terminal-output .emoji.lightning,.cmd .emoji.lightning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f329-fe0f.png);}
.terminal-output .emoji.tornado,.cmd .emoji.tornado{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32a-fe0f.png);}
.terminal-output .emoji.fog,.cmd .emoji.fog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32b-fe0f.png);}
.terminal-output .emoji.wind_blowing_face,.cmd .emoji.wind_blowing_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32c-fe0f.png);}
.terminal-output .emoji.hotdog,.cmd .emoji.hotdog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32d.png);}
.terminal-output .emoji.taco,.cmd .emoji.taco{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32e.png);}
.terminal-output .emoji.burrito,.cmd .emoji.burrito{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f32f.png);}
.terminal-output .emoji.chestnut,.cmd .emoji.chestnut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f330.png);}
.terminal-output .emoji.seedling,.cmd .emoji.seedling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f331.png);}
.terminal-output .emoji.evergreen_tree,.cmd .emoji.evergreen_tree{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f332.png);}
.terminal-output .emoji.deciduous_tree,.cmd .emoji.deciduous_tree{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f333.png);}
.terminal-output .emoji.palm_tree,.cmd .emoji.palm_tree{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f334.png);}
.terminal-output .emoji.cactus,.cmd .emoji.cactus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f335.png);}
.terminal-output .emoji.hot_pepper,.cmd .emoji.hot_pepper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f336-fe0f.png);}
.terminal-output .emoji.tulip,.cmd .emoji.tulip{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f337.png);}
.terminal-output .emoji.cherry_blossom,.cmd .emoji.cherry_blossom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f338.png);}
.terminal-output .emoji.rose,.cmd .emoji.rose{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f339.png);}
.terminal-output .emoji.hibiscus,.cmd .emoji.hibiscus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33a.png);}
.terminal-output .emoji.sunflower,.cmd .emoji.sunflower{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33b.png);}
.terminal-output .emoji.blossom,.cmd .emoji.blossom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33c.png);}
.terminal-output .emoji.corn,.cmd .emoji.corn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33d.png);}
.terminal-output .emoji.ear_of_rice,.cmd .emoji.ear_of_rice{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33e.png);}
.terminal-output .emoji.herb,.cmd .emoji.herb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f33f.png);}
.terminal-output .emoji.four_leaf_clover,.cmd .emoji.four_leaf_clover{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f340.png);}
.terminal-output .emoji.maple_leaf,.cmd .emoji.maple_leaf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f341.png);}
.terminal-output .emoji.fallen_leaf,.cmd .emoji.fallen_leaf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f342.png);}
.terminal-output .emoji.leaves,.cmd .emoji.leaves{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f343.png);}
.terminal-output .emoji.mushroom,.cmd .emoji.mushroom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f344.png);}
.terminal-output .emoji.tomato,.cmd .emoji.tomato{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f345.png);}
.terminal-output .emoji.eggplant,.cmd .emoji.eggplant{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f346.png);}
.terminal-output .emoji.grapes,.cmd .emoji.grapes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f347.png);}
.terminal-output .emoji.melon,.cmd .emoji.melon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f348.png);}
.terminal-output .emoji.watermelon,.cmd .emoji.watermelon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f349.png);}
.terminal-output .emoji.tangerine,.cmd .emoji.tangerine{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34a.png);}
.terminal-output .emoji.lemon,.cmd .emoji.lemon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34b.png);}
.terminal-output .emoji.banana,.cmd .emoji.banana{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34c.png);}
.terminal-output .emoji.pineapple,.cmd .emoji.pineapple{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34d.png);}
.terminal-output .emoji.apple,.cmd .emoji.apple{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34e.png);}
.terminal-output .emoji.green_apple,.cmd .emoji.green_apple{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f34f.png);}
.terminal-output .emoji.pear,.cmd .emoji.pear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f350.png);}
.terminal-output .emoji.peach,.cmd .emoji.peach{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f351.png);}
.terminal-output .emoji.cherries,.cmd .emoji.cherries{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f352.png);}
.terminal-output .emoji.strawberry,.cmd .emoji.strawberry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f353.png);}
.terminal-output .emoji.hamburger,.cmd .emoji.hamburger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f354.png);}
.terminal-output .emoji.pizza,.cmd .emoji.pizza{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f355.png);}
.terminal-output .emoji.meat_on_bone,.cmd .emoji.meat_on_bone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f356.png);}
.terminal-output .emoji.poultry_leg,.cmd .emoji.poultry_leg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f357.png);}
.terminal-output .emoji.rice_cracker,.cmd .emoji.rice_cracker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f358.png);}
.terminal-output .emoji.rice_ball,.cmd .emoji.rice_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f359.png);}
.terminal-output .emoji.rice,.cmd .emoji.rice{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35a.png);}
.terminal-output .emoji.curry,.cmd .emoji.curry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35b.png);}
.terminal-output .emoji.ramen,.cmd .emoji.ramen{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35c.png);}
.terminal-output .emoji.spaghetti,.cmd .emoji.spaghetti{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35d.png);}
.terminal-output .emoji.bread,.cmd .emoji.bread{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35e.png);}
.terminal-output .emoji.fries,.cmd .emoji.fries{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f35f.png);}
.terminal-output .emoji.sweet_potato,.cmd .emoji.sweet_potato{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f360.png);}
.terminal-output .emoji.dango,.cmd .emoji.dango{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f361.png);}
.terminal-output .emoji.oden,.cmd .emoji.oden{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f362.png);}
.terminal-output .emoji.sushi,.cmd .emoji.sushi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f363.png);}
.terminal-output .emoji.fried_shrimp,.cmd .emoji.fried_shrimp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f364.png);}
.terminal-output .emoji.fish_cake,.cmd .emoji.fish_cake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f365.png);}
.terminal-output .emoji.icecream,.cmd .emoji.icecream{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f366.png);}
.terminal-output .emoji.shaved_ice,.cmd .emoji.shaved_ice{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f367.png);}
.terminal-output .emoji.ice_cream,.cmd .emoji.ice_cream{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f368.png);}
.terminal-output .emoji.doughnut,.cmd .emoji.doughnut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f369.png);}
.terminal-output .emoji.cookie,.cmd .emoji.cookie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36a.png);}
.terminal-output .emoji.chocolate_bar,.cmd .emoji.chocolate_bar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36b.png);}
.terminal-output .emoji.candy,.cmd .emoji.candy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36c.png);}
.terminal-output .emoji.lollipop,.cmd .emoji.lollipop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36d.png);}
.terminal-output .emoji.custard,.cmd .emoji.custard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36e.png);}
.terminal-output .emoji.honey_pot,.cmd .emoji.honey_pot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f36f.png);}
.terminal-output .emoji.cake,.cmd .emoji.cake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f370.png);}
.terminal-output .emoji.bento,.cmd .emoji.bento{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f371.png);}
.terminal-output .emoji.stew,.cmd .emoji.stew{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f372.png);}
.terminal-output .emoji.fried_egg,.cmd .emoji.fried_egg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f373.png);}
.terminal-output .emoji.fork_and_knife,.cmd .emoji.fork_and_knife{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f374.png);}
.terminal-output .emoji.tea,.cmd .emoji.tea{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f375.png);}
.terminal-output .emoji.sake,.cmd .emoji.sake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f376.png);}
.terminal-output .emoji.wine_glass,.cmd .emoji.wine_glass{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f377.png);}
.terminal-output .emoji.cocktail,.cmd .emoji.cocktail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f378.png);}
.terminal-output .emoji.tropical_drink,.cmd .emoji.tropical_drink{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f379.png);}
.terminal-output .emoji.beer,.cmd .emoji.beer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37a.png);}
.terminal-output .emoji.beers,.cmd .emoji.beers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37b.png);}
.terminal-output .emoji.baby_bottle,.cmd .emoji.baby_bottle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37c.png);}
.terminal-output .emoji.knife_fork_plate,.cmd .emoji.knife_fork_plate{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37d-fe0f.png);}
.terminal-output .emoji.champagne,.cmd .emoji.champagne{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37e.png);}
.terminal-output .emoji.popcorn,.cmd .emoji.popcorn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f37f.png);}
.terminal-output .emoji.ribbon,.cmd .emoji.ribbon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f380.png);}
.terminal-output .emoji.gift,.cmd .emoji.gift{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f381.png);}
.terminal-output .emoji.birthday,.cmd .emoji.birthday{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f382.png);}
.terminal-output .emoji.jack_o_lantern,.cmd .emoji.jack_o_lantern{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f383.png);}
.terminal-output .emoji.christmas_tree,.cmd .emoji.christmas_tree{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f384.png);}
.terminal-output .emoji.santa,.cmd .emoji.santa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385.png);}
.terminal-output .emoji.santa-var-0,.cmd .emoji.santa-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385-1f3fb.png);}
.terminal-output .emoji.santa-var-1,.cmd .emoji.santa-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385-1f3fc.png);}
.terminal-output .emoji.santa-var-2,.cmd .emoji.santa-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385-1f3fd.png);}
.terminal-output .emoji.santa-var-3,.cmd .emoji.santa-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385-1f3fe.png);}
.terminal-output .emoji.santa-var-4,.cmd .emoji.santa-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f385-1f3ff.png);}
.terminal-output .emoji.fireworks,.cmd .emoji.fireworks{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f386.png);}
.terminal-output .emoji.sparkler,.cmd .emoji.sparkler{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f387.png);}
.terminal-output .emoji.balloon,.cmd .emoji.balloon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f388.png);}
.terminal-output .emoji.tada,.cmd .emoji.tada{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f389.png);}
.terminal-output .emoji.confetti_ball,.cmd .emoji.confetti_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38a.png);}
.terminal-output .emoji.tanabata_tree,.cmd .emoji.tanabata_tree{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38b.png);}
.terminal-output .emoji.crossed_flags,.cmd .emoji.crossed_flags{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38c.png);}
.terminal-output .emoji.bamboo,.cmd .emoji.bamboo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38d.png);}
.terminal-output .emoji.dolls,.cmd .emoji.dolls{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38e.png);}
.terminal-output .emoji.flags,.cmd .emoji.flags{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f38f.png);}
.terminal-output .emoji.wind_chime,.cmd .emoji.wind_chime{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f390.png);}
.terminal-output .emoji.rice_scene,.cmd .emoji.rice_scene{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f391.png);}
.terminal-output .emoji.school_satchel,.cmd .emoji.school_satchel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f392.png);}
.terminal-output .emoji.mortar_board,.cmd .emoji.mortar_board{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f393.png);}
.terminal-output .emoji.medal,.cmd .emoji.medal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f396-fe0f.png);}
.terminal-output .emoji.reminder_ribbon,.cmd .emoji.reminder_ribbon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f397-fe0f.png);}
.terminal-output .emoji.studio_microphone,.cmd .emoji.studio_microphone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f399-fe0f.png);}
.terminal-output .emoji.level_slider,.cmd .emoji.level_slider{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f39a-fe0f.png);}
.terminal-output .emoji.control_knobs,.cmd .emoji.control_knobs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f39b-fe0f.png);}
.terminal-output .emoji.film_frames,.cmd .emoji.film_frames{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f39e-fe0f.png);}
.terminal-output .emoji.admission_tickets,.cmd .emoji.admission_tickets{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f39f-fe0f.png);}
.terminal-output .emoji.carousel_horse,.cmd .emoji.carousel_horse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a0.png);}
.terminal-output .emoji.ferris_wheel,.cmd .emoji.ferris_wheel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a1.png);}
.terminal-output .emoji.roller_coaster,.cmd .emoji.roller_coaster{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a2.png);}
.terminal-output .emoji.fishing_pole_and_fish,.cmd .emoji.fishing_pole_and_fish{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a3.png);}
.terminal-output .emoji.microphone,.cmd .emoji.microphone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a4.png);}
.terminal-output .emoji.movie_camera,.cmd .emoji.movie_camera{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a5.png);}
.terminal-output .emoji.cinema,.cmd .emoji.cinema{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a6.png);}
.terminal-output .emoji.headphones,.cmd .emoji.headphones{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a7.png);}
.terminal-output .emoji.art,.cmd .emoji.art{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a8.png);}
.terminal-output .emoji.tophat,.cmd .emoji.tophat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3a9.png);}
.terminal-output .emoji.circus_tent,.cmd .emoji.circus_tent{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3aa.png);}
.terminal-output .emoji.ticket,.cmd .emoji.ticket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ab.png);}
.terminal-output .emoji.clapper,.cmd .emoji.clapper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ac.png);}
.terminal-output .emoji.performing_arts,.cmd .emoji.performing_arts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ad.png);}
.terminal-output .emoji.video_game,.cmd .emoji.video_game{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ae.png);}
.terminal-output .emoji.dart,.cmd .emoji.dart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3af.png);}
.terminal-output .emoji.slot_machine,.cmd .emoji.slot_machine{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b0.png);}
.terminal-output .emoji.\38 ball,.cmd .emoji.\38 ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b1.png);}
.terminal-output .emoji.game_die,.cmd .emoji.game_die{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b2.png);}
.terminal-output .emoji.bowling,.cmd .emoji.bowling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b3.png);}
.terminal-output .emoji.flower_playing_cards,.cmd .emoji.flower_playing_cards{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b4.png);}
.terminal-output .emoji.musical_note,.cmd .emoji.musical_note{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b5.png);}
.terminal-output .emoji.notes,.cmd .emoji.notes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b6.png);}
.terminal-output .emoji.saxophone,.cmd .emoji.saxophone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b7.png);}
.terminal-output .emoji.guitar,.cmd .emoji.guitar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b8.png);}
.terminal-output .emoji.musical_keyboard,.cmd .emoji.musical_keyboard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3b9.png);}
.terminal-output .emoji.trumpet,.cmd .emoji.trumpet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ba.png);}
.terminal-output .emoji.violin,.cmd .emoji.violin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3bb.png);}
.terminal-output .emoji.musical_score,.cmd .emoji.musical_score{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3bc.png);}
.terminal-output .emoji.running_shirt_with_sash,.cmd .emoji.running_shirt_with_sash{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3bd.png);}
.terminal-output .emoji.tennis,.cmd .emoji.tennis{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3be.png);}
.terminal-output .emoji.ski,.cmd .emoji.ski{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3bf.png);}
.terminal-output .emoji.basketball,.cmd .emoji.basketball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c0.png);}
.terminal-output .emoji.checkered_flag,.cmd .emoji.checkered_flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c1.png);}
.terminal-output .emoji.snowboarder,.cmd .emoji.snowboarder{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2.png);}
.terminal-output .emoji.snowboarder-var-0,.cmd .emoji.snowboarder-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2-1f3fb.png);}
.terminal-output .emoji.snowboarder-var-1,.cmd .emoji.snowboarder-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2-1f3fc.png);}
.terminal-output .emoji.snowboarder-var-2,.cmd .emoji.snowboarder-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2-1f3fd.png);}
.terminal-output .emoji.snowboarder-var-3,.cmd .emoji.snowboarder-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2-1f3fe.png);}
.terminal-output .emoji.snowboarder-var-4,.cmd .emoji.snowboarder-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c2-1f3ff.png);}
.terminal-output .emoji.woman-running,.cmd .emoji.woman-running{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-running-var-0,.cmd .emoji.woman-running-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-running-var-1,.cmd .emoji.woman-running-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-running-var-2,.cmd .emoji.woman-running-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-running-var-3,.cmd .emoji.woman-running-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-running-var-4,.cmd .emoji.woman-running-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-running,.cmd .emoji.man-running{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-200d-2642-fe0f.png);}
.terminal-output .emoji.man-running-var-0,.cmd .emoji.man-running-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-running-var-1,.cmd .emoji.man-running-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-running-var-2,.cmd .emoji.man-running-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-running-var-3,.cmd .emoji.man-running-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-running-var-4,.cmd .emoji.man-running-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.runner,.cmd .emoji.runner{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3.png);}
.terminal-output .emoji.runner-var-0,.cmd .emoji.runner-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fb.png);}
.terminal-output .emoji.runner-var-1,.cmd .emoji.runner-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fc.png);}
.terminal-output .emoji.runner-var-2,.cmd .emoji.runner-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fd.png);}
.terminal-output .emoji.runner-var-3,.cmd .emoji.runner-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3fe.png);}
.terminal-output .emoji.runner-var-4,.cmd .emoji.runner-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c3-1f3ff.png);}
.terminal-output .emoji.woman-surfing,.cmd .emoji.woman-surfing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-surfing-var-0,.cmd .emoji.woman-surfing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-surfing-var-1,.cmd .emoji.woman-surfing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-surfing-var-2,.cmd .emoji.woman-surfing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-surfing-var-3,.cmd .emoji.woman-surfing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-surfing-var-4,.cmd .emoji.woman-surfing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-surfing,.cmd .emoji.man-surfing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-200d-2642-fe0f.png);}
.terminal-output .emoji.man-surfing-var-0,.cmd .emoji.man-surfing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-surfing-var-1,.cmd .emoji.man-surfing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-surfing-var-2,.cmd .emoji.man-surfing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-surfing-var-3,.cmd .emoji.man-surfing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-surfing-var-4,.cmd .emoji.man-surfing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.surfer,.cmd .emoji.surfer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4.png);}
.terminal-output .emoji.surfer-var-0,.cmd .emoji.surfer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fb.png);}
.terminal-output .emoji.surfer-var-1,.cmd .emoji.surfer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fc.png);}
.terminal-output .emoji.surfer-var-2,.cmd .emoji.surfer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fd.png);}
.terminal-output .emoji.surfer-var-3,.cmd .emoji.surfer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3fe.png);}
.terminal-output .emoji.surfer-var-4,.cmd .emoji.surfer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c4-1f3ff.png);}
.terminal-output .emoji.sports_medal,.cmd .emoji.sports_medal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c5.png);}
.terminal-output .emoji.trophy,.cmd .emoji.trophy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c6.png);}
.terminal-output .emoji.horse_racing,.cmd .emoji.horse_racing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7.png);}
.terminal-output .emoji.horse_racing-var-0,.cmd .emoji.horse_racing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7-1f3fb.png);}
.terminal-output .emoji.horse_racing-var-1,.cmd .emoji.horse_racing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7-1f3fc.png);}
.terminal-output .emoji.horse_racing-var-2,.cmd .emoji.horse_racing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7-1f3fd.png);}
.terminal-output .emoji.horse_racing-var-3,.cmd .emoji.horse_racing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7-1f3fe.png);}
.terminal-output .emoji.horse_racing-var-4,.cmd .emoji.horse_racing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c7-1f3ff.png);}
.terminal-output .emoji.football,.cmd .emoji.football{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c8.png);}
.terminal-output .emoji.rugby_football,.cmd .emoji.rugby_football{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3c9.png);}
.terminal-output .emoji.woman-swimming,.cmd .emoji.woman-swimming{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-swimming-var-0,.cmd .emoji.woman-swimming-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-swimming-var-1,.cmd .emoji.woman-swimming-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-swimming-var-2,.cmd .emoji.woman-swimming-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-swimming-var-3,.cmd .emoji.woman-swimming-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-swimming-var-4,.cmd .emoji.woman-swimming-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-swimming,.cmd .emoji.man-swimming{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-200d-2642-fe0f.png);}
.terminal-output .emoji.man-swimming-var-0,.cmd .emoji.man-swimming-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-swimming-var-1,.cmd .emoji.man-swimming-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-swimming-var-2,.cmd .emoji.man-swimming-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-swimming-var-3,.cmd .emoji.man-swimming-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-swimming-var-4,.cmd .emoji.man-swimming-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.swimmer,.cmd .emoji.swimmer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca.png);}
.terminal-output .emoji.swimmer-var-0,.cmd .emoji.swimmer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fb.png);}
.terminal-output .emoji.swimmer-var-1,.cmd .emoji.swimmer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fc.png);}
.terminal-output .emoji.swimmer-var-2,.cmd .emoji.swimmer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fd.png);}
.terminal-output .emoji.swimmer-var-3,.cmd .emoji.swimmer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3fe.png);}
.terminal-output .emoji.swimmer-var-4,.cmd .emoji.swimmer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ca-1f3ff.png);}
.terminal-output .emoji.woman-lifting-weights,.cmd .emoji.woman-lifting-weights{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-fe0f-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-lifting-weights-var-0,.cmd .emoji.woman-lifting-weights-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-lifting-weights-var-1,.cmd .emoji.woman-lifting-weights-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-lifting-weights-var-2,.cmd .emoji.woman-lifting-weights-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-lifting-weights-var-3,.cmd .emoji.woman-lifting-weights-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-lifting-weights-var-4,.cmd .emoji.woman-lifting-weights-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-lifting-weights,.cmd .emoji.man-lifting-weights{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-fe0f-200d-2642-fe0f.png);}
.terminal-output .emoji.man-lifting-weights-var-0,.cmd .emoji.man-lifting-weights-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-lifting-weights-var-1,.cmd .emoji.man-lifting-weights-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-lifting-weights-var-2,.cmd .emoji.man-lifting-weights-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-lifting-weights-var-3,.cmd .emoji.man-lifting-weights-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-lifting-weights-var-4,.cmd .emoji.man-lifting-weights-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.weight_lifter,.cmd .emoji.weight_lifter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-fe0f.png);}
.terminal-output .emoji.weight_lifter-var-0,.cmd .emoji.weight_lifter-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fb.png);}
.terminal-output .emoji.weight_lifter-var-1,.cmd .emoji.weight_lifter-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fc.png);}
.terminal-output .emoji.weight_lifter-var-2,.cmd .emoji.weight_lifter-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fd.png);}
.terminal-output .emoji.weight_lifter-var-3,.cmd .emoji.weight_lifter-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3fe.png);}
.terminal-output .emoji.weight_lifter-var-4,.cmd .emoji.weight_lifter-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cb-1f3ff.png);}
.terminal-output .emoji.woman-golfing,.cmd .emoji.woman-golfing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-fe0f-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-golfing-var-0,.cmd .emoji.woman-golfing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-golfing-var-1,.cmd .emoji.woman-golfing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-golfing-var-2,.cmd .emoji.woman-golfing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-golfing-var-3,.cmd .emoji.woman-golfing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-golfing-var-4,.cmd .emoji.woman-golfing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-golfing,.cmd .emoji.man-golfing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-fe0f-200d-2642-fe0f.png);}
.terminal-output .emoji.man-golfing-var-0,.cmd .emoji.man-golfing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-golfing-var-1,.cmd .emoji.man-golfing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-golfing-var-2,.cmd .emoji.man-golfing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-golfing-var-3,.cmd .emoji.man-golfing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-golfing-var-4,.cmd .emoji.man-golfing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.golfer,.cmd .emoji.golfer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-fe0f.png);}
.terminal-output .emoji.golfer-var-0,.cmd .emoji.golfer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fb.png);}
.terminal-output .emoji.golfer-var-1,.cmd .emoji.golfer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fc.png);}
.terminal-output .emoji.golfer-var-2,.cmd .emoji.golfer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fd.png);}
.terminal-output .emoji.golfer-var-3,.cmd .emoji.golfer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3fe.png);}
.terminal-output .emoji.golfer-var-4,.cmd .emoji.golfer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cc-1f3ff.png);}
.terminal-output .emoji.racing_motorcycle,.cmd .emoji.racing_motorcycle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cd-fe0f.png);}
.terminal-output .emoji.racing_car,.cmd .emoji.racing_car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ce-fe0f.png);}
.terminal-output .emoji.cricket_bat_and_ball,.cmd .emoji.cricket_bat_and_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3cf.png);}
.terminal-output .emoji.volleyball,.cmd .emoji.volleyball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d0.png);}
.terminal-output .emoji.field_hockey_stick_and_ball,.cmd .emoji.field_hockey_stick_and_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d1.png);}
.terminal-output .emoji.ice_hockey_stick_and_puck,.cmd .emoji.ice_hockey_stick_and_puck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d2.png);}
.terminal-output .emoji.table_tennis_paddle_and_ball,.cmd .emoji.table_tennis_paddle_and_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d3.png);}
.terminal-output .emoji.snow_capped_mountain,.cmd .emoji.snow_capped_mountain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d4-fe0f.png);}
.terminal-output .emoji.camping,.cmd .emoji.camping{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d5-fe0f.png);}
.terminal-output .emoji.beach_with_umbrella,.cmd .emoji.beach_with_umbrella{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d6-fe0f.png);}
.terminal-output .emoji.building_construction,.cmd .emoji.building_construction{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d7-fe0f.png);}
.terminal-output .emoji.house_buildings,.cmd .emoji.house_buildings{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d8-fe0f.png);}
.terminal-output .emoji.cityscape,.cmd .emoji.cityscape{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3d9-fe0f.png);}
.terminal-output .emoji.derelict_house_building,.cmd .emoji.derelict_house_building{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3da-fe0f.png);}
.terminal-output .emoji.classical_building,.cmd .emoji.classical_building{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3db-fe0f.png);}
.terminal-output .emoji.desert,.cmd .emoji.desert{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3dc-fe0f.png);}
.terminal-output .emoji.desert_island,.cmd .emoji.desert_island{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3dd-fe0f.png);}
.terminal-output .emoji.national_park,.cmd .emoji.national_park{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3de-fe0f.png);}
.terminal-output .emoji.stadium,.cmd .emoji.stadium{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3df-fe0f.png);}
.terminal-output .emoji.house,.cmd .emoji.house{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e0.png);}
.terminal-output .emoji.house_with_garden,.cmd .emoji.house_with_garden{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e1.png);}
.terminal-output .emoji.office,.cmd .emoji.office{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e2.png);}
.terminal-output .emoji.post_office,.cmd .emoji.post_office{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e3.png);}
.terminal-output .emoji.european_post_office,.cmd .emoji.european_post_office{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e4.png);}
.terminal-output .emoji.hospital,.cmd .emoji.hospital{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e5.png);}
.terminal-output .emoji.bank,.cmd .emoji.bank{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e6.png);}
.terminal-output .emoji.atm,.cmd .emoji.atm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e7.png);}
.terminal-output .emoji.hotel,.cmd .emoji.hotel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e8.png);}
.terminal-output .emoji.love_hotel,.cmd .emoji.love_hotel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3e9.png);}
.terminal-output .emoji.convenience_store,.cmd .emoji.convenience_store{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ea.png);}
.terminal-output .emoji.school,.cmd .emoji.school{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3eb.png);}
.terminal-output .emoji.department_store,.cmd .emoji.department_store{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ec.png);}
.terminal-output .emoji.factory,.cmd .emoji.factory{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ed.png);}
.terminal-output .emoji.izakaya_lantern,.cmd .emoji.izakaya_lantern{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ee.png);}
.terminal-output .emoji.japanese_castle,.cmd .emoji.japanese_castle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ef.png);}
.terminal-output .emoji.european_castle,.cmd .emoji.european_castle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f0.png);}
.terminal-output .emoji.rainbow-flag,.cmd .emoji.rainbow-flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f3-fe0f-200d-1f308.png);}
.terminal-output .emoji.transgender_flag,.cmd .emoji.transgender_flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f3-fe0f-200d-26a7-fe0f.png);}
.terminal-output .emoji.waving_white_flag,.cmd .emoji.waving_white_flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f3-fe0f.png);}
.terminal-output .emoji.pirate_flag,.cmd .emoji.pirate_flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f4-200d-2620-fe0f.png);}
.terminal-output .emoji.flag-england,.cmd .emoji.flag-england{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f4-e0067-e0062-e0065-e006e-e0067-e007f.png);}
.terminal-output .emoji.flag-scotland,.cmd .emoji.flag-scotland{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f4-e0067-e0062-e0073-e0063-e0074-e007f.png);}
.terminal-output .emoji.flag-wales,.cmd .emoji.flag-wales{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f4-e0067-e0062-e0077-e006c-e0073-e007f.png);}
.terminal-output .emoji.waving_black_flag,.cmd .emoji.waving_black_flag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f4.png);}
.terminal-output .emoji.rosette,.cmd .emoji.rosette{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f5-fe0f.png);}
.terminal-output .emoji.label,.cmd .emoji.label{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f7-fe0f.png);}
.terminal-output .emoji.badminton_racquet_and_shuttlecock,.cmd .emoji.badminton_racquet_and_shuttlecock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f8.png);}
.terminal-output .emoji.bow_and_arrow,.cmd .emoji.bow_and_arrow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3f9.png);}
.terminal-output .emoji.amphora,.cmd .emoji.amphora{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3fa.png);}
.terminal-output .emoji.skin-tone-2,.cmd .emoji.skin-tone-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3fb.png);}
.terminal-output .emoji.skin-tone-3,.cmd .emoji.skin-tone-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3fc.png);}
.terminal-output .emoji.skin-tone-4,.cmd .emoji.skin-tone-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3fd.png);}
.terminal-output .emoji.skin-tone-5,.cmd .emoji.skin-tone-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3fe.png);}
.terminal-output .emoji.skin-tone-6,.cmd .emoji.skin-tone-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f3ff.png);}
.terminal-output .emoji.rat,.cmd .emoji.rat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f400.png);}
.terminal-output .emoji.mouse2,.cmd .emoji.mouse2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f401.png);}
.terminal-output .emoji.ox,.cmd .emoji.ox{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f402.png);}
.terminal-output .emoji.water_buffalo,.cmd .emoji.water_buffalo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f403.png);}
.terminal-output .emoji.cow2,.cmd .emoji.cow2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f404.png);}
.terminal-output .emoji.tiger2,.cmd .emoji.tiger2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f405.png);}
.terminal-output .emoji.leopard,.cmd .emoji.leopard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f406.png);}
.terminal-output .emoji.rabbit2,.cmd .emoji.rabbit2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f407.png);}
.terminal-output .emoji.black_cat,.cmd .emoji.black_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f408-200d-2b1b.png);}
.terminal-output .emoji.cat2,.cmd .emoji.cat2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f408.png);}
.terminal-output .emoji.dragon,.cmd .emoji.dragon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f409.png);}
.terminal-output .emoji.crocodile,.cmd .emoji.crocodile{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40a.png);}
.terminal-output .emoji.whale2,.cmd .emoji.whale2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40b.png);}
.terminal-output .emoji.snail,.cmd .emoji.snail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40c.png);}
.terminal-output .emoji.snake,.cmd .emoji.snake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40d.png);}
.terminal-output .emoji.racehorse,.cmd .emoji.racehorse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40e.png);}
.terminal-output .emoji.ram,.cmd .emoji.ram{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f40f.png);}
.terminal-output .emoji.goat,.cmd .emoji.goat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f410.png);}
.terminal-output .emoji.sheep,.cmd .emoji.sheep{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f411.png);}
.terminal-output .emoji.monkey,.cmd .emoji.monkey{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f412.png);}
.terminal-output .emoji.rooster,.cmd .emoji.rooster{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f413.png);}
.terminal-output .emoji.chicken,.cmd .emoji.chicken{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f414.png);}
.terminal-output .emoji.service_dog,.cmd .emoji.service_dog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f415-200d-1f9ba.png);}
.terminal-output .emoji.dog2,.cmd .emoji.dog2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f415.png);}
.terminal-output .emoji.pig2,.cmd .emoji.pig2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f416.png);}
.terminal-output .emoji.boar,.cmd .emoji.boar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f417.png);}
.terminal-output .emoji.elephant,.cmd .emoji.elephant{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f418.png);}
.terminal-output .emoji.octopus,.cmd .emoji.octopus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f419.png);}
.terminal-output .emoji.shell,.cmd .emoji.shell{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41a.png);}
.terminal-output .emoji.bug,.cmd .emoji.bug{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41b.png);}
.terminal-output .emoji.ant,.cmd .emoji.ant{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41c.png);}
.terminal-output .emoji.bee,.cmd .emoji.bee{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41d.png);}
.terminal-output .emoji.ladybug,.cmd .emoji.ladybug{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41e.png);}
.terminal-output .emoji.fish,.cmd .emoji.fish{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f41f.png);}
.terminal-output .emoji.tropical_fish,.cmd .emoji.tropical_fish{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f420.png);}
.terminal-output .emoji.blowfish,.cmd .emoji.blowfish{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f421.png);}
.terminal-output .emoji.turtle,.cmd .emoji.turtle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f422.png);}
.terminal-output .emoji.hatching_chick,.cmd .emoji.hatching_chick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f423.png);}
.terminal-output .emoji.baby_chick,.cmd .emoji.baby_chick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f424.png);}
.terminal-output .emoji.hatched_chick,.cmd .emoji.hatched_chick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f425.png);}
.terminal-output .emoji.bird,.cmd .emoji.bird{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f426.png);}
.terminal-output .emoji.penguin,.cmd .emoji.penguin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f427.png);}
.terminal-output .emoji.koala,.cmd .emoji.koala{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f428.png);}
.terminal-output .emoji.poodle,.cmd .emoji.poodle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f429.png);}
.terminal-output .emoji.dromedary_camel,.cmd .emoji.dromedary_camel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42a.png);}
.terminal-output .emoji.camel,.cmd .emoji.camel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42b.png);}
.terminal-output .emoji.dolphin,.cmd .emoji.dolphin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42c.png);}
.terminal-output .emoji.mouse,.cmd .emoji.mouse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42d.png);}
.terminal-output .emoji.cow,.cmd .emoji.cow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42e.png);}
.terminal-output .emoji.tiger,.cmd .emoji.tiger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f42f.png);}
.terminal-output .emoji.rabbit,.cmd .emoji.rabbit{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f430.png);}
.terminal-output .emoji.cat,.cmd .emoji.cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f431.png);}
.terminal-output .emoji.dragon_face,.cmd .emoji.dragon_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f432.png);}
.terminal-output .emoji.whale,.cmd .emoji.whale{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f433.png);}
.terminal-output .emoji.horse,.cmd .emoji.horse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f434.png);}
.terminal-output .emoji.monkey_face,.cmd .emoji.monkey_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f435.png);}
.terminal-output .emoji.dog,.cmd .emoji.dog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f436.png);}
.terminal-output .emoji.pig,.cmd .emoji.pig{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f437.png);}
.terminal-output .emoji.frog,.cmd .emoji.frog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f438.png);}
.terminal-output .emoji.hamster,.cmd .emoji.hamster{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f439.png);}
.terminal-output .emoji.wolf,.cmd .emoji.wolf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43a.png);}
.terminal-output .emoji.polar_bear,.cmd .emoji.polar_bear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43b-200d-2744-fe0f.png);}
.terminal-output .emoji.bear,.cmd .emoji.bear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43b.png);}
.terminal-output .emoji.panda_face,.cmd .emoji.panda_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43c.png);}
.terminal-output .emoji.pig_nose,.cmd .emoji.pig_nose{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43d.png);}
.terminal-output .emoji.feet,.cmd .emoji.feet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43e.png);}
.terminal-output .emoji.chipmunk,.cmd .emoji.chipmunk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f43f-fe0f.png);}
.terminal-output .emoji.eyes,.cmd .emoji.eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f440.png);}
.terminal-output .emoji.eye-in-speech-bubble,.cmd .emoji.eye-in-speech-bubble{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f441-fe0f-200d-1f5e8-fe0f.png);}
.terminal-output .emoji.eye,.cmd .emoji.eye{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f441-fe0f.png);}
.terminal-output .emoji.ear,.cmd .emoji.ear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442.png);}
.terminal-output .emoji.ear-var-0,.cmd .emoji.ear-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442-1f3fb.png);}
.terminal-output .emoji.ear-var-1,.cmd .emoji.ear-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442-1f3fc.png);}
.terminal-output .emoji.ear-var-2,.cmd .emoji.ear-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442-1f3fd.png);}
.terminal-output .emoji.ear-var-3,.cmd .emoji.ear-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442-1f3fe.png);}
.terminal-output .emoji.ear-var-4,.cmd .emoji.ear-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f442-1f3ff.png);}
.terminal-output .emoji.nose,.cmd .emoji.nose{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443.png);}
.terminal-output .emoji.nose-var-0,.cmd .emoji.nose-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443-1f3fb.png);}
.terminal-output .emoji.nose-var-1,.cmd .emoji.nose-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443-1f3fc.png);}
.terminal-output .emoji.nose-var-2,.cmd .emoji.nose-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443-1f3fd.png);}
.terminal-output .emoji.nose-var-3,.cmd .emoji.nose-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443-1f3fe.png);}
.terminal-output .emoji.nose-var-4,.cmd .emoji.nose-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f443-1f3ff.png);}
.terminal-output .emoji.lips,.cmd .emoji.lips{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f444.png);}
.terminal-output .emoji.tongue,.cmd .emoji.tongue{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f445.png);}
.terminal-output .emoji.point_up_2,.cmd .emoji.point_up_2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446.png);}
.terminal-output .emoji.point_up_2-var-0,.cmd .emoji.point_up_2-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446-1f3fb.png);}
.terminal-output .emoji.point_up_2-var-1,.cmd .emoji.point_up_2-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446-1f3fc.png);}
.terminal-output .emoji.point_up_2-var-2,.cmd .emoji.point_up_2-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446-1f3fd.png);}
.terminal-output .emoji.point_up_2-var-3,.cmd .emoji.point_up_2-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446-1f3fe.png);}
.terminal-output .emoji.point_up_2-var-4,.cmd .emoji.point_up_2-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f446-1f3ff.png);}
.terminal-output .emoji.point_down,.cmd .emoji.point_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447.png);}
.terminal-output .emoji.point_down-var-0,.cmd .emoji.point_down-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447-1f3fb.png);}
.terminal-output .emoji.point_down-var-1,.cmd .emoji.point_down-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447-1f3fc.png);}
.terminal-output .emoji.point_down-var-2,.cmd .emoji.point_down-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447-1f3fd.png);}
.terminal-output .emoji.point_down-var-3,.cmd .emoji.point_down-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447-1f3fe.png);}
.terminal-output .emoji.point_down-var-4,.cmd .emoji.point_down-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f447-1f3ff.png);}
.terminal-output .emoji.point_left,.cmd .emoji.point_left{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448.png);}
.terminal-output .emoji.point_left-var-0,.cmd .emoji.point_left-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448-1f3fb.png);}
.terminal-output .emoji.point_left-var-1,.cmd .emoji.point_left-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448-1f3fc.png);}
.terminal-output .emoji.point_left-var-2,.cmd .emoji.point_left-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448-1f3fd.png);}
.terminal-output .emoji.point_left-var-3,.cmd .emoji.point_left-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448-1f3fe.png);}
.terminal-output .emoji.point_left-var-4,.cmd .emoji.point_left-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f448-1f3ff.png);}
.terminal-output .emoji.point_right,.cmd .emoji.point_right{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449.png);}
.terminal-output .emoji.point_right-var-0,.cmd .emoji.point_right-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449-1f3fb.png);}
.terminal-output .emoji.point_right-var-1,.cmd .emoji.point_right-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449-1f3fc.png);}
.terminal-output .emoji.point_right-var-2,.cmd .emoji.point_right-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449-1f3fd.png);}
.terminal-output .emoji.point_right-var-3,.cmd .emoji.point_right-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449-1f3fe.png);}
.terminal-output .emoji.point_right-var-4,.cmd .emoji.point_right-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f449-1f3ff.png);}
.terminal-output .emoji.facepunch,.cmd .emoji.facepunch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a.png);}
.terminal-output .emoji.facepunch-var-0,.cmd .emoji.facepunch-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a-1f3fb.png);}
.terminal-output .emoji.facepunch-var-1,.cmd .emoji.facepunch-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a-1f3fc.png);}
.terminal-output .emoji.facepunch-var-2,.cmd .emoji.facepunch-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a-1f3fd.png);}
.terminal-output .emoji.facepunch-var-3,.cmd .emoji.facepunch-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a-1f3fe.png);}
.terminal-output .emoji.facepunch-var-4,.cmd .emoji.facepunch-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44a-1f3ff.png);}
.terminal-output .emoji.wave,.cmd .emoji.wave{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b.png);}
.terminal-output .emoji.wave-var-0,.cmd .emoji.wave-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b-1f3fb.png);}
.terminal-output .emoji.wave-var-1,.cmd .emoji.wave-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b-1f3fc.png);}
.terminal-output .emoji.wave-var-2,.cmd .emoji.wave-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b-1f3fd.png);}
.terminal-output .emoji.wave-var-3,.cmd .emoji.wave-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b-1f3fe.png);}
.terminal-output .emoji.wave-var-4,.cmd .emoji.wave-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44b-1f3ff.png);}
.terminal-output .emoji.ok_hand,.cmd .emoji.ok_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c.png);}
.terminal-output .emoji.ok_hand-var-0,.cmd .emoji.ok_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c-1f3fb.png);}
.terminal-output .emoji.ok_hand-var-1,.cmd .emoji.ok_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c-1f3fc.png);}
.terminal-output .emoji.ok_hand-var-2,.cmd .emoji.ok_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c-1f3fd.png);}
.terminal-output .emoji.ok_hand-var-3,.cmd .emoji.ok_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c-1f3fe.png);}
.terminal-output .emoji.ok_hand-var-4,.cmd .emoji.ok_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44c-1f3ff.png);}
.terminal-output .emoji.\+1,.cmd .emoji.\+1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d.png);}
.terminal-output .emoji.\+1-var-0,.cmd .emoji.\+1-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d-1f3fb.png);}
.terminal-output .emoji.\+1-var-1,.cmd .emoji.\+1-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d-1f3fc.png);}
.terminal-output .emoji.\+1-var-2,.cmd .emoji.\+1-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d-1f3fd.png);}
.terminal-output .emoji.\+1-var-3,.cmd .emoji.\+1-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d-1f3fe.png);}
.terminal-output .emoji.\+1-var-4,.cmd .emoji.\+1-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44d-1f3ff.png);}
.terminal-output .emoji.-1,.cmd .emoji.-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e.png);}
.terminal-output .emoji.-1-var-0,.cmd .emoji.-1-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e-1f3fb.png);}
.terminal-output .emoji.-1-var-1,.cmd .emoji.-1-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e-1f3fc.png);}
.terminal-output .emoji.-1-var-2,.cmd .emoji.-1-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e-1f3fd.png);}
.terminal-output .emoji.-1-var-3,.cmd .emoji.-1-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e-1f3fe.png);}
.terminal-output .emoji.-1-var-4,.cmd .emoji.-1-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44e-1f3ff.png);}
.terminal-output .emoji.clap,.cmd .emoji.clap{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f.png);}
.terminal-output .emoji.clap-var-0,.cmd .emoji.clap-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f-1f3fb.png);}
.terminal-output .emoji.clap-var-1,.cmd .emoji.clap-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f-1f3fc.png);}
.terminal-output .emoji.clap-var-2,.cmd .emoji.clap-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f-1f3fd.png);}
.terminal-output .emoji.clap-var-3,.cmd .emoji.clap-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f-1f3fe.png);}
.terminal-output .emoji.clap-var-4,.cmd .emoji.clap-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f44f-1f3ff.png);}
.terminal-output .emoji.open_hands,.cmd .emoji.open_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450.png);}
.terminal-output .emoji.open_hands-var-0,.cmd .emoji.open_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450-1f3fb.png);}
.terminal-output .emoji.open_hands-var-1,.cmd .emoji.open_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450-1f3fc.png);}
.terminal-output .emoji.open_hands-var-2,.cmd .emoji.open_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450-1f3fd.png);}
.terminal-output .emoji.open_hands-var-3,.cmd .emoji.open_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450-1f3fe.png);}
.terminal-output .emoji.open_hands-var-4,.cmd .emoji.open_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f450-1f3ff.png);}
.terminal-output .emoji.crown,.cmd .emoji.crown{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f451.png);}
.terminal-output .emoji.womans_hat,.cmd .emoji.womans_hat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f452.png);}
.terminal-output .emoji.eyeglasses,.cmd .emoji.eyeglasses{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f453.png);}
.terminal-output .emoji.necktie,.cmd .emoji.necktie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f454.png);}
.terminal-output .emoji.shirt,.cmd .emoji.shirt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f455.png);}
.terminal-output .emoji.jeans,.cmd .emoji.jeans{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f456.png);}
.terminal-output .emoji.dress,.cmd .emoji.dress{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f457.png);}
.terminal-output .emoji.kimono,.cmd .emoji.kimono{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f458.png);}
.terminal-output .emoji.bikini,.cmd .emoji.bikini{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f459.png);}
.terminal-output .emoji.womans_clothes,.cmd .emoji.womans_clothes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45a.png);}
.terminal-output .emoji.purse,.cmd .emoji.purse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45b.png);}
.terminal-output .emoji.handbag,.cmd .emoji.handbag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45c.png);}
.terminal-output .emoji.pouch,.cmd .emoji.pouch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45d.png);}
.terminal-output .emoji.mans_shoe,.cmd .emoji.mans_shoe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45e.png);}
.terminal-output .emoji.athletic_shoe,.cmd .emoji.athletic_shoe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f45f.png);}
.terminal-output .emoji.high_heel,.cmd .emoji.high_heel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f460.png);}
.terminal-output .emoji.sandal,.cmd .emoji.sandal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f461.png);}
.terminal-output .emoji.boot,.cmd .emoji.boot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f462.png);}
.terminal-output .emoji.footprints,.cmd .emoji.footprints{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f463.png);}
.terminal-output .emoji.bust_in_silhouette,.cmd .emoji.bust_in_silhouette{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f464.png);}
.terminal-output .emoji.busts_in_silhouette,.cmd .emoji.busts_in_silhouette{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f465.png);}
.terminal-output .emoji.boy,.cmd .emoji.boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466.png);}
.terminal-output .emoji.boy-var-0,.cmd .emoji.boy-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466-1f3fb.png);}
.terminal-output .emoji.boy-var-1,.cmd .emoji.boy-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466-1f3fc.png);}
.terminal-output .emoji.boy-var-2,.cmd .emoji.boy-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466-1f3fd.png);}
.terminal-output .emoji.boy-var-3,.cmd .emoji.boy-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466-1f3fe.png);}
.terminal-output .emoji.boy-var-4,.cmd .emoji.boy-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f466-1f3ff.png);}
.terminal-output .emoji.girl,.cmd .emoji.girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467.png);}
.terminal-output .emoji.girl-var-0,.cmd .emoji.girl-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467-1f3fb.png);}
.terminal-output .emoji.girl-var-1,.cmd .emoji.girl-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467-1f3fc.png);}
.terminal-output .emoji.girl-var-2,.cmd .emoji.girl-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467-1f3fd.png);}
.terminal-output .emoji.girl-var-3,.cmd .emoji.girl-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467-1f3fe.png);}
.terminal-output .emoji.girl-var-4,.cmd .emoji.girl-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f467-1f3ff.png);}
.terminal-output .emoji.male-farmer,.cmd .emoji.male-farmer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f33e.png);}
.terminal-output .emoji.male-farmer-var-0,.cmd .emoji.male-farmer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f33e.png);}
.terminal-output .emoji.male-farmer-var-1,.cmd .emoji.male-farmer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f33e.png);}
.terminal-output .emoji.male-farmer-var-2,.cmd .emoji.male-farmer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f33e.png);}
.terminal-output .emoji.male-farmer-var-3,.cmd .emoji.male-farmer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f33e.png);}
.terminal-output .emoji.male-farmer-var-4,.cmd .emoji.male-farmer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f33e.png);}
.terminal-output .emoji.male-cook,.cmd .emoji.male-cook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f373.png);}
.terminal-output .emoji.male-cook-var-0,.cmd .emoji.male-cook-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f373.png);}
.terminal-output .emoji.male-cook-var-1,.cmd .emoji.male-cook-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f373.png);}
.terminal-output .emoji.male-cook-var-2,.cmd .emoji.male-cook-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f373.png);}
.terminal-output .emoji.male-cook-var-3,.cmd .emoji.male-cook-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f373.png);}
.terminal-output .emoji.male-cook-var-4,.cmd .emoji.male-cook-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f373.png);}
.terminal-output .emoji.man_feeding_baby,.cmd .emoji.man_feeding_baby{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f37c.png);}
.terminal-output .emoji.man_feeding_baby-var-0,.cmd .emoji.man_feeding_baby-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f37c.png);}
.terminal-output .emoji.man_feeding_baby-var-1,.cmd .emoji.man_feeding_baby-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f37c.png);}
.terminal-output .emoji.man_feeding_baby-var-2,.cmd .emoji.man_feeding_baby-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f37c.png);}
.terminal-output .emoji.man_feeding_baby-var-3,.cmd .emoji.man_feeding_baby-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f37c.png);}
.terminal-output .emoji.man_feeding_baby-var-4,.cmd .emoji.man_feeding_baby-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f37c.png);}
.terminal-output .emoji.male-student,.cmd .emoji.male-student{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f393.png);}
.terminal-output .emoji.male-student-var-0,.cmd .emoji.male-student-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f393.png);}
.terminal-output .emoji.male-student-var-1,.cmd .emoji.male-student-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f393.png);}
.terminal-output .emoji.male-student-var-2,.cmd .emoji.male-student-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f393.png);}
.terminal-output .emoji.male-student-var-3,.cmd .emoji.male-student-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f393.png);}
.terminal-output .emoji.male-student-var-4,.cmd .emoji.male-student-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f393.png);}
.terminal-output .emoji.male-singer,.cmd .emoji.male-singer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f3a4.png);}
.terminal-output .emoji.male-singer-var-0,.cmd .emoji.male-singer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f3a4.png);}
.terminal-output .emoji.male-singer-var-1,.cmd .emoji.male-singer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f3a4.png);}
.terminal-output .emoji.male-singer-var-2,.cmd .emoji.male-singer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f3a4.png);}
.terminal-output .emoji.male-singer-var-3,.cmd .emoji.male-singer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f3a4.png);}
.terminal-output .emoji.male-singer-var-4,.cmd .emoji.male-singer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f3a4.png);}
.terminal-output .emoji.male-artist,.cmd .emoji.male-artist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f3a8.png);}
.terminal-output .emoji.male-artist-var-0,.cmd .emoji.male-artist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f3a8.png);}
.terminal-output .emoji.male-artist-var-1,.cmd .emoji.male-artist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f3a8.png);}
.terminal-output .emoji.male-artist-var-2,.cmd .emoji.male-artist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f3a8.png);}
.terminal-output .emoji.male-artist-var-3,.cmd .emoji.male-artist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f3a8.png);}
.terminal-output .emoji.male-artist-var-4,.cmd .emoji.male-artist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f3a8.png);}
.terminal-output .emoji.male-teacher,.cmd .emoji.male-teacher{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f3eb.png);}
.terminal-output .emoji.male-teacher-var-0,.cmd .emoji.male-teacher-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f3eb.png);}
.terminal-output .emoji.male-teacher-var-1,.cmd .emoji.male-teacher-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f3eb.png);}
.terminal-output .emoji.male-teacher-var-2,.cmd .emoji.male-teacher-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f3eb.png);}
.terminal-output .emoji.male-teacher-var-3,.cmd .emoji.male-teacher-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f3eb.png);}
.terminal-output .emoji.male-teacher-var-4,.cmd .emoji.male-teacher-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f3eb.png);}
.terminal-output .emoji.male-factory-worker,.cmd .emoji.male-factory-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f3ed.png);}
.terminal-output .emoji.male-factory-worker-var-0,.cmd .emoji.male-factory-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f3ed.png);}
.terminal-output .emoji.male-factory-worker-var-1,.cmd .emoji.male-factory-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f3ed.png);}
.terminal-output .emoji.male-factory-worker-var-2,.cmd .emoji.male-factory-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f3ed.png);}
.terminal-output .emoji.male-factory-worker-var-3,.cmd .emoji.male-factory-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f3ed.png);}
.terminal-output .emoji.male-factory-worker-var-4,.cmd .emoji.male-factory-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f3ed.png);}
.terminal-output .emoji.man-boy-boy,.cmd .emoji.man-boy-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f466-200d-1f466.png);}
.terminal-output .emoji.man-boy,.cmd .emoji.man-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f466.png);}
.terminal-output .emoji.man-girl-boy,.cmd .emoji.man-girl-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f467-200d-1f466.png);}
.terminal-output .emoji.man-girl-girl,.cmd .emoji.man-girl-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f467-200d-1f467.png);}
.terminal-output .emoji.man-girl,.cmd .emoji.man-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f467.png);}
.terminal-output .emoji.man-man-boy,.cmd .emoji.man-man-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f468-200d-1f466.png);}
.terminal-output .emoji.man-man-boy-boy,.cmd .emoji.man-man-boy-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f468-200d-1f466-200d-1f466.png);}
.terminal-output .emoji.man-man-girl,.cmd .emoji.man-man-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f468-200d-1f467.png);}
.terminal-output .emoji.man-man-girl-boy,.cmd .emoji.man-man-girl-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f468-200d-1f467-200d-1f466.png);}
.terminal-output .emoji.man-man-girl-girl,.cmd .emoji.man-man-girl-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f468-200d-1f467-200d-1f467.png);}
.terminal-output .emoji.man-woman-boy,.cmd .emoji.man-woman-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f469-200d-1f466.png);}
.terminal-output .emoji.man-woman-boy-boy,.cmd .emoji.man-woman-boy-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f469-200d-1f466-200d-1f466.png);}
.terminal-output .emoji.man-woman-girl,.cmd .emoji.man-woman-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f469-200d-1f467.png);}
.terminal-output .emoji.man-woman-girl-boy,.cmd .emoji.man-woman-girl-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f469-200d-1f467-200d-1f466.png);}
.terminal-output .emoji.man-woman-girl-girl,.cmd .emoji.man-woman-girl-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f469-200d-1f467-200d-1f467.png);}
.terminal-output .emoji.male-technologist,.cmd .emoji.male-technologist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f4bb.png);}
.terminal-output .emoji.male-technologist-var-0,.cmd .emoji.male-technologist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f4bb.png);}
.terminal-output .emoji.male-technologist-var-1,.cmd .emoji.male-technologist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f4bb.png);}
.terminal-output .emoji.male-technologist-var-2,.cmd .emoji.male-technologist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f4bb.png);}
.terminal-output .emoji.male-technologist-var-3,.cmd .emoji.male-technologist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f4bb.png);}
.terminal-output .emoji.male-technologist-var-4,.cmd .emoji.male-technologist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f4bb.png);}
.terminal-output .emoji.male-office-worker,.cmd .emoji.male-office-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f4bc.png);}
.terminal-output .emoji.male-office-worker-var-0,.cmd .emoji.male-office-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f4bc.png);}
.terminal-output .emoji.male-office-worker-var-1,.cmd .emoji.male-office-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f4bc.png);}
.terminal-output .emoji.male-office-worker-var-2,.cmd .emoji.male-office-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f4bc.png);}
.terminal-output .emoji.male-office-worker-var-3,.cmd .emoji.male-office-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f4bc.png);}
.terminal-output .emoji.male-office-worker-var-4,.cmd .emoji.male-office-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f4bc.png);}
.terminal-output .emoji.male-mechanic,.cmd .emoji.male-mechanic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f527.png);}
.terminal-output .emoji.male-mechanic-var-0,.cmd .emoji.male-mechanic-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f527.png);}
.terminal-output .emoji.male-mechanic-var-1,.cmd .emoji.male-mechanic-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f527.png);}
.terminal-output .emoji.male-mechanic-var-2,.cmd .emoji.male-mechanic-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f527.png);}
.terminal-output .emoji.male-mechanic-var-3,.cmd .emoji.male-mechanic-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f527.png);}
.terminal-output .emoji.male-mechanic-var-4,.cmd .emoji.male-mechanic-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f527.png);}
.terminal-output .emoji.male-scientist,.cmd .emoji.male-scientist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f52c.png);}
.terminal-output .emoji.male-scientist-var-0,.cmd .emoji.male-scientist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f52c.png);}
.terminal-output .emoji.male-scientist-var-1,.cmd .emoji.male-scientist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f52c.png);}
.terminal-output .emoji.male-scientist-var-2,.cmd .emoji.male-scientist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f52c.png);}
.terminal-output .emoji.male-scientist-var-3,.cmd .emoji.male-scientist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f52c.png);}
.terminal-output .emoji.male-scientist-var-4,.cmd .emoji.male-scientist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f52c.png);}
.terminal-output .emoji.male-astronaut,.cmd .emoji.male-astronaut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f680.png);}
.terminal-output .emoji.male-astronaut-var-0,.cmd .emoji.male-astronaut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f680.png);}
.terminal-output .emoji.male-astronaut-var-1,.cmd .emoji.male-astronaut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f680.png);}
.terminal-output .emoji.male-astronaut-var-2,.cmd .emoji.male-astronaut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f680.png);}
.terminal-output .emoji.male-astronaut-var-3,.cmd .emoji.male-astronaut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f680.png);}
.terminal-output .emoji.male-astronaut-var-4,.cmd .emoji.male-astronaut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f680.png);}
.terminal-output .emoji.male-firefighter,.cmd .emoji.male-firefighter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f692.png);}
.terminal-output .emoji.male-firefighter-var-0,.cmd .emoji.male-firefighter-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f692.png);}
.terminal-output .emoji.male-firefighter-var-1,.cmd .emoji.male-firefighter-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f692.png);}
.terminal-output .emoji.male-firefighter-var-2,.cmd .emoji.male-firefighter-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f692.png);}
.terminal-output .emoji.male-firefighter-var-3,.cmd .emoji.male-firefighter-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f692.png);}
.terminal-output .emoji.male-firefighter-var-4,.cmd .emoji.male-firefighter-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f692.png);}
.terminal-output .emoji.man_with_probing_cane,.cmd .emoji.man_with_probing_cane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9af.png);}
.terminal-output .emoji.man_with_probing_cane-var-0,.cmd .emoji.man_with_probing_cane-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9af.png);}
.terminal-output .emoji.man_with_probing_cane-var-1,.cmd .emoji.man_with_probing_cane-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9af.png);}
.terminal-output .emoji.man_with_probing_cane-var-2,.cmd .emoji.man_with_probing_cane-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9af.png);}
.terminal-output .emoji.man_with_probing_cane-var-3,.cmd .emoji.man_with_probing_cane-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9af.png);}
.terminal-output .emoji.man_with_probing_cane-var-4,.cmd .emoji.man_with_probing_cane-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9af.png);}
.terminal-output .emoji.red_haired_man,.cmd .emoji.red_haired_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_man-var-0,.cmd .emoji.red_haired_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_man-var-1,.cmd .emoji.red_haired_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_man-var-2,.cmd .emoji.red_haired_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_man-var-3,.cmd .emoji.red_haired_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_man-var-4,.cmd .emoji.red_haired_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9b0.png);}
.terminal-output .emoji.curly_haired_man,.cmd .emoji.curly_haired_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_man-var-0,.cmd .emoji.curly_haired_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_man-var-1,.cmd .emoji.curly_haired_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_man-var-2,.cmd .emoji.curly_haired_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_man-var-3,.cmd .emoji.curly_haired_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_man-var-4,.cmd .emoji.curly_haired_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9b1.png);}
.terminal-output .emoji.bald_man,.cmd .emoji.bald_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9b2.png);}
.terminal-output .emoji.bald_man-var-0,.cmd .emoji.bald_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9b2.png);}
.terminal-output .emoji.bald_man-var-1,.cmd .emoji.bald_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9b2.png);}
.terminal-output .emoji.bald_man-var-2,.cmd .emoji.bald_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9b2.png);}
.terminal-output .emoji.bald_man-var-3,.cmd .emoji.bald_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9b2.png);}
.terminal-output .emoji.bald_man-var-4,.cmd .emoji.bald_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9b2.png);}
.terminal-output .emoji.white_haired_man,.cmd .emoji.white_haired_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_man-var-0,.cmd .emoji.white_haired_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_man-var-1,.cmd .emoji.white_haired_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_man-var-2,.cmd .emoji.white_haired_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_man-var-3,.cmd .emoji.white_haired_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_man-var-4,.cmd .emoji.white_haired_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9b3.png);}
.terminal-output .emoji.man_in_motorized_wheelchair,.cmd .emoji.man_in_motorized_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9bc.png);}
.terminal-output .emoji.man_in_motorized_wheelchair-var-0,.cmd .emoji.man_in_motorized_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9bc.png);}
.terminal-output .emoji.man_in_motorized_wheelchair-var-1,.cmd .emoji.man_in_motorized_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9bc.png);}
.terminal-output .emoji.man_in_motorized_wheelchair-var-2,.cmd .emoji.man_in_motorized_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9bc.png);}
.terminal-output .emoji.man_in_motorized_wheelchair-var-3,.cmd .emoji.man_in_motorized_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9bc.png);}
.terminal-output .emoji.man_in_motorized_wheelchair-var-4,.cmd .emoji.man_in_motorized_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9bc.png);}
.terminal-output .emoji.man_in_manual_wheelchair,.cmd .emoji.man_in_manual_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-1f9bd.png);}
.terminal-output .emoji.man_in_manual_wheelchair-var-0,.cmd .emoji.man_in_manual_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f9bd.png);}
.terminal-output .emoji.man_in_manual_wheelchair-var-1,.cmd .emoji.man_in_manual_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f9bd.png);}
.terminal-output .emoji.man_in_manual_wheelchair-var-2,.cmd .emoji.man_in_manual_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f9bd.png);}
.terminal-output .emoji.man_in_manual_wheelchair-var-3,.cmd .emoji.man_in_manual_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f9bd.png);}
.terminal-output .emoji.man_in_manual_wheelchair-var-4,.cmd .emoji.man_in_manual_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f9bd.png);}
.terminal-output .emoji.male-doctor,.cmd .emoji.male-doctor{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-2695-fe0f.png);}
.terminal-output .emoji.male-doctor-var-0,.cmd .emoji.male-doctor-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2695-fe0f.png);}
.terminal-output .emoji.male-doctor-var-1,.cmd .emoji.male-doctor-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2695-fe0f.png);}
.terminal-output .emoji.male-doctor-var-2,.cmd .emoji.male-doctor-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2695-fe0f.png);}
.terminal-output .emoji.male-doctor-var-3,.cmd .emoji.male-doctor-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2695-fe0f.png);}
.terminal-output .emoji.male-doctor-var-4,.cmd .emoji.male-doctor-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2695-fe0f.png);}
.terminal-output .emoji.male-judge,.cmd .emoji.male-judge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-2696-fe0f.png);}
.terminal-output .emoji.male-judge-var-0,.cmd .emoji.male-judge-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2696-fe0f.png);}
.terminal-output .emoji.male-judge-var-1,.cmd .emoji.male-judge-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2696-fe0f.png);}
.terminal-output .emoji.male-judge-var-2,.cmd .emoji.male-judge-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2696-fe0f.png);}
.terminal-output .emoji.male-judge-var-3,.cmd .emoji.male-judge-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2696-fe0f.png);}
.terminal-output .emoji.male-judge-var-4,.cmd .emoji.male-judge-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2696-fe0f.png);}
.terminal-output .emoji.male-pilot,.cmd .emoji.male-pilot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-2708-fe0f.png);}
.terminal-output .emoji.male-pilot-var-0,.cmd .emoji.male-pilot-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2708-fe0f.png);}
.terminal-output .emoji.male-pilot-var-1,.cmd .emoji.male-pilot-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2708-fe0f.png);}
.terminal-output .emoji.male-pilot-var-2,.cmd .emoji.male-pilot-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2708-fe0f.png);}
.terminal-output .emoji.male-pilot-var-3,.cmd .emoji.male-pilot-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2708-fe0f.png);}
.terminal-output .emoji.male-pilot-var-4,.cmd .emoji.male-pilot-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2708-fe0f.png);}
.terminal-output .emoji.man-heart-man,.cmd .emoji.man-heart-man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-2764-fe0f-200d-1f468.png);}
.terminal-output .emoji.man-heart-man-var-0,.cmd .emoji.man-heart-man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-heart-man-var-1,.cmd .emoji.man-heart-man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-heart-man-var-2,.cmd .emoji.man-heart-man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-heart-man-var-3,.cmd .emoji.man-heart-man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-heart-man-var-4,.cmd .emoji.man-heart-man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-heart-man-var-5,.cmd .emoji.man-heart-man-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-heart-man-var-6,.cmd .emoji.man-heart-man-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-heart-man-var-7,.cmd .emoji.man-heart-man-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-heart-man-var-8,.cmd .emoji.man-heart-man-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-heart-man-var-9,.cmd .emoji.man-heart-man-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-heart-man-var-10,.cmd .emoji.man-heart-man-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-heart-man-var-11,.cmd .emoji.man-heart-man-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-heart-man-var-12,.cmd .emoji.man-heart-man-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-heart-man-var-13,.cmd .emoji.man-heart-man-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-heart-man-var-14,.cmd .emoji.man-heart-man-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-heart-man-var-15,.cmd .emoji.man-heart-man-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-heart-man-var-16,.cmd .emoji.man-heart-man-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-heart-man-var-17,.cmd .emoji.man-heart-man-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-heart-man-var-18,.cmd .emoji.man-heart-man-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-heart-man-var-19,.cmd .emoji.man-heart-man-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-heart-man-var-20,.cmd .emoji.man-heart-man-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-heart-man-var-21,.cmd .emoji.man-heart-man-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-heart-man-var-22,.cmd .emoji.man-heart-man-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-heart-man-var-23,.cmd .emoji.man-heart-man-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-heart-man-var-24,.cmd .emoji.man-heart-man-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-kiss-man,.cmd .emoji.man-kiss-man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-200d-2764-fe0f-200d-1f48b-200d-1f468.png);}
.terminal-output .emoji.man-kiss-man-var-0,.cmd .emoji.man-kiss-man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-kiss-man-var-1,.cmd .emoji.man-kiss-man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-kiss-man-var-2,.cmd .emoji.man-kiss-man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-kiss-man-var-3,.cmd .emoji.man-kiss-man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-kiss-man-var-4,.cmd .emoji.man-kiss-man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-kiss-man-var-5,.cmd .emoji.man-kiss-man-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-kiss-man-var-6,.cmd .emoji.man-kiss-man-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-kiss-man-var-7,.cmd .emoji.man-kiss-man-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-kiss-man-var-8,.cmd .emoji.man-kiss-man-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-kiss-man-var-9,.cmd .emoji.man-kiss-man-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-kiss-man-var-10,.cmd .emoji.man-kiss-man-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-kiss-man-var-11,.cmd .emoji.man-kiss-man-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-kiss-man-var-12,.cmd .emoji.man-kiss-man-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-kiss-man-var-13,.cmd .emoji.man-kiss-man-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-kiss-man-var-14,.cmd .emoji.man-kiss-man-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-kiss-man-var-15,.cmd .emoji.man-kiss-man-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-kiss-man-var-16,.cmd .emoji.man-kiss-man-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-kiss-man-var-17,.cmd .emoji.man-kiss-man-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-kiss-man-var-18,.cmd .emoji.man-kiss-man-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-kiss-man-var-19,.cmd .emoji.man-kiss-man-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man-kiss-man-var-20,.cmd .emoji.man-kiss-man-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man-kiss-man-var-21,.cmd .emoji.man-kiss-man-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man-kiss-man-var-22,.cmd .emoji.man-kiss-man-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man-kiss-man-var-23,.cmd .emoji.man-kiss-man-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man-kiss-man-var-24,.cmd .emoji.man-kiss-man-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man,.cmd .emoji.man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468.png);}
.terminal-output .emoji.man-var-0,.cmd .emoji.man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb.png);}
.terminal-output .emoji.man-var-1,.cmd .emoji.man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc.png);}
.terminal-output .emoji.man-var-2,.cmd .emoji.man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd.png);}
.terminal-output .emoji.man-var-3,.cmd .emoji.man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe.png);}
.terminal-output .emoji.man-var-4,.cmd .emoji.man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff.png);}
.terminal-output .emoji.female-farmer,.cmd .emoji.female-farmer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f33e.png);}
.terminal-output .emoji.female-farmer-var-0,.cmd .emoji.female-farmer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f33e.png);}
.terminal-output .emoji.female-farmer-var-1,.cmd .emoji.female-farmer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f33e.png);}
.terminal-output .emoji.female-farmer-var-2,.cmd .emoji.female-farmer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f33e.png);}
.terminal-output .emoji.female-farmer-var-3,.cmd .emoji.female-farmer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f33e.png);}
.terminal-output .emoji.female-farmer-var-4,.cmd .emoji.female-farmer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f33e.png);}
.terminal-output .emoji.female-cook,.cmd .emoji.female-cook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f373.png);}
.terminal-output .emoji.female-cook-var-0,.cmd .emoji.female-cook-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f373.png);}
.terminal-output .emoji.female-cook-var-1,.cmd .emoji.female-cook-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f373.png);}
.terminal-output .emoji.female-cook-var-2,.cmd .emoji.female-cook-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f373.png);}
.terminal-output .emoji.female-cook-var-3,.cmd .emoji.female-cook-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f373.png);}
.terminal-output .emoji.female-cook-var-4,.cmd .emoji.female-cook-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f373.png);}
.terminal-output .emoji.woman_feeding_baby,.cmd .emoji.woman_feeding_baby{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f37c.png);}
.terminal-output .emoji.woman_feeding_baby-var-0,.cmd .emoji.woman_feeding_baby-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f37c.png);}
.terminal-output .emoji.woman_feeding_baby-var-1,.cmd .emoji.woman_feeding_baby-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f37c.png);}
.terminal-output .emoji.woman_feeding_baby-var-2,.cmd .emoji.woman_feeding_baby-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f37c.png);}
.terminal-output .emoji.woman_feeding_baby-var-3,.cmd .emoji.woman_feeding_baby-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f37c.png);}
.terminal-output .emoji.woman_feeding_baby-var-4,.cmd .emoji.woman_feeding_baby-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f37c.png);}
.terminal-output .emoji.female-student,.cmd .emoji.female-student{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f393.png);}
.terminal-output .emoji.female-student-var-0,.cmd .emoji.female-student-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f393.png);}
.terminal-output .emoji.female-student-var-1,.cmd .emoji.female-student-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f393.png);}
.terminal-output .emoji.female-student-var-2,.cmd .emoji.female-student-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f393.png);}
.terminal-output .emoji.female-student-var-3,.cmd .emoji.female-student-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f393.png);}
.terminal-output .emoji.female-student-var-4,.cmd .emoji.female-student-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f393.png);}
.terminal-output .emoji.female-singer,.cmd .emoji.female-singer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f3a4.png);}
.terminal-output .emoji.female-singer-var-0,.cmd .emoji.female-singer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f3a4.png);}
.terminal-output .emoji.female-singer-var-1,.cmd .emoji.female-singer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f3a4.png);}
.terminal-output .emoji.female-singer-var-2,.cmd .emoji.female-singer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f3a4.png);}
.terminal-output .emoji.female-singer-var-3,.cmd .emoji.female-singer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f3a4.png);}
.terminal-output .emoji.female-singer-var-4,.cmd .emoji.female-singer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f3a4.png);}
.terminal-output .emoji.female-artist,.cmd .emoji.female-artist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f3a8.png);}
.terminal-output .emoji.female-artist-var-0,.cmd .emoji.female-artist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f3a8.png);}
.terminal-output .emoji.female-artist-var-1,.cmd .emoji.female-artist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f3a8.png);}
.terminal-output .emoji.female-artist-var-2,.cmd .emoji.female-artist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f3a8.png);}
.terminal-output .emoji.female-artist-var-3,.cmd .emoji.female-artist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f3a8.png);}
.terminal-output .emoji.female-artist-var-4,.cmd .emoji.female-artist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f3a8.png);}
.terminal-output .emoji.female-teacher,.cmd .emoji.female-teacher{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f3eb.png);}
.terminal-output .emoji.female-teacher-var-0,.cmd .emoji.female-teacher-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f3eb.png);}
.terminal-output .emoji.female-teacher-var-1,.cmd .emoji.female-teacher-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f3eb.png);}
.terminal-output .emoji.female-teacher-var-2,.cmd .emoji.female-teacher-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f3eb.png);}
.terminal-output .emoji.female-teacher-var-3,.cmd .emoji.female-teacher-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f3eb.png);}
.terminal-output .emoji.female-teacher-var-4,.cmd .emoji.female-teacher-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f3eb.png);}
.terminal-output .emoji.female-factory-worker,.cmd .emoji.female-factory-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f3ed.png);}
.terminal-output .emoji.female-factory-worker-var-0,.cmd .emoji.female-factory-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f3ed.png);}
.terminal-output .emoji.female-factory-worker-var-1,.cmd .emoji.female-factory-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f3ed.png);}
.terminal-output .emoji.female-factory-worker-var-2,.cmd .emoji.female-factory-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f3ed.png);}
.terminal-output .emoji.female-factory-worker-var-3,.cmd .emoji.female-factory-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f3ed.png);}
.terminal-output .emoji.female-factory-worker-var-4,.cmd .emoji.female-factory-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f3ed.png);}
.terminal-output .emoji.woman-boy-boy,.cmd .emoji.woman-boy-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f466-200d-1f466.png);}
.terminal-output .emoji.woman-boy,.cmd .emoji.woman-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f466.png);}
.terminal-output .emoji.woman-girl-boy,.cmd .emoji.woman-girl-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f467-200d-1f466.png);}
.terminal-output .emoji.woman-girl-girl,.cmd .emoji.woman-girl-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f467-200d-1f467.png);}
.terminal-output .emoji.woman-girl,.cmd .emoji.woman-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f467.png);}
.terminal-output .emoji.woman-woman-boy,.cmd .emoji.woman-woman-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f469-200d-1f466.png);}
.terminal-output .emoji.woman-woman-boy-boy,.cmd .emoji.woman-woman-boy-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f469-200d-1f466-200d-1f466.png);}
.terminal-output .emoji.woman-woman-girl,.cmd .emoji.woman-woman-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f469-200d-1f467.png);}
.terminal-output .emoji.woman-woman-girl-boy,.cmd .emoji.woman-woman-girl-boy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f469-200d-1f467-200d-1f466.png);}
.terminal-output .emoji.woman-woman-girl-girl,.cmd .emoji.woman-woman-girl-girl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f469-200d-1f467-200d-1f467.png);}
.terminal-output .emoji.female-technologist,.cmd .emoji.female-technologist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f4bb.png);}
.terminal-output .emoji.female-technologist-var-0,.cmd .emoji.female-technologist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f4bb.png);}
.terminal-output .emoji.female-technologist-var-1,.cmd .emoji.female-technologist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f4bb.png);}
.terminal-output .emoji.female-technologist-var-2,.cmd .emoji.female-technologist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f4bb.png);}
.terminal-output .emoji.female-technologist-var-3,.cmd .emoji.female-technologist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f4bb.png);}
.terminal-output .emoji.female-technologist-var-4,.cmd .emoji.female-technologist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f4bb.png);}
.terminal-output .emoji.female-office-worker,.cmd .emoji.female-office-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f4bc.png);}
.terminal-output .emoji.female-office-worker-var-0,.cmd .emoji.female-office-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f4bc.png);}
.terminal-output .emoji.female-office-worker-var-1,.cmd .emoji.female-office-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f4bc.png);}
.terminal-output .emoji.female-office-worker-var-2,.cmd .emoji.female-office-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f4bc.png);}
.terminal-output .emoji.female-office-worker-var-3,.cmd .emoji.female-office-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f4bc.png);}
.terminal-output .emoji.female-office-worker-var-4,.cmd .emoji.female-office-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f4bc.png);}
.terminal-output .emoji.female-mechanic,.cmd .emoji.female-mechanic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f527.png);}
.terminal-output .emoji.female-mechanic-var-0,.cmd .emoji.female-mechanic-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f527.png);}
.terminal-output .emoji.female-mechanic-var-1,.cmd .emoji.female-mechanic-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f527.png);}
.terminal-output .emoji.female-mechanic-var-2,.cmd .emoji.female-mechanic-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f527.png);}
.terminal-output .emoji.female-mechanic-var-3,.cmd .emoji.female-mechanic-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f527.png);}
.terminal-output .emoji.female-mechanic-var-4,.cmd .emoji.female-mechanic-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f527.png);}
.terminal-output .emoji.female-scientist,.cmd .emoji.female-scientist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f52c.png);}
.terminal-output .emoji.female-scientist-var-0,.cmd .emoji.female-scientist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f52c.png);}
.terminal-output .emoji.female-scientist-var-1,.cmd .emoji.female-scientist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f52c.png);}
.terminal-output .emoji.female-scientist-var-2,.cmd .emoji.female-scientist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f52c.png);}
.terminal-output .emoji.female-scientist-var-3,.cmd .emoji.female-scientist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f52c.png);}
.terminal-output .emoji.female-scientist-var-4,.cmd .emoji.female-scientist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f52c.png);}
.terminal-output .emoji.female-astronaut,.cmd .emoji.female-astronaut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f680.png);}
.terminal-output .emoji.female-astronaut-var-0,.cmd .emoji.female-astronaut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f680.png);}
.terminal-output .emoji.female-astronaut-var-1,.cmd .emoji.female-astronaut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f680.png);}
.terminal-output .emoji.female-astronaut-var-2,.cmd .emoji.female-astronaut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f680.png);}
.terminal-output .emoji.female-astronaut-var-3,.cmd .emoji.female-astronaut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f680.png);}
.terminal-output .emoji.female-astronaut-var-4,.cmd .emoji.female-astronaut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f680.png);}
.terminal-output .emoji.female-firefighter,.cmd .emoji.female-firefighter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f692.png);}
.terminal-output .emoji.female-firefighter-var-0,.cmd .emoji.female-firefighter-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f692.png);}
.terminal-output .emoji.female-firefighter-var-1,.cmd .emoji.female-firefighter-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f692.png);}
.terminal-output .emoji.female-firefighter-var-2,.cmd .emoji.female-firefighter-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f692.png);}
.terminal-output .emoji.female-firefighter-var-3,.cmd .emoji.female-firefighter-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f692.png);}
.terminal-output .emoji.female-firefighter-var-4,.cmd .emoji.female-firefighter-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f692.png);}
.terminal-output .emoji.woman_with_probing_cane,.cmd .emoji.woman_with_probing_cane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9af.png);}
.terminal-output .emoji.woman_with_probing_cane-var-0,.cmd .emoji.woman_with_probing_cane-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9af.png);}
.terminal-output .emoji.woman_with_probing_cane-var-1,.cmd .emoji.woman_with_probing_cane-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9af.png);}
.terminal-output .emoji.woman_with_probing_cane-var-2,.cmd .emoji.woman_with_probing_cane-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9af.png);}
.terminal-output .emoji.woman_with_probing_cane-var-3,.cmd .emoji.woman_with_probing_cane-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9af.png);}
.terminal-output .emoji.woman_with_probing_cane-var-4,.cmd .emoji.woman_with_probing_cane-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9af.png);}
.terminal-output .emoji.red_haired_woman,.cmd .emoji.red_haired_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_woman-var-0,.cmd .emoji.red_haired_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_woman-var-1,.cmd .emoji.red_haired_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_woman-var-2,.cmd .emoji.red_haired_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_woman-var-3,.cmd .emoji.red_haired_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_woman-var-4,.cmd .emoji.red_haired_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9b0.png);}
.terminal-output .emoji.curly_haired_woman,.cmd .emoji.curly_haired_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_woman-var-0,.cmd .emoji.curly_haired_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_woman-var-1,.cmd .emoji.curly_haired_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_woman-var-2,.cmd .emoji.curly_haired_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_woman-var-3,.cmd .emoji.curly_haired_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_woman-var-4,.cmd .emoji.curly_haired_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9b1.png);}
.terminal-output .emoji.bald_woman,.cmd .emoji.bald_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9b2.png);}
.terminal-output .emoji.bald_woman-var-0,.cmd .emoji.bald_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9b2.png);}
.terminal-output .emoji.bald_woman-var-1,.cmd .emoji.bald_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9b2.png);}
.terminal-output .emoji.bald_woman-var-2,.cmd .emoji.bald_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9b2.png);}
.terminal-output .emoji.bald_woman-var-3,.cmd .emoji.bald_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9b2.png);}
.terminal-output .emoji.bald_woman-var-4,.cmd .emoji.bald_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9b2.png);}
.terminal-output .emoji.white_haired_woman,.cmd .emoji.white_haired_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_woman-var-0,.cmd .emoji.white_haired_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_woman-var-1,.cmd .emoji.white_haired_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_woman-var-2,.cmd .emoji.white_haired_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_woman-var-3,.cmd .emoji.white_haired_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_woman-var-4,.cmd .emoji.white_haired_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9b3.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair,.cmd .emoji.woman_in_motorized_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair-var-0,.cmd .emoji.woman_in_motorized_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair-var-1,.cmd .emoji.woman_in_motorized_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair-var-2,.cmd .emoji.woman_in_motorized_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair-var-3,.cmd .emoji.woman_in_motorized_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_motorized_wheelchair-var-4,.cmd .emoji.woman_in_motorized_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9bc.png);}
.terminal-output .emoji.woman_in_manual_wheelchair,.cmd .emoji.woman_in_manual_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-1f9bd.png);}
.terminal-output .emoji.woman_in_manual_wheelchair-var-0,.cmd .emoji.woman_in_manual_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f9bd.png);}
.terminal-output .emoji.woman_in_manual_wheelchair-var-1,.cmd .emoji.woman_in_manual_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f9bd.png);}
.terminal-output .emoji.woman_in_manual_wheelchair-var-2,.cmd .emoji.woman_in_manual_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f9bd.png);}
.terminal-output .emoji.woman_in_manual_wheelchair-var-3,.cmd .emoji.woman_in_manual_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f9bd.png);}
.terminal-output .emoji.woman_in_manual_wheelchair-var-4,.cmd .emoji.woman_in_manual_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f9bd.png);}
.terminal-output .emoji.female-doctor,.cmd .emoji.female-doctor{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2695-fe0f.png);}
.terminal-output .emoji.female-doctor-var-0,.cmd .emoji.female-doctor-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2695-fe0f.png);}
.terminal-output .emoji.female-doctor-var-1,.cmd .emoji.female-doctor-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2695-fe0f.png);}
.terminal-output .emoji.female-doctor-var-2,.cmd .emoji.female-doctor-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2695-fe0f.png);}
.terminal-output .emoji.female-doctor-var-3,.cmd .emoji.female-doctor-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2695-fe0f.png);}
.terminal-output .emoji.female-doctor-var-4,.cmd .emoji.female-doctor-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2695-fe0f.png);}
.terminal-output .emoji.female-judge,.cmd .emoji.female-judge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2696-fe0f.png);}
.terminal-output .emoji.female-judge-var-0,.cmd .emoji.female-judge-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2696-fe0f.png);}
.terminal-output .emoji.female-judge-var-1,.cmd .emoji.female-judge-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2696-fe0f.png);}
.terminal-output .emoji.female-judge-var-2,.cmd .emoji.female-judge-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2696-fe0f.png);}
.terminal-output .emoji.female-judge-var-3,.cmd .emoji.female-judge-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2696-fe0f.png);}
.terminal-output .emoji.female-judge-var-4,.cmd .emoji.female-judge-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2696-fe0f.png);}
.terminal-output .emoji.female-pilot,.cmd .emoji.female-pilot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2708-fe0f.png);}
.terminal-output .emoji.female-pilot-var-0,.cmd .emoji.female-pilot-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2708-fe0f.png);}
.terminal-output .emoji.female-pilot-var-1,.cmd .emoji.female-pilot-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2708-fe0f.png);}
.terminal-output .emoji.female-pilot-var-2,.cmd .emoji.female-pilot-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2708-fe0f.png);}
.terminal-output .emoji.female-pilot-var-3,.cmd .emoji.female-pilot-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2708-fe0f.png);}
.terminal-output .emoji.female-pilot-var-4,.cmd .emoji.female-pilot-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2708-fe0f.png);}
.terminal-output .emoji.woman-heart-man,.cmd .emoji.woman-heart-man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2764-fe0f-200d-1f468.png);}
.terminal-output .emoji.woman-heart-man-var-0,.cmd .emoji.woman-heart-man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-heart-man-var-1,.cmd .emoji.woman-heart-man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-heart-man-var-2,.cmd .emoji.woman-heart-man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-heart-man-var-3,.cmd .emoji.woman-heart-man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-heart-man-var-4,.cmd .emoji.woman-heart-man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-heart-man-var-5,.cmd .emoji.woman-heart-man-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-heart-man-var-6,.cmd .emoji.woman-heart-man-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-heart-man-var-7,.cmd .emoji.woman-heart-man-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-heart-man-var-8,.cmd .emoji.woman-heart-man-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-heart-man-var-9,.cmd .emoji.woman-heart-man-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-heart-man-var-10,.cmd .emoji.woman-heart-man-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-heart-man-var-11,.cmd .emoji.woman-heart-man-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-heart-man-var-12,.cmd .emoji.woman-heart-man-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-heart-man-var-13,.cmd .emoji.woman-heart-man-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-heart-man-var-14,.cmd .emoji.woman-heart-man-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-heart-man-var-15,.cmd .emoji.woman-heart-man-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-heart-man-var-16,.cmd .emoji.woman-heart-man-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-heart-man-var-17,.cmd .emoji.woman-heart-man-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-heart-man-var-18,.cmd .emoji.woman-heart-man-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-heart-man-var-19,.cmd .emoji.woman-heart-man-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-heart-man-var-20,.cmd .emoji.woman-heart-man-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-heart-man-var-21,.cmd .emoji.woman-heart-man-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-heart-man-var-22,.cmd .emoji.woman-heart-man-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-heart-man-var-23,.cmd .emoji.woman-heart-man-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-heart-man-var-24,.cmd .emoji.woman-heart-man-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-heart-woman,.cmd .emoji.woman-heart-woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2764-fe0f-200d-1f469.png);}
.terminal-output .emoji.woman-heart-woman-var-0,.cmd .emoji.woman-heart-woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-heart-woman-var-1,.cmd .emoji.woman-heart-woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-heart-woman-var-2,.cmd .emoji.woman-heart-woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-heart-woman-var-3,.cmd .emoji.woman-heart-woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-heart-woman-var-4,.cmd .emoji.woman-heart-woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-heart-woman-var-5,.cmd .emoji.woman-heart-woman-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-heart-woman-var-6,.cmd .emoji.woman-heart-woman-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-heart-woman-var-7,.cmd .emoji.woman-heart-woman-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-heart-woman-var-8,.cmd .emoji.woman-heart-woman-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-heart-woman-var-9,.cmd .emoji.woman-heart-woman-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-heart-woman-var-10,.cmd .emoji.woman-heart-woman-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-heart-woman-var-11,.cmd .emoji.woman-heart-woman-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-heart-woman-var-12,.cmd .emoji.woman-heart-woman-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-heart-woman-var-13,.cmd .emoji.woman-heart-woman-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-heart-woman-var-14,.cmd .emoji.woman-heart-woman-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-heart-woman-var-15,.cmd .emoji.woman-heart-woman-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-heart-woman-var-16,.cmd .emoji.woman-heart-woman-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-heart-woman-var-17,.cmd .emoji.woman-heart-woman-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-heart-woman-var-18,.cmd .emoji.woman-heart-woman-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-heart-woman-var-19,.cmd .emoji.woman-heart-woman-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-heart-woman-var-20,.cmd .emoji.woman-heart-woman-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-heart-woman-var-21,.cmd .emoji.woman-heart-woman-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-heart-woman-var-22,.cmd .emoji.woman-heart-woman-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-heart-woman-var-23,.cmd .emoji.woman-heart-woman-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-heart-woman-var-24,.cmd .emoji.woman-heart-woman-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-kiss-man,.cmd .emoji.woman-kiss-man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2764-fe0f-200d-1f48b-200d-1f468.png);}
.terminal-output .emoji.woman-kiss-man-var-0,.cmd .emoji.woman-kiss-man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-kiss-man-var-1,.cmd .emoji.woman-kiss-man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-kiss-man-var-2,.cmd .emoji.woman-kiss-man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-kiss-man-var-3,.cmd .emoji.woman-kiss-man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-kiss-man-var-4,.cmd .emoji.woman-kiss-man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-kiss-man-var-5,.cmd .emoji.woman-kiss-man-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-kiss-man-var-6,.cmd .emoji.woman-kiss-man-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-kiss-man-var-7,.cmd .emoji.woman-kiss-man-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-kiss-man-var-8,.cmd .emoji.woman-kiss-man-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-kiss-man-var-9,.cmd .emoji.woman-kiss-man-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-kiss-man-var-10,.cmd .emoji.woman-kiss-man-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-kiss-man-var-11,.cmd .emoji.woman-kiss-man-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-kiss-man-var-12,.cmd .emoji.woman-kiss-man-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-kiss-man-var-13,.cmd .emoji.woman-kiss-man-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-kiss-man-var-14,.cmd .emoji.woman-kiss-man-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-kiss-man-var-15,.cmd .emoji.woman-kiss-man-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-kiss-man-var-16,.cmd .emoji.woman-kiss-man-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-kiss-man-var-17,.cmd .emoji.woman-kiss-man-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-kiss-man-var-18,.cmd .emoji.woman-kiss-man-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-kiss-man-var-19,.cmd .emoji.woman-kiss-man-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-kiss-man-var-20,.cmd .emoji.woman-kiss-man-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fb.png);}
.terminal-output .emoji.woman-kiss-man-var-21,.cmd .emoji.woman-kiss-man-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fc.png);}
.terminal-output .emoji.woman-kiss-man-var-22,.cmd .emoji.woman-kiss-man-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fd.png);}
.terminal-output .emoji.woman-kiss-man-var-23,.cmd .emoji.woman-kiss-man-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3fe.png);}
.terminal-output .emoji.woman-kiss-man-var-24,.cmd .emoji.woman-kiss-man-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f468-1f3ff.png);}
.terminal-output .emoji.woman-kiss-woman,.cmd .emoji.woman-kiss-woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-200d-2764-fe0f-200d-1f48b-200d-1f469.png);}
.terminal-output .emoji.woman-kiss-woman-var-0,.cmd .emoji.woman-kiss-woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-kiss-woman-var-1,.cmd .emoji.woman-kiss-woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-kiss-woman-var-2,.cmd .emoji.woman-kiss-woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-kiss-woman-var-3,.cmd .emoji.woman-kiss-woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-kiss-woman-var-4,.cmd .emoji.woman-kiss-woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-kiss-woman-var-5,.cmd .emoji.woman-kiss-woman-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-kiss-woman-var-6,.cmd .emoji.woman-kiss-woman-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-kiss-woman-var-7,.cmd .emoji.woman-kiss-woman-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-kiss-woman-var-8,.cmd .emoji.woman-kiss-woman-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-kiss-woman-var-9,.cmd .emoji.woman-kiss-woman-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-kiss-woman-var-10,.cmd .emoji.woman-kiss-woman-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-kiss-woman-var-11,.cmd .emoji.woman-kiss-woman-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-kiss-woman-var-12,.cmd .emoji.woman-kiss-woman-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-kiss-woman-var-13,.cmd .emoji.woman-kiss-woman-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-kiss-woman-var-14,.cmd .emoji.woman-kiss-woman-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-kiss-woman-var-15,.cmd .emoji.woman-kiss-woman-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-kiss-woman-var-16,.cmd .emoji.woman-kiss-woman-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-kiss-woman-var-17,.cmd .emoji.woman-kiss-woman-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-kiss-woman-var-18,.cmd .emoji.woman-kiss-woman-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-kiss-woman-var-19,.cmd .emoji.woman-kiss-woman-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman-kiss-woman-var-20,.cmd .emoji.woman-kiss-woman-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fb.png);}
.terminal-output .emoji.woman-kiss-woman-var-21,.cmd .emoji.woman-kiss-woman-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fc.png);}
.terminal-output .emoji.woman-kiss-woman-var-22,.cmd .emoji.woman-kiss-woman-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fd.png);}
.terminal-output .emoji.woman-kiss-woman-var-23,.cmd .emoji.woman-kiss-woman-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3fe.png);}
.terminal-output .emoji.woman-kiss-woman-var-24,.cmd .emoji.woman-kiss-woman-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f469-1f3ff.png);}
.terminal-output .emoji.woman,.cmd .emoji.woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469.png);}
.terminal-output .emoji.woman-var-0,.cmd .emoji.woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb.png);}
.terminal-output .emoji.woman-var-1,.cmd .emoji.woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc.png);}
.terminal-output .emoji.woman-var-2,.cmd .emoji.woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd.png);}
.terminal-output .emoji.woman-var-3,.cmd .emoji.woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe.png);}
.terminal-output .emoji.woman-var-4,.cmd .emoji.woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff.png);}
.terminal-output .emoji.family,.cmd .emoji.family{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46a.png);}
.terminal-output .emoji.man_and_woman_holding_hands,.cmd .emoji.man_and_woman_holding_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-0,.cmd .emoji.man_and_woman_holding_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b-1f3fb.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-1,.cmd .emoji.man_and_woman_holding_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b-1f3fc.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-2,.cmd .emoji.man_and_woman_holding_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b-1f3fd.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-3,.cmd .emoji.man_and_woman_holding_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b-1f3fe.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-4,.cmd .emoji.man_and_woman_holding_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46b-1f3ff.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-5,.cmd .emoji.man_and_woman_holding_hands-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-6,.cmd .emoji.man_and_woman_holding_hands-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-7,.cmd .emoji.man_and_woman_holding_hands-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-8,.cmd .emoji.man_and_woman_holding_hands-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-9,.cmd .emoji.man_and_woman_holding_hands-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-10,.cmd .emoji.man_and_woman_holding_hands-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-11,.cmd .emoji.man_and_woman_holding_hands-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-12,.cmd .emoji.man_and_woman_holding_hands-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-13,.cmd .emoji.man_and_woman_holding_hands-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-14,.cmd .emoji.man_and_woman_holding_hands-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-15,.cmd .emoji.man_and_woman_holding_hands-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-16,.cmd .emoji.man_and_woman_holding_hands-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-17,.cmd .emoji.man_and_woman_holding_hands-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-18,.cmd .emoji.man_and_woman_holding_hands-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-19,.cmd .emoji.man_and_woman_holding_hands-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-20,.cmd .emoji.man_and_woman_holding_hands-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-21,.cmd .emoji.man_and_woman_holding_hands-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-22,.cmd .emoji.man_and_woman_holding_hands-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-23,.cmd .emoji.man_and_woman_holding_hands-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.man_and_woman_holding_hands-var-24,.cmd .emoji.man_and_woman_holding_hands-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.two_men_holding_hands,.cmd .emoji.two_men_holding_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c.png);}
.terminal-output .emoji.two_men_holding_hands-var-0,.cmd .emoji.two_men_holding_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c-1f3fb.png);}
.terminal-output .emoji.two_men_holding_hands-var-1,.cmd .emoji.two_men_holding_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c-1f3fc.png);}
.terminal-output .emoji.two_men_holding_hands-var-2,.cmd .emoji.two_men_holding_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c-1f3fd.png);}
.terminal-output .emoji.two_men_holding_hands-var-3,.cmd .emoji.two_men_holding_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c-1f3fe.png);}
.terminal-output .emoji.two_men_holding_hands-var-4,.cmd .emoji.two_men_holding_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46c-1f3ff.png);}
.terminal-output .emoji.two_men_holding_hands-var-5,.cmd .emoji.two_men_holding_hands-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.two_men_holding_hands-var-6,.cmd .emoji.two_men_holding_hands-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.two_men_holding_hands-var-7,.cmd .emoji.two_men_holding_hands-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.two_men_holding_hands-var-8,.cmd .emoji.two_men_holding_hands-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fb-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.two_men_holding_hands-var-9,.cmd .emoji.two_men_holding_hands-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.two_men_holding_hands-var-10,.cmd .emoji.two_men_holding_hands-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.two_men_holding_hands-var-11,.cmd .emoji.two_men_holding_hands-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.two_men_holding_hands-var-12,.cmd .emoji.two_men_holding_hands-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fc-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.two_men_holding_hands-var-13,.cmd .emoji.two_men_holding_hands-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.two_men_holding_hands-var-14,.cmd .emoji.two_men_holding_hands-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.two_men_holding_hands-var-15,.cmd .emoji.two_men_holding_hands-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.two_men_holding_hands-var-16,.cmd .emoji.two_men_holding_hands-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fd-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.two_men_holding_hands-var-17,.cmd .emoji.two_men_holding_hands-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.two_men_holding_hands-var-18,.cmd .emoji.two_men_holding_hands-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.two_men_holding_hands-var-19,.cmd .emoji.two_men_holding_hands-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.two_men_holding_hands-var-20,.cmd .emoji.two_men_holding_hands-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3fe-200d-1f91d-200d-1f468-1f3ff.png);}
.terminal-output .emoji.two_men_holding_hands-var-21,.cmd .emoji.two_men_holding_hands-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f91d-200d-1f468-1f3fb.png);}
.terminal-output .emoji.two_men_holding_hands-var-22,.cmd .emoji.two_men_holding_hands-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f91d-200d-1f468-1f3fc.png);}
.terminal-output .emoji.two_men_holding_hands-var-23,.cmd .emoji.two_men_holding_hands-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f91d-200d-1f468-1f3fd.png);}
.terminal-output .emoji.two_men_holding_hands-var-24,.cmd .emoji.two_men_holding_hands-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f468-1f3ff-200d-1f91d-200d-1f468-1f3fe.png);}
.terminal-output .emoji.two_women_holding_hands,.cmd .emoji.two_women_holding_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d.png);}
.terminal-output .emoji.two_women_holding_hands-var-0,.cmd .emoji.two_women_holding_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d-1f3fb.png);}
.terminal-output .emoji.two_women_holding_hands-var-1,.cmd .emoji.two_women_holding_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d-1f3fc.png);}
.terminal-output .emoji.two_women_holding_hands-var-2,.cmd .emoji.two_women_holding_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d-1f3fd.png);}
.terminal-output .emoji.two_women_holding_hands-var-3,.cmd .emoji.two_women_holding_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d-1f3fe.png);}
.terminal-output .emoji.two_women_holding_hands-var-4,.cmd .emoji.two_women_holding_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46d-1f3ff.png);}
.terminal-output .emoji.two_women_holding_hands-var-5,.cmd .emoji.two_women_holding_hands-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f469-1f3fc.png);}
.terminal-output .emoji.two_women_holding_hands-var-6,.cmd .emoji.two_women_holding_hands-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f469-1f3fd.png);}
.terminal-output .emoji.two_women_holding_hands-var-7,.cmd .emoji.two_women_holding_hands-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f469-1f3fe.png);}
.terminal-output .emoji.two_women_holding_hands-var-8,.cmd .emoji.two_women_holding_hands-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fb-200d-1f91d-200d-1f469-1f3ff.png);}
.terminal-output .emoji.two_women_holding_hands-var-9,.cmd .emoji.two_women_holding_hands-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f469-1f3fb.png);}
.terminal-output .emoji.two_women_holding_hands-var-10,.cmd .emoji.two_women_holding_hands-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f469-1f3fd.png);}
.terminal-output .emoji.two_women_holding_hands-var-11,.cmd .emoji.two_women_holding_hands-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f469-1f3fe.png);}
.terminal-output .emoji.two_women_holding_hands-var-12,.cmd .emoji.two_women_holding_hands-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fc-200d-1f91d-200d-1f469-1f3ff.png);}
.terminal-output .emoji.two_women_holding_hands-var-13,.cmd .emoji.two_women_holding_hands-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f469-1f3fb.png);}
.terminal-output .emoji.two_women_holding_hands-var-14,.cmd .emoji.two_women_holding_hands-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f469-1f3fc.png);}
.terminal-output .emoji.two_women_holding_hands-var-15,.cmd .emoji.two_women_holding_hands-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f469-1f3fe.png);}
.terminal-output .emoji.two_women_holding_hands-var-16,.cmd .emoji.two_women_holding_hands-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fd-200d-1f91d-200d-1f469-1f3ff.png);}
.terminal-output .emoji.two_women_holding_hands-var-17,.cmd .emoji.two_women_holding_hands-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f469-1f3fb.png);}
.terminal-output .emoji.two_women_holding_hands-var-18,.cmd .emoji.two_women_holding_hands-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f469-1f3fc.png);}
.terminal-output .emoji.two_women_holding_hands-var-19,.cmd .emoji.two_women_holding_hands-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f469-1f3fd.png);}
.terminal-output .emoji.two_women_holding_hands-var-20,.cmd .emoji.two_women_holding_hands-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3fe-200d-1f91d-200d-1f469-1f3ff.png);}
.terminal-output .emoji.two_women_holding_hands-var-21,.cmd .emoji.two_women_holding_hands-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f469-1f3fb.png);}
.terminal-output .emoji.two_women_holding_hands-var-22,.cmd .emoji.two_women_holding_hands-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f469-1f3fc.png);}
.terminal-output .emoji.two_women_holding_hands-var-23,.cmd .emoji.two_women_holding_hands-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f469-1f3fd.png);}
.terminal-output .emoji.two_women_holding_hands-var-24,.cmd .emoji.two_women_holding_hands-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f469-1f3ff-200d-1f91d-200d-1f469-1f3fe.png);}
.terminal-output .emoji.female-police-officer,.cmd .emoji.female-police-officer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-200d-2640-fe0f.png);}
.terminal-output .emoji.female-police-officer-var-0,.cmd .emoji.female-police-officer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female-police-officer-var-1,.cmd .emoji.female-police-officer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female-police-officer-var-2,.cmd .emoji.female-police-officer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female-police-officer-var-3,.cmd .emoji.female-police-officer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female-police-officer-var-4,.cmd .emoji.female-police-officer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male-police-officer,.cmd .emoji.male-police-officer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-200d-2642-fe0f.png);}
.terminal-output .emoji.male-police-officer-var-0,.cmd .emoji.male-police-officer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male-police-officer-var-1,.cmd .emoji.male-police-officer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male-police-officer-var-2,.cmd .emoji.male-police-officer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male-police-officer-var-3,.cmd .emoji.male-police-officer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male-police-officer-var-4,.cmd .emoji.male-police-officer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.cop,.cmd .emoji.cop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e.png);}
.terminal-output .emoji.cop-var-0,.cmd .emoji.cop-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fb.png);}
.terminal-output .emoji.cop-var-1,.cmd .emoji.cop-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fc.png);}
.terminal-output .emoji.cop-var-2,.cmd .emoji.cop-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fd.png);}
.terminal-output .emoji.cop-var-3,.cmd .emoji.cop-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3fe.png);}
.terminal-output .emoji.cop-var-4,.cmd .emoji.cop-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46e-1f3ff.png);}
.terminal-output .emoji.women-with-bunny-ears-partying,.cmd .emoji.women-with-bunny-ears-partying{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46f-200d-2640-fe0f.png);}
.terminal-output .emoji.men-with-bunny-ears-partying,.cmd .emoji.men-with-bunny-ears-partying{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46f-200d-2642-fe0f.png);}
.terminal-output .emoji.dancers,.cmd .emoji.dancers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f46f.png);}
.terminal-output .emoji.woman_with_veil,.cmd .emoji.woman_with_veil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_veil-var-0,.cmd .emoji.woman_with_veil-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_veil-var-1,.cmd .emoji.woman_with_veil-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_veil-var-2,.cmd .emoji.woman_with_veil-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_veil-var-3,.cmd .emoji.woman_with_veil-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_veil-var-4,.cmd .emoji.woman_with_veil-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_with_veil,.cmd .emoji.man_with_veil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_veil-var-0,.cmd .emoji.man_with_veil-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_veil-var-1,.cmd .emoji.man_with_veil-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_veil-var-2,.cmd .emoji.man_with_veil-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_veil-var-3,.cmd .emoji.man_with_veil-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_veil-var-4,.cmd .emoji.man_with_veil-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.bride_with_veil,.cmd .emoji.bride_with_veil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470.png);}
.terminal-output .emoji.bride_with_veil-var-0,.cmd .emoji.bride_with_veil-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fb.png);}
.terminal-output .emoji.bride_with_veil-var-1,.cmd .emoji.bride_with_veil-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fc.png);}
.terminal-output .emoji.bride_with_veil-var-2,.cmd .emoji.bride_with_veil-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fd.png);}
.terminal-output .emoji.bride_with_veil-var-3,.cmd .emoji.bride_with_veil-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3fe.png);}
.terminal-output .emoji.bride_with_veil-var-4,.cmd .emoji.bride_with_veil-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f470-1f3ff.png);}
.terminal-output .emoji.blond-haired-woman,.cmd .emoji.blond-haired-woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-woman-var-0,.cmd .emoji.blond-haired-woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-woman-var-1,.cmd .emoji.blond-haired-woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-woman-var-2,.cmd .emoji.blond-haired-woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-woman-var-3,.cmd .emoji.blond-haired-woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-woman-var-4,.cmd .emoji.blond-haired-woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.blond-haired-man,.cmd .emoji.blond-haired-man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-200d-2642-fe0f.png);}
.terminal-output .emoji.blond-haired-man-var-0,.cmd .emoji.blond-haired-man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.blond-haired-man-var-1,.cmd .emoji.blond-haired-man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.blond-haired-man-var-2,.cmd .emoji.blond-haired-man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.blond-haired-man-var-3,.cmd .emoji.blond-haired-man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.blond-haired-man-var-4,.cmd .emoji.blond-haired-man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_with_blond_hair,.cmd .emoji.person_with_blond_hair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471.png);}
.terminal-output .emoji.person_with_blond_hair-var-0,.cmd .emoji.person_with_blond_hair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fb.png);}
.terminal-output .emoji.person_with_blond_hair-var-1,.cmd .emoji.person_with_blond_hair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fc.png);}
.terminal-output .emoji.person_with_blond_hair-var-2,.cmd .emoji.person_with_blond_hair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fd.png);}
.terminal-output .emoji.person_with_blond_hair-var-3,.cmd .emoji.person_with_blond_hair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3fe.png);}
.terminal-output .emoji.person_with_blond_hair-var-4,.cmd .emoji.person_with_blond_hair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f471-1f3ff.png);}
.terminal-output .emoji.man_with_gua_pi_mao,.cmd .emoji.man_with_gua_pi_mao{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472.png);}
.terminal-output .emoji.man_with_gua_pi_mao-var-0,.cmd .emoji.man_with_gua_pi_mao-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472-1f3fb.png);}
.terminal-output .emoji.man_with_gua_pi_mao-var-1,.cmd .emoji.man_with_gua_pi_mao-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472-1f3fc.png);}
.terminal-output .emoji.man_with_gua_pi_mao-var-2,.cmd .emoji.man_with_gua_pi_mao-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472-1f3fd.png);}
.terminal-output .emoji.man_with_gua_pi_mao-var-3,.cmd .emoji.man_with_gua_pi_mao-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472-1f3fe.png);}
.terminal-output .emoji.man_with_gua_pi_mao-var-4,.cmd .emoji.man_with_gua_pi_mao-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f472-1f3ff.png);}
.terminal-output .emoji.woman-wearing-turban,.cmd .emoji.woman-wearing-turban{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-wearing-turban-var-0,.cmd .emoji.woman-wearing-turban-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-wearing-turban-var-1,.cmd .emoji.woman-wearing-turban-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-wearing-turban-var-2,.cmd .emoji.woman-wearing-turban-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-wearing-turban-var-3,.cmd .emoji.woman-wearing-turban-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-wearing-turban-var-4,.cmd .emoji.woman-wearing-turban-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-wearing-turban,.cmd .emoji.man-wearing-turban{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-200d-2642-fe0f.png);}
.terminal-output .emoji.man-wearing-turban-var-0,.cmd .emoji.man-wearing-turban-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-wearing-turban-var-1,.cmd .emoji.man-wearing-turban-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-wearing-turban-var-2,.cmd .emoji.man-wearing-turban-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-wearing-turban-var-3,.cmd .emoji.man-wearing-turban-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-wearing-turban-var-4,.cmd .emoji.man-wearing-turban-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_turban,.cmd .emoji.man_with_turban{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473.png);}
.terminal-output .emoji.man_with_turban-var-0,.cmd .emoji.man_with_turban-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fb.png);}
.terminal-output .emoji.man_with_turban-var-1,.cmd .emoji.man_with_turban-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fc.png);}
.terminal-output .emoji.man_with_turban-var-2,.cmd .emoji.man_with_turban-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fd.png);}
.terminal-output .emoji.man_with_turban-var-3,.cmd .emoji.man_with_turban-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3fe.png);}
.terminal-output .emoji.man_with_turban-var-4,.cmd .emoji.man_with_turban-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f473-1f3ff.png);}
.terminal-output .emoji.older_man,.cmd .emoji.older_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474.png);}
.terminal-output .emoji.older_man-var-0,.cmd .emoji.older_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474-1f3fb.png);}
.terminal-output .emoji.older_man-var-1,.cmd .emoji.older_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474-1f3fc.png);}
.terminal-output .emoji.older_man-var-2,.cmd .emoji.older_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474-1f3fd.png);}
.terminal-output .emoji.older_man-var-3,.cmd .emoji.older_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474-1f3fe.png);}
.terminal-output .emoji.older_man-var-4,.cmd .emoji.older_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f474-1f3ff.png);}
.terminal-output .emoji.older_woman,.cmd .emoji.older_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475.png);}
.terminal-output .emoji.older_woman-var-0,.cmd .emoji.older_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475-1f3fb.png);}
.terminal-output .emoji.older_woman-var-1,.cmd .emoji.older_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475-1f3fc.png);}
.terminal-output .emoji.older_woman-var-2,.cmd .emoji.older_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475-1f3fd.png);}
.terminal-output .emoji.older_woman-var-3,.cmd .emoji.older_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475-1f3fe.png);}
.terminal-output .emoji.older_woman-var-4,.cmd .emoji.older_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f475-1f3ff.png);}
.terminal-output .emoji.baby,.cmd .emoji.baby{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476.png);}
.terminal-output .emoji.baby-var-0,.cmd .emoji.baby-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476-1f3fb.png);}
.terminal-output .emoji.baby-var-1,.cmd .emoji.baby-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476-1f3fc.png);}
.terminal-output .emoji.baby-var-2,.cmd .emoji.baby-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476-1f3fd.png);}
.terminal-output .emoji.baby-var-3,.cmd .emoji.baby-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476-1f3fe.png);}
.terminal-output .emoji.baby-var-4,.cmd .emoji.baby-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f476-1f3ff.png);}
.terminal-output .emoji.female-construction-worker,.cmd .emoji.female-construction-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-200d-2640-fe0f.png);}
.terminal-output .emoji.female-construction-worker-var-0,.cmd .emoji.female-construction-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female-construction-worker-var-1,.cmd .emoji.female-construction-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female-construction-worker-var-2,.cmd .emoji.female-construction-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female-construction-worker-var-3,.cmd .emoji.female-construction-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female-construction-worker-var-4,.cmd .emoji.female-construction-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male-construction-worker,.cmd .emoji.male-construction-worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-200d-2642-fe0f.png);}
.terminal-output .emoji.male-construction-worker-var-0,.cmd .emoji.male-construction-worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male-construction-worker-var-1,.cmd .emoji.male-construction-worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male-construction-worker-var-2,.cmd .emoji.male-construction-worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male-construction-worker-var-3,.cmd .emoji.male-construction-worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male-construction-worker-var-4,.cmd .emoji.male-construction-worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.construction_worker,.cmd .emoji.construction_worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477.png);}
.terminal-output .emoji.construction_worker-var-0,.cmd .emoji.construction_worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fb.png);}
.terminal-output .emoji.construction_worker-var-1,.cmd .emoji.construction_worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fc.png);}
.terminal-output .emoji.construction_worker-var-2,.cmd .emoji.construction_worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fd.png);}
.terminal-output .emoji.construction_worker-var-3,.cmd .emoji.construction_worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3fe.png);}
.terminal-output .emoji.construction_worker-var-4,.cmd .emoji.construction_worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f477-1f3ff.png);}
.terminal-output .emoji.princess,.cmd .emoji.princess{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478.png);}
.terminal-output .emoji.princess-var-0,.cmd .emoji.princess-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478-1f3fb.png);}
.terminal-output .emoji.princess-var-1,.cmd .emoji.princess-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478-1f3fc.png);}
.terminal-output .emoji.princess-var-2,.cmd .emoji.princess-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478-1f3fd.png);}
.terminal-output .emoji.princess-var-3,.cmd .emoji.princess-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478-1f3fe.png);}
.terminal-output .emoji.princess-var-4,.cmd .emoji.princess-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f478-1f3ff.png);}
.terminal-output .emoji.japanese_ogre,.cmd .emoji.japanese_ogre{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f479.png);}
.terminal-output .emoji.japanese_goblin,.cmd .emoji.japanese_goblin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47a.png);}
.terminal-output .emoji.ghost,.cmd .emoji.ghost{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47b.png);}
.terminal-output .emoji.angel,.cmd .emoji.angel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c.png);}
.terminal-output .emoji.angel-var-0,.cmd .emoji.angel-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c-1f3fb.png);}
.terminal-output .emoji.angel-var-1,.cmd .emoji.angel-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c-1f3fc.png);}
.terminal-output .emoji.angel-var-2,.cmd .emoji.angel-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c-1f3fd.png);}
.terminal-output .emoji.angel-var-3,.cmd .emoji.angel-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c-1f3fe.png);}
.terminal-output .emoji.angel-var-4,.cmd .emoji.angel-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47c-1f3ff.png);}
.terminal-output .emoji.alien,.cmd .emoji.alien{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47d.png);}
.terminal-output .emoji.space_invader,.cmd .emoji.space_invader{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47e.png);}
.terminal-output .emoji.imp,.cmd .emoji.imp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f47f.png);}
.terminal-output .emoji.skull,.cmd .emoji.skull{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f480.png);}
.terminal-output .emoji.woman-tipping-hand,.cmd .emoji.woman-tipping-hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-tipping-hand-var-0,.cmd .emoji.woman-tipping-hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-tipping-hand-var-1,.cmd .emoji.woman-tipping-hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-tipping-hand-var-2,.cmd .emoji.woman-tipping-hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-tipping-hand-var-3,.cmd .emoji.woman-tipping-hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-tipping-hand-var-4,.cmd .emoji.woman-tipping-hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-tipping-hand,.cmd .emoji.man-tipping-hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-200d-2642-fe0f.png);}
.terminal-output .emoji.man-tipping-hand-var-0,.cmd .emoji.man-tipping-hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-tipping-hand-var-1,.cmd .emoji.man-tipping-hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-tipping-hand-var-2,.cmd .emoji.man-tipping-hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-tipping-hand-var-3,.cmd .emoji.man-tipping-hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-tipping-hand-var-4,.cmd .emoji.man-tipping-hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.information_desk_person,.cmd .emoji.information_desk_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481.png);}
.terminal-output .emoji.information_desk_person-var-0,.cmd .emoji.information_desk_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fb.png);}
.terminal-output .emoji.information_desk_person-var-1,.cmd .emoji.information_desk_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fc.png);}
.terminal-output .emoji.information_desk_person-var-2,.cmd .emoji.information_desk_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fd.png);}
.terminal-output .emoji.information_desk_person-var-3,.cmd .emoji.information_desk_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3fe.png);}
.terminal-output .emoji.information_desk_person-var-4,.cmd .emoji.information_desk_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f481-1f3ff.png);}
.terminal-output .emoji.female-guard,.cmd .emoji.female-guard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-200d-2640-fe0f.png);}
.terminal-output .emoji.female-guard-var-0,.cmd .emoji.female-guard-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female-guard-var-1,.cmd .emoji.female-guard-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female-guard-var-2,.cmd .emoji.female-guard-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female-guard-var-3,.cmd .emoji.female-guard-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female-guard-var-4,.cmd .emoji.female-guard-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male-guard,.cmd .emoji.male-guard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-200d-2642-fe0f.png);}
.terminal-output .emoji.male-guard-var-0,.cmd .emoji.male-guard-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male-guard-var-1,.cmd .emoji.male-guard-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male-guard-var-2,.cmd .emoji.male-guard-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male-guard-var-3,.cmd .emoji.male-guard-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male-guard-var-4,.cmd .emoji.male-guard-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.guardsman,.cmd .emoji.guardsman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482.png);}
.terminal-output .emoji.guardsman-var-0,.cmd .emoji.guardsman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fb.png);}
.terminal-output .emoji.guardsman-var-1,.cmd .emoji.guardsman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fc.png);}
.terminal-output .emoji.guardsman-var-2,.cmd .emoji.guardsman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fd.png);}
.terminal-output .emoji.guardsman-var-3,.cmd .emoji.guardsman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3fe.png);}
.terminal-output .emoji.guardsman-var-4,.cmd .emoji.guardsman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f482-1f3ff.png);}
.terminal-output .emoji.dancer,.cmd .emoji.dancer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483.png);}
.terminal-output .emoji.dancer-var-0,.cmd .emoji.dancer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483-1f3fb.png);}
.terminal-output .emoji.dancer-var-1,.cmd .emoji.dancer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483-1f3fc.png);}
.terminal-output .emoji.dancer-var-2,.cmd .emoji.dancer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483-1f3fd.png);}
.terminal-output .emoji.dancer-var-3,.cmd .emoji.dancer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483-1f3fe.png);}
.terminal-output .emoji.dancer-var-4,.cmd .emoji.dancer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f483-1f3ff.png);}
.terminal-output .emoji.lipstick,.cmd .emoji.lipstick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f484.png);}
.terminal-output .emoji.nail_care,.cmd .emoji.nail_care{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485.png);}
.terminal-output .emoji.nail_care-var-0,.cmd .emoji.nail_care-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485-1f3fb.png);}
.terminal-output .emoji.nail_care-var-1,.cmd .emoji.nail_care-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485-1f3fc.png);}
.terminal-output .emoji.nail_care-var-2,.cmd .emoji.nail_care-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485-1f3fd.png);}
.terminal-output .emoji.nail_care-var-3,.cmd .emoji.nail_care-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485-1f3fe.png);}
.terminal-output .emoji.nail_care-var-4,.cmd .emoji.nail_care-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f485-1f3ff.png);}
.terminal-output .emoji.woman-getting-massage,.cmd .emoji.woman-getting-massage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-massage-var-0,.cmd .emoji.woman-getting-massage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-massage-var-1,.cmd .emoji.woman-getting-massage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-massage-var-2,.cmd .emoji.woman-getting-massage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-massage-var-3,.cmd .emoji.woman-getting-massage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-massage-var-4,.cmd .emoji.woman-getting-massage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-getting-massage,.cmd .emoji.man-getting-massage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-massage-var-0,.cmd .emoji.man-getting-massage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-massage-var-1,.cmd .emoji.man-getting-massage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-massage-var-2,.cmd .emoji.man-getting-massage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-massage-var-3,.cmd .emoji.man-getting-massage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-massage-var-4,.cmd .emoji.man-getting-massage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.massage,.cmd .emoji.massage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486.png);}
.terminal-output .emoji.massage-var-0,.cmd .emoji.massage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fb.png);}
.terminal-output .emoji.massage-var-1,.cmd .emoji.massage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fc.png);}
.terminal-output .emoji.massage-var-2,.cmd .emoji.massage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fd.png);}
.terminal-output .emoji.massage-var-3,.cmd .emoji.massage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3fe.png);}
.terminal-output .emoji.massage-var-4,.cmd .emoji.massage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f486-1f3ff.png);}
.terminal-output .emoji.woman-getting-haircut,.cmd .emoji.woman-getting-haircut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-haircut-var-0,.cmd .emoji.woman-getting-haircut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-haircut-var-1,.cmd .emoji.woman-getting-haircut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-haircut-var-2,.cmd .emoji.woman-getting-haircut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-haircut-var-3,.cmd .emoji.woman-getting-haircut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-getting-haircut-var-4,.cmd .emoji.woman-getting-haircut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-getting-haircut,.cmd .emoji.man-getting-haircut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-haircut-var-0,.cmd .emoji.man-getting-haircut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-haircut-var-1,.cmd .emoji.man-getting-haircut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-haircut-var-2,.cmd .emoji.man-getting-haircut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-haircut-var-3,.cmd .emoji.man-getting-haircut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-getting-haircut-var-4,.cmd .emoji.man-getting-haircut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.haircut,.cmd .emoji.haircut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487.png);}
.terminal-output .emoji.haircut-var-0,.cmd .emoji.haircut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fb.png);}
.terminal-output .emoji.haircut-var-1,.cmd .emoji.haircut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fc.png);}
.terminal-output .emoji.haircut-var-2,.cmd .emoji.haircut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fd.png);}
.terminal-output .emoji.haircut-var-3,.cmd .emoji.haircut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3fe.png);}
.terminal-output .emoji.haircut-var-4,.cmd .emoji.haircut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f487-1f3ff.png);}
.terminal-output .emoji.barber,.cmd .emoji.barber{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f488.png);}
.terminal-output .emoji.syringe,.cmd .emoji.syringe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f489.png);}
.terminal-output .emoji.pill,.cmd .emoji.pill{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48a.png);}
.terminal-output .emoji.kiss,.cmd .emoji.kiss{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48b.png);}
.terminal-output .emoji.love_letter,.cmd .emoji.love_letter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48c.png);}
.terminal-output .emoji.ring,.cmd .emoji.ring{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48d.png);}
.terminal-output .emoji.gem,.cmd .emoji.gem{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48e.png);}
.terminal-output .emoji.couplekiss,.cmd .emoji.couplekiss{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f.png);}
.terminal-output .emoji.couplekiss-var-0,.cmd .emoji.couplekiss-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f-1f3fb.png);}
.terminal-output .emoji.couplekiss-var-1,.cmd .emoji.couplekiss-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f-1f3fc.png);}
.terminal-output .emoji.couplekiss-var-2,.cmd .emoji.couplekiss-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f-1f3fd.png);}
.terminal-output .emoji.couplekiss-var-3,.cmd .emoji.couplekiss-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f-1f3fe.png);}
.terminal-output .emoji.couplekiss-var-4,.cmd .emoji.couplekiss-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f48f-1f3ff.png);}
.terminal-output .emoji.couplekiss-var-5,.cmd .emoji.couplekiss-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couplekiss-var-6,.cmd .emoji.couplekiss-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couplekiss-var-7,.cmd .emoji.couplekiss-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couplekiss-var-8,.cmd .emoji.couplekiss-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couplekiss-var-9,.cmd .emoji.couplekiss-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couplekiss-var-10,.cmd .emoji.couplekiss-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couplekiss-var-11,.cmd .emoji.couplekiss-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couplekiss-var-12,.cmd .emoji.couplekiss-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couplekiss-var-13,.cmd .emoji.couplekiss-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couplekiss-var-14,.cmd .emoji.couplekiss-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couplekiss-var-15,.cmd .emoji.couplekiss-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couplekiss-var-16,.cmd .emoji.couplekiss-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couplekiss-var-17,.cmd .emoji.couplekiss-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couplekiss-var-18,.cmd .emoji.couplekiss-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couplekiss-var-19,.cmd .emoji.couplekiss-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couplekiss-var-20,.cmd .emoji.couplekiss-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couplekiss-var-21,.cmd .emoji.couplekiss-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couplekiss-var-22,.cmd .emoji.couplekiss-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couplekiss-var-23,.cmd .emoji.couplekiss-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couplekiss-var-24,.cmd .emoji.couplekiss-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f48b-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.bouquet,.cmd .emoji.bouquet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f490.png);}
.terminal-output .emoji.couple_with_heart,.cmd .emoji.couple_with_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491.png);}
.terminal-output .emoji.couple_with_heart-var-0,.cmd .emoji.couple_with_heart-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491-1f3fb.png);}
.terminal-output .emoji.couple_with_heart-var-1,.cmd .emoji.couple_with_heart-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491-1f3fc.png);}
.terminal-output .emoji.couple_with_heart-var-2,.cmd .emoji.couple_with_heart-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491-1f3fd.png);}
.terminal-output .emoji.couple_with_heart-var-3,.cmd .emoji.couple_with_heart-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491-1f3fe.png);}
.terminal-output .emoji.couple_with_heart-var-4,.cmd .emoji.couple_with_heart-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f491-1f3ff.png);}
.terminal-output .emoji.couple_with_heart-var-5,.cmd .emoji.couple_with_heart-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couple_with_heart-var-6,.cmd .emoji.couple_with_heart-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couple_with_heart-var-7,.cmd .emoji.couple_with_heart-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couple_with_heart-var-8,.cmd .emoji.couple_with_heart-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2764-fe0f-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couple_with_heart-var-9,.cmd .emoji.couple_with_heart-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couple_with_heart-var-10,.cmd .emoji.couple_with_heart-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couple_with_heart-var-11,.cmd .emoji.couple_with_heart-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couple_with_heart-var-12,.cmd .emoji.couple_with_heart-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2764-fe0f-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couple_with_heart-var-13,.cmd .emoji.couple_with_heart-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couple_with_heart-var-14,.cmd .emoji.couple_with_heart-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couple_with_heart-var-15,.cmd .emoji.couple_with_heart-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.couple_with_heart-var-16,.cmd .emoji.couple_with_heart-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2764-fe0f-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couple_with_heart-var-17,.cmd .emoji.couple_with_heart-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couple_with_heart-var-18,.cmd .emoji.couple_with_heart-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couple_with_heart-var-19,.cmd .emoji.couple_with_heart-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couple_with_heart-var-20,.cmd .emoji.couple_with_heart-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2764-fe0f-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.couple_with_heart-var-21,.cmd .emoji.couple_with_heart-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.couple_with_heart-var-22,.cmd .emoji.couple_with_heart-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.couple_with_heart-var-23,.cmd .emoji.couple_with_heart-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.couple_with_heart-var-24,.cmd .emoji.couple_with_heart-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2764-fe0f-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.wedding,.cmd .emoji.wedding{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f492.png);}
.terminal-output .emoji.heartbeat,.cmd .emoji.heartbeat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f493.png);}
.terminal-output .emoji.broken_heart,.cmd .emoji.broken_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f494.png);}
.terminal-output .emoji.two_hearts,.cmd .emoji.two_hearts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f495.png);}
.terminal-output .emoji.sparkling_heart,.cmd .emoji.sparkling_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f496.png);}
.terminal-output .emoji.heartpulse,.cmd .emoji.heartpulse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f497.png);}
.terminal-output .emoji.cupid,.cmd .emoji.cupid{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f498.png);}
.terminal-output .emoji.blue_heart,.cmd .emoji.blue_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f499.png);}
.terminal-output .emoji.green_heart,.cmd .emoji.green_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49a.png);}
.terminal-output .emoji.yellow_heart,.cmd .emoji.yellow_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49b.png);}
.terminal-output .emoji.purple_heart,.cmd .emoji.purple_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49c.png);}
.terminal-output .emoji.gift_heart,.cmd .emoji.gift_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49d.png);}
.terminal-output .emoji.revolving_hearts,.cmd .emoji.revolving_hearts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49e.png);}
.terminal-output .emoji.heart_decoration,.cmd .emoji.heart_decoration{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f49f.png);}
.terminal-output .emoji.diamond_shape_with_a_dot_inside,.cmd .emoji.diamond_shape_with_a_dot_inside{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a0.png);}
.terminal-output .emoji.bulb,.cmd .emoji.bulb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a1.png);}
.terminal-output .emoji.anger,.cmd .emoji.anger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a2.png);}
.terminal-output .emoji.bomb,.cmd .emoji.bomb{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a3.png);}
.terminal-output .emoji.zzz,.cmd .emoji.zzz{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a4.png);}
.terminal-output .emoji.boom,.cmd .emoji.boom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a5.png);}
.terminal-output .emoji.sweat_drops,.cmd .emoji.sweat_drops{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a6.png);}
.terminal-output .emoji.droplet,.cmd .emoji.droplet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a7.png);}
.terminal-output .emoji.dash,.cmd .emoji.dash{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a8.png);}
.terminal-output .emoji.hankey,.cmd .emoji.hankey{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4a9.png);}
.terminal-output .emoji.muscle,.cmd .emoji.muscle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa.png);}
.terminal-output .emoji.muscle-var-0,.cmd .emoji.muscle-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa-1f3fb.png);}
.terminal-output .emoji.muscle-var-1,.cmd .emoji.muscle-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa-1f3fc.png);}
.terminal-output .emoji.muscle-var-2,.cmd .emoji.muscle-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa-1f3fd.png);}
.terminal-output .emoji.muscle-var-3,.cmd .emoji.muscle-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa-1f3fe.png);}
.terminal-output .emoji.muscle-var-4,.cmd .emoji.muscle-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4aa-1f3ff.png);}
.terminal-output .emoji.dizzy,.cmd .emoji.dizzy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ab.png);}
.terminal-output .emoji.speech_balloon,.cmd .emoji.speech_balloon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ac.png);}
.terminal-output .emoji.thought_balloon,.cmd .emoji.thought_balloon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ad.png);}
.terminal-output .emoji.white_flower,.cmd .emoji.white_flower{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ae.png);}
.terminal-output .emoji.\31 00,.cmd .emoji.\31 00{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4af.png);}
.terminal-output .emoji.moneybag,.cmd .emoji.moneybag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b0.png);}
.terminal-output .emoji.currency_exchange,.cmd .emoji.currency_exchange{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b1.png);}
.terminal-output .emoji.heavy_dollar_sign,.cmd .emoji.heavy_dollar_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b2.png);}
.terminal-output .emoji.credit_card,.cmd .emoji.credit_card{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b3.png);}
.terminal-output .emoji.yen,.cmd .emoji.yen{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b4.png);}
.terminal-output .emoji.dollar,.cmd .emoji.dollar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b5.png);}
.terminal-output .emoji.euro,.cmd .emoji.euro{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b6.png);}
.terminal-output .emoji.pound,.cmd .emoji.pound{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b7.png);}
.terminal-output .emoji.money_with_wings,.cmd .emoji.money_with_wings{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b8.png);}
.terminal-output .emoji.chart,.cmd .emoji.chart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4b9.png);}
.terminal-output .emoji.seat,.cmd .emoji.seat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ba.png);}
.terminal-output .emoji.computer,.cmd .emoji.computer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4bb.png);}
.terminal-output .emoji.briefcase,.cmd .emoji.briefcase{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4bc.png);}
.terminal-output .emoji.minidisc,.cmd .emoji.minidisc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4bd.png);}
.terminal-output .emoji.floppy_disk,.cmd .emoji.floppy_disk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4be.png);}
.terminal-output .emoji.cd,.cmd .emoji.cd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4bf.png);}
.terminal-output .emoji.dvd,.cmd .emoji.dvd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c0.png);}
.terminal-output .emoji.file_folder,.cmd .emoji.file_folder{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c1.png);}
.terminal-output .emoji.open_file_folder,.cmd .emoji.open_file_folder{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c2.png);}
.terminal-output .emoji.page_with_curl,.cmd .emoji.page_with_curl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c3.png);}
.terminal-output .emoji.page_facing_up,.cmd .emoji.page_facing_up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c4.png);}
.terminal-output .emoji.date,.cmd .emoji.date{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c5.png);}
.terminal-output .emoji.calendar,.cmd .emoji.calendar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c6.png);}
.terminal-output .emoji.card_index,.cmd .emoji.card_index{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c7.png);}
.terminal-output .emoji.chart_with_upwards_trend,.cmd .emoji.chart_with_upwards_trend{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c8.png);}
.terminal-output .emoji.chart_with_downwards_trend,.cmd .emoji.chart_with_downwards_trend{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4c9.png);}
.terminal-output .emoji.bar_chart,.cmd .emoji.bar_chart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ca.png);}
.terminal-output .emoji.clipboard,.cmd .emoji.clipboard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4cb.png);}
.terminal-output .emoji.pushpin,.cmd .emoji.pushpin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4cc.png);}
.terminal-output .emoji.round_pushpin,.cmd .emoji.round_pushpin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4cd.png);}
.terminal-output .emoji.paperclip,.cmd .emoji.paperclip{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ce.png);}
.terminal-output .emoji.straight_ruler,.cmd .emoji.straight_ruler{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4cf.png);}
.terminal-output .emoji.triangular_ruler,.cmd .emoji.triangular_ruler{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d0.png);}
.terminal-output .emoji.bookmark_tabs,.cmd .emoji.bookmark_tabs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d1.png);}
.terminal-output .emoji.ledger,.cmd .emoji.ledger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d2.png);}
.terminal-output .emoji.notebook,.cmd .emoji.notebook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d3.png);}
.terminal-output .emoji.notebook_with_decorative_cover,.cmd .emoji.notebook_with_decorative_cover{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d4.png);}
.terminal-output .emoji.closed_book,.cmd .emoji.closed_book{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d5.png);}
.terminal-output .emoji.book,.cmd .emoji.book{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d6.png);}
.terminal-output .emoji.green_book,.cmd .emoji.green_book{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d7.png);}
.terminal-output .emoji.blue_book,.cmd .emoji.blue_book{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d8.png);}
.terminal-output .emoji.orange_book,.cmd .emoji.orange_book{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4d9.png);}
.terminal-output .emoji.books,.cmd .emoji.books{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4da.png);}
.terminal-output .emoji.name_badge,.cmd .emoji.name_badge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4db.png);}
.terminal-output .emoji.scroll,.cmd .emoji.scroll{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4dc.png);}
.terminal-output .emoji.memo,.cmd .emoji.memo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4dd.png);}
.terminal-output .emoji.telephone_receiver,.cmd .emoji.telephone_receiver{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4de.png);}
.terminal-output .emoji.pager,.cmd .emoji.pager{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4df.png);}
.terminal-output .emoji.fax,.cmd .emoji.fax{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e0.png);}
.terminal-output .emoji.satellite_antenna,.cmd .emoji.satellite_antenna{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e1.png);}
.terminal-output .emoji.loudspeaker,.cmd .emoji.loudspeaker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e2.png);}
.terminal-output .emoji.mega,.cmd .emoji.mega{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e3.png);}
.terminal-output .emoji.outbox_tray,.cmd .emoji.outbox_tray{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e4.png);}
.terminal-output .emoji.inbox_tray,.cmd .emoji.inbox_tray{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e5.png);}
.terminal-output .emoji.package,.cmd .emoji.package{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e6.png);}
.terminal-output .emoji.e-mail,.cmd .emoji.e-mail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e7.png);}
.terminal-output .emoji.incoming_envelope,.cmd .emoji.incoming_envelope{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e8.png);}
.terminal-output .emoji.envelope_with_arrow,.cmd .emoji.envelope_with_arrow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4e9.png);}
.terminal-output .emoji.mailbox_closed,.cmd .emoji.mailbox_closed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ea.png);}
.terminal-output .emoji.mailbox,.cmd .emoji.mailbox{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4eb.png);}
.terminal-output .emoji.mailbox_with_mail,.cmd .emoji.mailbox_with_mail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ec.png);}
.terminal-output .emoji.mailbox_with_no_mail,.cmd .emoji.mailbox_with_no_mail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ed.png);}
.terminal-output .emoji.postbox,.cmd .emoji.postbox{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ee.png);}
.terminal-output .emoji.postal_horn,.cmd .emoji.postal_horn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ef.png);}
.terminal-output .emoji.newspaper,.cmd .emoji.newspaper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f0.png);}
.terminal-output .emoji.iphone,.cmd .emoji.iphone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f1.png);}
.terminal-output .emoji.calling,.cmd .emoji.calling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f2.png);}
.terminal-output .emoji.vibration_mode,.cmd .emoji.vibration_mode{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f3.png);}
.terminal-output .emoji.mobile_phone_off,.cmd .emoji.mobile_phone_off{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f4.png);}
.terminal-output .emoji.no_mobile_phones,.cmd .emoji.no_mobile_phones{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f5.png);}
.terminal-output .emoji.signal_strength,.cmd .emoji.signal_strength{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f6.png);}
.terminal-output .emoji.camera,.cmd .emoji.camera{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f7.png);}
.terminal-output .emoji.camera_with_flash,.cmd .emoji.camera_with_flash{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f8.png);}
.terminal-output .emoji.video_camera,.cmd .emoji.video_camera{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4f9.png);}
.terminal-output .emoji.tv,.cmd .emoji.tv{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4fa.png);}
.terminal-output .emoji.radio,.cmd .emoji.radio{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4fb.png);}
.terminal-output .emoji.vhs,.cmd .emoji.vhs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4fc.png);}
.terminal-output .emoji.film_projector,.cmd .emoji.film_projector{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4fd-fe0f.png);}
.terminal-output .emoji.prayer_beads,.cmd .emoji.prayer_beads{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f4ff.png);}
.terminal-output .emoji.twisted_rightwards_arrows,.cmd .emoji.twisted_rightwards_arrows{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f500.png);}
.terminal-output .emoji.repeat,.cmd .emoji.repeat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f501.png);}
.terminal-output .emoji.repeat_one,.cmd .emoji.repeat_one{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f502.png);}
.terminal-output .emoji.arrows_clockwise,.cmd .emoji.arrows_clockwise{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f503.png);}
.terminal-output .emoji.arrows_counterclockwise,.cmd .emoji.arrows_counterclockwise{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f504.png);}
.terminal-output .emoji.low_brightness,.cmd .emoji.low_brightness{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f505.png);}
.terminal-output .emoji.high_brightness,.cmd .emoji.high_brightness{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f506.png);}
.terminal-output .emoji.mute,.cmd .emoji.mute{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f507.png);}
.terminal-output .emoji.speaker,.cmd .emoji.speaker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f508.png);}
.terminal-output .emoji.sound,.cmd .emoji.sound{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f509.png);}
.terminal-output .emoji.loud_sound,.cmd .emoji.loud_sound{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50a.png);}
.terminal-output .emoji.battery,.cmd .emoji.battery{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50b.png);}
.terminal-output .emoji.electric_plug,.cmd .emoji.electric_plug{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50c.png);}
.terminal-output .emoji.mag,.cmd .emoji.mag{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50d.png);}
.terminal-output .emoji.mag_right,.cmd .emoji.mag_right{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50e.png);}
.terminal-output .emoji.lock_with_ink_pen,.cmd .emoji.lock_with_ink_pen{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f50f.png);}
.terminal-output .emoji.closed_lock_with_key,.cmd .emoji.closed_lock_with_key{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f510.png);}
.terminal-output .emoji.key,.cmd .emoji.key{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f511.png);}
.terminal-output .emoji.lock,.cmd .emoji.lock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f512.png);}
.terminal-output .emoji.unlock,.cmd .emoji.unlock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f513.png);}
.terminal-output .emoji.bell,.cmd .emoji.bell{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f514.png);}
.terminal-output .emoji.no_bell,.cmd .emoji.no_bell{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f515.png);}
.terminal-output .emoji.bookmark,.cmd .emoji.bookmark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f516.png);}
.terminal-output .emoji.link,.cmd .emoji.link{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f517.png);}
.terminal-output .emoji.radio_button,.cmd .emoji.radio_button{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f518.png);}
.terminal-output .emoji.back,.cmd .emoji.back{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f519.png);}
.terminal-output .emoji.end,.cmd .emoji.end{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51a.png);}
.terminal-output .emoji.on,.cmd .emoji.on{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51b.png);}
.terminal-output .emoji.soon,.cmd .emoji.soon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51c.png);}
.terminal-output .emoji.top,.cmd .emoji.top{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51d.png);}
.terminal-output .emoji.underage,.cmd .emoji.underage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51e.png);}
.terminal-output .emoji.keycap_ten,.cmd .emoji.keycap_ten{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f51f.png);}
.terminal-output .emoji.capital_abcd,.cmd .emoji.capital_abcd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f520.png);}
.terminal-output .emoji.abcd,.cmd .emoji.abcd{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f521.png);}
.terminal-output .emoji.\31 234,.cmd .emoji.\31 234{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f522.png);}
.terminal-output .emoji.symbols,.cmd .emoji.symbols{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f523.png);}
.terminal-output .emoji.abc,.cmd .emoji.abc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f524.png);}
.terminal-output .emoji.fire,.cmd .emoji.fire{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f525.png);}
.terminal-output .emoji.flashlight,.cmd .emoji.flashlight{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f526.png);}
.terminal-output .emoji.wrench,.cmd .emoji.wrench{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f527.png);}
.terminal-output .emoji.hammer,.cmd .emoji.hammer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f528.png);}
.terminal-output .emoji.nut_and_bolt,.cmd .emoji.nut_and_bolt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f529.png);}
.terminal-output .emoji.hocho,.cmd .emoji.hocho{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52a.png);}
.terminal-output .emoji.gun,.cmd .emoji.gun{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52b.png);}
.terminal-output .emoji.microscope,.cmd .emoji.microscope{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52c.png);}
.terminal-output .emoji.telescope,.cmd .emoji.telescope{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52d.png);}
.terminal-output .emoji.crystal_ball,.cmd .emoji.crystal_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52e.png);}
.terminal-output .emoji.six_pointed_star,.cmd .emoji.six_pointed_star{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f52f.png);}
.terminal-output .emoji.beginner,.cmd .emoji.beginner{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f530.png);}
.terminal-output .emoji.trident,.cmd .emoji.trident{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f531.png);}
.terminal-output .emoji.black_square_button,.cmd .emoji.black_square_button{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f532.png);}
.terminal-output .emoji.white_square_button,.cmd .emoji.white_square_button{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f533.png);}
.terminal-output .emoji.red_circle,.cmd .emoji.red_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f534.png);}
.terminal-output .emoji.large_blue_circle,.cmd .emoji.large_blue_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f535.png);}
.terminal-output .emoji.large_orange_diamond,.cmd .emoji.large_orange_diamond{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f536.png);}
.terminal-output .emoji.large_blue_diamond,.cmd .emoji.large_blue_diamond{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f537.png);}
.terminal-output .emoji.small_orange_diamond,.cmd .emoji.small_orange_diamond{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f538.png);}
.terminal-output .emoji.small_blue_diamond,.cmd .emoji.small_blue_diamond{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f539.png);}
.terminal-output .emoji.small_red_triangle,.cmd .emoji.small_red_triangle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f53a.png);}
.terminal-output .emoji.small_red_triangle_down,.cmd .emoji.small_red_triangle_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f53b.png);}
.terminal-output .emoji.arrow_up_small,.cmd .emoji.arrow_up_small{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f53c.png);}
.terminal-output .emoji.arrow_down_small,.cmd .emoji.arrow_down_small{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f53d.png);}
.terminal-output .emoji.om_symbol,.cmd .emoji.om_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f549-fe0f.png);}
.terminal-output .emoji.dove_of_peace,.cmd .emoji.dove_of_peace{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f54a-fe0f.png);}
.terminal-output .emoji.kaaba,.cmd .emoji.kaaba{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f54b.png);}
.terminal-output .emoji.mosque,.cmd .emoji.mosque{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f54c.png);}
.terminal-output .emoji.synagogue,.cmd .emoji.synagogue{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f54d.png);}
.terminal-output .emoji.menorah_with_nine_branches,.cmd .emoji.menorah_with_nine_branches{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f54e.png);}
.terminal-output .emoji.clock1,.cmd .emoji.clock1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f550.png);}
.terminal-output .emoji.clock2,.cmd .emoji.clock2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f551.png);}
.terminal-output .emoji.clock3,.cmd .emoji.clock3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f552.png);}
.terminal-output .emoji.clock4,.cmd .emoji.clock4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f553.png);}
.terminal-output .emoji.clock5,.cmd .emoji.clock5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f554.png);}
.terminal-output .emoji.clock6,.cmd .emoji.clock6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f555.png);}
.terminal-output .emoji.clock7,.cmd .emoji.clock7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f556.png);}
.terminal-output .emoji.clock8,.cmd .emoji.clock8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f557.png);}
.terminal-output .emoji.clock9,.cmd .emoji.clock9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f558.png);}
.terminal-output .emoji.clock10,.cmd .emoji.clock10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f559.png);}
.terminal-output .emoji.clock11,.cmd .emoji.clock11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55a.png);}
.terminal-output .emoji.clock12,.cmd .emoji.clock12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55b.png);}
.terminal-output .emoji.clock130,.cmd .emoji.clock130{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55c.png);}
.terminal-output .emoji.clock230,.cmd .emoji.clock230{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55d.png);}
.terminal-output .emoji.clock330,.cmd .emoji.clock330{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55e.png);}
.terminal-output .emoji.clock430,.cmd .emoji.clock430{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f55f.png);}
.terminal-output .emoji.clock530,.cmd .emoji.clock530{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f560.png);}
.terminal-output .emoji.clock630,.cmd .emoji.clock630{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f561.png);}
.terminal-output .emoji.clock730,.cmd .emoji.clock730{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f562.png);}
.terminal-output .emoji.clock830,.cmd .emoji.clock830{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f563.png);}
.terminal-output .emoji.clock930,.cmd .emoji.clock930{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f564.png);}
.terminal-output .emoji.clock1030,.cmd .emoji.clock1030{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f565.png);}
.terminal-output .emoji.clock1130,.cmd .emoji.clock1130{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f566.png);}
.terminal-output .emoji.clock1230,.cmd .emoji.clock1230{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f567.png);}
.terminal-output .emoji.candle,.cmd .emoji.candle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f56f-fe0f.png);}
.terminal-output .emoji.mantelpiece_clock,.cmd .emoji.mantelpiece_clock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f570-fe0f.png);}
.terminal-output .emoji.hole,.cmd .emoji.hole{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f573-fe0f.png);}
.terminal-output .emoji.man_in_business_suit_levitating,.cmd .emoji.man_in_business_suit_levitating{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-fe0f.png);}
.terminal-output .emoji.man_in_business_suit_levitating-var-0,.cmd .emoji.man_in_business_suit_levitating-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-1f3fb.png);}
.terminal-output .emoji.man_in_business_suit_levitating-var-1,.cmd .emoji.man_in_business_suit_levitating-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-1f3fc.png);}
.terminal-output .emoji.man_in_business_suit_levitating-var-2,.cmd .emoji.man_in_business_suit_levitating-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-1f3fd.png);}
.terminal-output .emoji.man_in_business_suit_levitating-var-3,.cmd .emoji.man_in_business_suit_levitating-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-1f3fe.png);}
.terminal-output .emoji.man_in_business_suit_levitating-var-4,.cmd .emoji.man_in_business_suit_levitating-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f574-1f3ff.png);}
.terminal-output .emoji.female-detective,.cmd .emoji.female-detective{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-fe0f-200d-2640-fe0f.png);}
.terminal-output .emoji.female-detective-var-0,.cmd .emoji.female-detective-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female-detective-var-1,.cmd .emoji.female-detective-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female-detective-var-2,.cmd .emoji.female-detective-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female-detective-var-3,.cmd .emoji.female-detective-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female-detective-var-4,.cmd .emoji.female-detective-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male-detective,.cmd .emoji.male-detective{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-fe0f-200d-2642-fe0f.png);}
.terminal-output .emoji.male-detective-var-0,.cmd .emoji.male-detective-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male-detective-var-1,.cmd .emoji.male-detective-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male-detective-var-2,.cmd .emoji.male-detective-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male-detective-var-3,.cmd .emoji.male-detective-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male-detective-var-4,.cmd .emoji.male-detective-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.sleuth_or_spy,.cmd .emoji.sleuth_or_spy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-fe0f.png);}
.terminal-output .emoji.sleuth_or_spy-var-0,.cmd .emoji.sleuth_or_spy-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fb.png);}
.terminal-output .emoji.sleuth_or_spy-var-1,.cmd .emoji.sleuth_or_spy-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fc.png);}
.terminal-output .emoji.sleuth_or_spy-var-2,.cmd .emoji.sleuth_or_spy-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fd.png);}
.terminal-output .emoji.sleuth_or_spy-var-3,.cmd .emoji.sleuth_or_spy-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3fe.png);}
.terminal-output .emoji.sleuth_or_spy-var-4,.cmd .emoji.sleuth_or_spy-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f575-1f3ff.png);}
.terminal-output .emoji.dark_sunglasses,.cmd .emoji.dark_sunglasses{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f576-fe0f.png);}
.terminal-output .emoji.spider,.cmd .emoji.spider{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f577-fe0f.png);}
.terminal-output .emoji.spider_web,.cmd .emoji.spider_web{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f578-fe0f.png);}
.terminal-output .emoji.joystick,.cmd .emoji.joystick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f579-fe0f.png);}
.terminal-output .emoji.man_dancing,.cmd .emoji.man_dancing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a.png);}
.terminal-output .emoji.man_dancing-var-0,.cmd .emoji.man_dancing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a-1f3fb.png);}
.terminal-output .emoji.man_dancing-var-1,.cmd .emoji.man_dancing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a-1f3fc.png);}
.terminal-output .emoji.man_dancing-var-2,.cmd .emoji.man_dancing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a-1f3fd.png);}
.terminal-output .emoji.man_dancing-var-3,.cmd .emoji.man_dancing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a-1f3fe.png);}
.terminal-output .emoji.man_dancing-var-4,.cmd .emoji.man_dancing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f57a-1f3ff.png);}
.terminal-output .emoji.linked_paperclips,.cmd .emoji.linked_paperclips{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f587-fe0f.png);}
.terminal-output .emoji.lower_left_ballpoint_pen,.cmd .emoji.lower_left_ballpoint_pen{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f58a-fe0f.png);}
.terminal-output .emoji.lower_left_fountain_pen,.cmd .emoji.lower_left_fountain_pen{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f58b-fe0f.png);}
.terminal-output .emoji.lower_left_paintbrush,.cmd .emoji.lower_left_paintbrush{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f58c-fe0f.png);}
.terminal-output .emoji.lower_left_crayon,.cmd .emoji.lower_left_crayon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f58d-fe0f.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed,.cmd .emoji.raised_hand_with_fingers_splayed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-fe0f.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed-var-0,.cmd .emoji.raised_hand_with_fingers_splayed-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-1f3fb.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed-var-1,.cmd .emoji.raised_hand_with_fingers_splayed-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-1f3fc.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed-var-2,.cmd .emoji.raised_hand_with_fingers_splayed-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-1f3fd.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed-var-3,.cmd .emoji.raised_hand_with_fingers_splayed-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-1f3fe.png);}
.terminal-output .emoji.raised_hand_with_fingers_splayed-var-4,.cmd .emoji.raised_hand_with_fingers_splayed-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f590-1f3ff.png);}
.terminal-output .emoji.middle_finger,.cmd .emoji.middle_finger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595.png);}
.terminal-output .emoji.middle_finger-var-0,.cmd .emoji.middle_finger-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595-1f3fb.png);}
.terminal-output .emoji.middle_finger-var-1,.cmd .emoji.middle_finger-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595-1f3fc.png);}
.terminal-output .emoji.middle_finger-var-2,.cmd .emoji.middle_finger-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595-1f3fd.png);}
.terminal-output .emoji.middle_finger-var-3,.cmd .emoji.middle_finger-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595-1f3fe.png);}
.terminal-output .emoji.middle_finger-var-4,.cmd .emoji.middle_finger-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f595-1f3ff.png);}
.terminal-output .emoji.spock-hand,.cmd .emoji.spock-hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596.png);}
.terminal-output .emoji.spock-hand-var-0,.cmd .emoji.spock-hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596-1f3fb.png);}
.terminal-output .emoji.spock-hand-var-1,.cmd .emoji.spock-hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596-1f3fc.png);}
.terminal-output .emoji.spock-hand-var-2,.cmd .emoji.spock-hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596-1f3fd.png);}
.terminal-output .emoji.spock-hand-var-3,.cmd .emoji.spock-hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596-1f3fe.png);}
.terminal-output .emoji.spock-hand-var-4,.cmd .emoji.spock-hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f596-1f3ff.png);}
.terminal-output .emoji.black_heart,.cmd .emoji.black_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5a4.png);}
.terminal-output .emoji.desktop_computer,.cmd .emoji.desktop_computer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5a5-fe0f.png);}
.terminal-output .emoji.printer,.cmd .emoji.printer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5a8-fe0f.png);}
.terminal-output .emoji.three_button_mouse,.cmd .emoji.three_button_mouse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5b1-fe0f.png);}
.terminal-output .emoji.trackball,.cmd .emoji.trackball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5b2-fe0f.png);}
.terminal-output .emoji.frame_with_picture,.cmd .emoji.frame_with_picture{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5bc-fe0f.png);}
.terminal-output .emoji.card_index_dividers,.cmd .emoji.card_index_dividers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5c2-fe0f.png);}
.terminal-output .emoji.card_file_box,.cmd .emoji.card_file_box{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5c3-fe0f.png);}
.terminal-output .emoji.file_cabinet,.cmd .emoji.file_cabinet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5c4-fe0f.png);}
.terminal-output .emoji.wastebasket,.cmd .emoji.wastebasket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5d1-fe0f.png);}
.terminal-output .emoji.spiral_note_pad,.cmd .emoji.spiral_note_pad{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5d2-fe0f.png);}
.terminal-output .emoji.spiral_calendar_pad,.cmd .emoji.spiral_calendar_pad{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5d3-fe0f.png);}
.terminal-output .emoji.compression,.cmd .emoji.compression{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5dc-fe0f.png);}
.terminal-output .emoji.old_key,.cmd .emoji.old_key{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5dd-fe0f.png);}
.terminal-output .emoji.rolled_up_newspaper,.cmd .emoji.rolled_up_newspaper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5de-fe0f.png);}
.terminal-output .emoji.dagger_knife,.cmd .emoji.dagger_knife{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5e1-fe0f.png);}
.terminal-output .emoji.speaking_head_in_silhouette,.cmd .emoji.speaking_head_in_silhouette{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5e3-fe0f.png);}
.terminal-output .emoji.left_speech_bubble,.cmd .emoji.left_speech_bubble{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5e8-fe0f.png);}
.terminal-output .emoji.right_anger_bubble,.cmd .emoji.right_anger_bubble{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5ef-fe0f.png);}
.terminal-output .emoji.ballot_box_with_ballot,.cmd .emoji.ballot_box_with_ballot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5f3-fe0f.png);}
.terminal-output .emoji.world_map,.cmd .emoji.world_map{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5fa-fe0f.png);}
.terminal-output .emoji.mount_fuji,.cmd .emoji.mount_fuji{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5fb.png);}
.terminal-output .emoji.tokyo_tower,.cmd .emoji.tokyo_tower{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5fc.png);}
.terminal-output .emoji.statue_of_liberty,.cmd .emoji.statue_of_liberty{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5fd.png);}
.terminal-output .emoji.japan,.cmd .emoji.japan{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5fe.png);}
.terminal-output .emoji.moyai,.cmd .emoji.moyai{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f5ff.png);}
.terminal-output .emoji.grinning,.cmd .emoji.grinning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f600.png);}
.terminal-output .emoji.grin,.cmd .emoji.grin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f601.png);}
.terminal-output .emoji.joy,.cmd .emoji.joy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f602.png);}
.terminal-output .emoji.smiley,.cmd .emoji.smiley{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f603.png);}
.terminal-output .emoji.smile,.cmd .emoji.smile{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f604.png);}
.terminal-output .emoji.sweat_smile,.cmd .emoji.sweat_smile{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f605.png);}
.terminal-output .emoji.laughing,.cmd .emoji.laughing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f606.png);}
.terminal-output .emoji.innocent,.cmd .emoji.innocent{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f607.png);}
.terminal-output .emoji.smiling_imp,.cmd .emoji.smiling_imp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f608.png);}
.terminal-output .emoji.wink,.cmd .emoji.wink{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f609.png);}
.terminal-output .emoji.blush,.cmd .emoji.blush{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60a.png);}
.terminal-output .emoji.yum,.cmd .emoji.yum{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60b.png);}
.terminal-output .emoji.relieved,.cmd .emoji.relieved{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60c.png);}
.terminal-output .emoji.heart_eyes,.cmd .emoji.heart_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60d.png);}
.terminal-output .emoji.sunglasses,.cmd .emoji.sunglasses{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60e.png);}
.terminal-output .emoji.smirk,.cmd .emoji.smirk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f60f.png);}
.terminal-output .emoji.neutral_face,.cmd .emoji.neutral_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f610.png);}
.terminal-output .emoji.expressionless,.cmd .emoji.expressionless{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f611.png);}
.terminal-output .emoji.unamused,.cmd .emoji.unamused{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f612.png);}
.terminal-output .emoji.sweat,.cmd .emoji.sweat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f613.png);}
.terminal-output .emoji.pensive,.cmd .emoji.pensive{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f614.png);}
.terminal-output .emoji.confused,.cmd .emoji.confused{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f615.png);}
.terminal-output .emoji.confounded,.cmd .emoji.confounded{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f616.png);}
.terminal-output .emoji.kissing,.cmd .emoji.kissing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f617.png);}
.terminal-output .emoji.kissing_heart,.cmd .emoji.kissing_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f618.png);}
.terminal-output .emoji.kissing_smiling_eyes,.cmd .emoji.kissing_smiling_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f619.png);}
.terminal-output .emoji.kissing_closed_eyes,.cmd .emoji.kissing_closed_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61a.png);}
.terminal-output .emoji.stuck_out_tongue,.cmd .emoji.stuck_out_tongue{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61b.png);}
.terminal-output .emoji.stuck_out_tongue_winking_eye,.cmd .emoji.stuck_out_tongue_winking_eye{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61c.png);}
.terminal-output .emoji.stuck_out_tongue_closed_eyes,.cmd .emoji.stuck_out_tongue_closed_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61d.png);}
.terminal-output .emoji.disappointed,.cmd .emoji.disappointed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61e.png);}
.terminal-output .emoji.worried,.cmd .emoji.worried{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f61f.png);}
.terminal-output .emoji.angry,.cmd .emoji.angry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f620.png);}
.terminal-output .emoji.rage,.cmd .emoji.rage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f621.png);}
.terminal-output .emoji.cry,.cmd .emoji.cry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f622.png);}
.terminal-output .emoji.persevere,.cmd .emoji.persevere{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f623.png);}
.terminal-output .emoji.triumph,.cmd .emoji.triumph{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f624.png);}
.terminal-output .emoji.disappointed_relieved,.cmd .emoji.disappointed_relieved{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f625.png);}
.terminal-output .emoji.frowning,.cmd .emoji.frowning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f626.png);}
.terminal-output .emoji.anguished,.cmd .emoji.anguished{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f627.png);}
.terminal-output .emoji.fearful,.cmd .emoji.fearful{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f628.png);}
.terminal-output .emoji.weary,.cmd .emoji.weary{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f629.png);}
.terminal-output .emoji.sleepy,.cmd .emoji.sleepy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62a.png);}
.terminal-output .emoji.tired_face,.cmd .emoji.tired_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62b.png);}
.terminal-output .emoji.grimacing,.cmd .emoji.grimacing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62c.png);}
.terminal-output .emoji.sob,.cmd .emoji.sob{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62d.png);}
.terminal-output .emoji.face_exhaling,.cmd .emoji.face_exhaling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62e-200d-1f4a8.png);}
.terminal-output .emoji.open_mouth,.cmd .emoji.open_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62e.png);}
.terminal-output .emoji.hushed,.cmd .emoji.hushed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f62f.png);}
.terminal-output .emoji.cold_sweat,.cmd .emoji.cold_sweat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f630.png);}
.terminal-output .emoji.scream,.cmd .emoji.scream{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f631.png);}
.terminal-output .emoji.astonished,.cmd .emoji.astonished{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f632.png);}
.terminal-output .emoji.flushed,.cmd .emoji.flushed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f633.png);}
.terminal-output .emoji.sleeping,.cmd .emoji.sleeping{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f634.png);}
.terminal-output .emoji.face_with_spiral_eyes,.cmd .emoji.face_with_spiral_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f635-200d-1f4ab.png);}
.terminal-output .emoji.dizzy_face,.cmd .emoji.dizzy_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f635.png);}
.terminal-output .emoji.face_in_clouds,.cmd .emoji.face_in_clouds{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f636-200d-1f32b-fe0f.png);}
.terminal-output .emoji.no_mouth,.cmd .emoji.no_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f636.png);}
.terminal-output .emoji.mask,.cmd .emoji.mask{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f637.png);}
.terminal-output .emoji.smile_cat,.cmd .emoji.smile_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f638.png);}
.terminal-output .emoji.joy_cat,.cmd .emoji.joy_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f639.png);}
.terminal-output .emoji.smiley_cat,.cmd .emoji.smiley_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63a.png);}
.terminal-output .emoji.heart_eyes_cat,.cmd .emoji.heart_eyes_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63b.png);}
.terminal-output .emoji.smirk_cat,.cmd .emoji.smirk_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63c.png);}
.terminal-output .emoji.kissing_cat,.cmd .emoji.kissing_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63d.png);}
.terminal-output .emoji.pouting_cat,.cmd .emoji.pouting_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63e.png);}
.terminal-output .emoji.crying_cat_face,.cmd .emoji.crying_cat_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f63f.png);}
.terminal-output .emoji.scream_cat,.cmd .emoji.scream_cat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f640.png);}
.terminal-output .emoji.slightly_frowning_face,.cmd .emoji.slightly_frowning_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f641.png);}
.terminal-output .emoji.slightly_smiling_face,.cmd .emoji.slightly_smiling_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f642.png);}
.terminal-output .emoji.upside_down_face,.cmd .emoji.upside_down_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f643.png);}
.terminal-output .emoji.face_with_rolling_eyes,.cmd .emoji.face_with_rolling_eyes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f644.png);}
.terminal-output .emoji.woman-gesturing-no,.cmd .emoji.woman-gesturing-no{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-no-var-0,.cmd .emoji.woman-gesturing-no-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-no-var-1,.cmd .emoji.woman-gesturing-no-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-no-var-2,.cmd .emoji.woman-gesturing-no-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-no-var-3,.cmd .emoji.woman-gesturing-no-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-no-var-4,.cmd .emoji.woman-gesturing-no-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-gesturing-no,.cmd .emoji.man-gesturing-no{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-no-var-0,.cmd .emoji.man-gesturing-no-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-no-var-1,.cmd .emoji.man-gesturing-no-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-no-var-2,.cmd .emoji.man-gesturing-no-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-no-var-3,.cmd .emoji.man-gesturing-no-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-no-var-4,.cmd .emoji.man-gesturing-no-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.no_good,.cmd .emoji.no_good{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645.png);}
.terminal-output .emoji.no_good-var-0,.cmd .emoji.no_good-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fb.png);}
.terminal-output .emoji.no_good-var-1,.cmd .emoji.no_good-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fc.png);}
.terminal-output .emoji.no_good-var-2,.cmd .emoji.no_good-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fd.png);}
.terminal-output .emoji.no_good-var-3,.cmd .emoji.no_good-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3fe.png);}
.terminal-output .emoji.no_good-var-4,.cmd .emoji.no_good-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f645-1f3ff.png);}
.terminal-output .emoji.woman-gesturing-ok,.cmd .emoji.woman-gesturing-ok{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-ok-var-0,.cmd .emoji.woman-gesturing-ok-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-ok-var-1,.cmd .emoji.woman-gesturing-ok-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-ok-var-2,.cmd .emoji.woman-gesturing-ok-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-ok-var-3,.cmd .emoji.woman-gesturing-ok-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-gesturing-ok-var-4,.cmd .emoji.woman-gesturing-ok-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok,.cmd .emoji.man-gesturing-ok{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok-var-0,.cmd .emoji.man-gesturing-ok-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok-var-1,.cmd .emoji.man-gesturing-ok-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok-var-2,.cmd .emoji.man-gesturing-ok-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok-var-3,.cmd .emoji.man-gesturing-ok-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-gesturing-ok-var-4,.cmd .emoji.man-gesturing-ok-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.ok_woman,.cmd .emoji.ok_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646.png);}
.terminal-output .emoji.ok_woman-var-0,.cmd .emoji.ok_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fb.png);}
.terminal-output .emoji.ok_woman-var-1,.cmd .emoji.ok_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fc.png);}
.terminal-output .emoji.ok_woman-var-2,.cmd .emoji.ok_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fd.png);}
.terminal-output .emoji.ok_woman-var-3,.cmd .emoji.ok_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3fe.png);}
.terminal-output .emoji.ok_woman-var-4,.cmd .emoji.ok_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f646-1f3ff.png);}
.terminal-output .emoji.woman-bowing,.cmd .emoji.woman-bowing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bowing-var-0,.cmd .emoji.woman-bowing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bowing-var-1,.cmd .emoji.woman-bowing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bowing-var-2,.cmd .emoji.woman-bowing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bowing-var-3,.cmd .emoji.woman-bowing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bowing-var-4,.cmd .emoji.woman-bowing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-bowing,.cmd .emoji.man-bowing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bowing-var-0,.cmd .emoji.man-bowing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bowing-var-1,.cmd .emoji.man-bowing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bowing-var-2,.cmd .emoji.man-bowing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bowing-var-3,.cmd .emoji.man-bowing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bowing-var-4,.cmd .emoji.man-bowing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.bow,.cmd .emoji.bow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647.png);}
.terminal-output .emoji.bow-var-0,.cmd .emoji.bow-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fb.png);}
.terminal-output .emoji.bow-var-1,.cmd .emoji.bow-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fc.png);}
.terminal-output .emoji.bow-var-2,.cmd .emoji.bow-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fd.png);}
.terminal-output .emoji.bow-var-3,.cmd .emoji.bow-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3fe.png);}
.terminal-output .emoji.bow-var-4,.cmd .emoji.bow-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f647-1f3ff.png);}
.terminal-output .emoji.see_no_evil,.cmd .emoji.see_no_evil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f648.png);}
.terminal-output .emoji.hear_no_evil,.cmd .emoji.hear_no_evil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f649.png);}
.terminal-output .emoji.speak_no_evil,.cmd .emoji.speak_no_evil{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64a.png);}
.terminal-output .emoji.woman-raising-hand,.cmd .emoji.woman-raising-hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-raising-hand-var-0,.cmd .emoji.woman-raising-hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-raising-hand-var-1,.cmd .emoji.woman-raising-hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-raising-hand-var-2,.cmd .emoji.woman-raising-hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-raising-hand-var-3,.cmd .emoji.woman-raising-hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-raising-hand-var-4,.cmd .emoji.woman-raising-hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-raising-hand,.cmd .emoji.man-raising-hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-200d-2642-fe0f.png);}
.terminal-output .emoji.man-raising-hand-var-0,.cmd .emoji.man-raising-hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-raising-hand-var-1,.cmd .emoji.man-raising-hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-raising-hand-var-2,.cmd .emoji.man-raising-hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-raising-hand-var-3,.cmd .emoji.man-raising-hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-raising-hand-var-4,.cmd .emoji.man-raising-hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.raising_hand,.cmd .emoji.raising_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b.png);}
.terminal-output .emoji.raising_hand-var-0,.cmd .emoji.raising_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fb.png);}
.terminal-output .emoji.raising_hand-var-1,.cmd .emoji.raising_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fc.png);}
.terminal-output .emoji.raising_hand-var-2,.cmd .emoji.raising_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fd.png);}
.terminal-output .emoji.raising_hand-var-3,.cmd .emoji.raising_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3fe.png);}
.terminal-output .emoji.raising_hand-var-4,.cmd .emoji.raising_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64b-1f3ff.png);}
.terminal-output .emoji.raised_hands,.cmd .emoji.raised_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c.png);}
.terminal-output .emoji.raised_hands-var-0,.cmd .emoji.raised_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c-1f3fb.png);}
.terminal-output .emoji.raised_hands-var-1,.cmd .emoji.raised_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c-1f3fc.png);}
.terminal-output .emoji.raised_hands-var-2,.cmd .emoji.raised_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c-1f3fd.png);}
.terminal-output .emoji.raised_hands-var-3,.cmd .emoji.raised_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c-1f3fe.png);}
.terminal-output .emoji.raised_hands-var-4,.cmd .emoji.raised_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64c-1f3ff.png);}
.terminal-output .emoji.woman-frowning,.cmd .emoji.woman-frowning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-frowning-var-0,.cmd .emoji.woman-frowning-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-frowning-var-1,.cmd .emoji.woman-frowning-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-frowning-var-2,.cmd .emoji.woman-frowning-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-frowning-var-3,.cmd .emoji.woman-frowning-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-frowning-var-4,.cmd .emoji.woman-frowning-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-frowning,.cmd .emoji.man-frowning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-200d-2642-fe0f.png);}
.terminal-output .emoji.man-frowning-var-0,.cmd .emoji.man-frowning-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-frowning-var-1,.cmd .emoji.man-frowning-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-frowning-var-2,.cmd .emoji.man-frowning-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-frowning-var-3,.cmd .emoji.man-frowning-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-frowning-var-4,.cmd .emoji.man-frowning-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_frowning,.cmd .emoji.person_frowning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d.png);}
.terminal-output .emoji.person_frowning-var-0,.cmd .emoji.person_frowning-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fb.png);}
.terminal-output .emoji.person_frowning-var-1,.cmd .emoji.person_frowning-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fc.png);}
.terminal-output .emoji.person_frowning-var-2,.cmd .emoji.person_frowning-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fd.png);}
.terminal-output .emoji.person_frowning-var-3,.cmd .emoji.person_frowning-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3fe.png);}
.terminal-output .emoji.person_frowning-var-4,.cmd .emoji.person_frowning-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64d-1f3ff.png);}
.terminal-output .emoji.woman-pouting,.cmd .emoji.woman-pouting{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-pouting-var-0,.cmd .emoji.woman-pouting-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-pouting-var-1,.cmd .emoji.woman-pouting-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-pouting-var-2,.cmd .emoji.woman-pouting-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-pouting-var-3,.cmd .emoji.woman-pouting-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-pouting-var-4,.cmd .emoji.woman-pouting-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-pouting,.cmd .emoji.man-pouting{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-200d-2642-fe0f.png);}
.terminal-output .emoji.man-pouting-var-0,.cmd .emoji.man-pouting-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-pouting-var-1,.cmd .emoji.man-pouting-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-pouting-var-2,.cmd .emoji.man-pouting-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-pouting-var-3,.cmd .emoji.man-pouting-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-pouting-var-4,.cmd .emoji.man-pouting-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_with_pouting_face,.cmd .emoji.person_with_pouting_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e.png);}
.terminal-output .emoji.person_with_pouting_face-var-0,.cmd .emoji.person_with_pouting_face-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fb.png);}
.terminal-output .emoji.person_with_pouting_face-var-1,.cmd .emoji.person_with_pouting_face-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fc.png);}
.terminal-output .emoji.person_with_pouting_face-var-2,.cmd .emoji.person_with_pouting_face-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fd.png);}
.terminal-output .emoji.person_with_pouting_face-var-3,.cmd .emoji.person_with_pouting_face-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3fe.png);}
.terminal-output .emoji.person_with_pouting_face-var-4,.cmd .emoji.person_with_pouting_face-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64e-1f3ff.png);}
.terminal-output .emoji.pray,.cmd .emoji.pray{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f.png);}
.terminal-output .emoji.pray-var-0,.cmd .emoji.pray-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f-1f3fb.png);}
.terminal-output .emoji.pray-var-1,.cmd .emoji.pray-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f-1f3fc.png);}
.terminal-output .emoji.pray-var-2,.cmd .emoji.pray-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f-1f3fd.png);}
.terminal-output .emoji.pray-var-3,.cmd .emoji.pray-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f-1f3fe.png);}
.terminal-output .emoji.pray-var-4,.cmd .emoji.pray-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f64f-1f3ff.png);}
.terminal-output .emoji.rocket,.cmd .emoji.rocket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f680.png);}
.terminal-output .emoji.helicopter,.cmd .emoji.helicopter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f681.png);}
.terminal-output .emoji.steam_locomotive,.cmd .emoji.steam_locomotive{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f682.png);}
.terminal-output .emoji.railway_car,.cmd .emoji.railway_car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f683.png);}
.terminal-output .emoji.bullettrain_side,.cmd .emoji.bullettrain_side{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f684.png);}
.terminal-output .emoji.bullettrain_front,.cmd .emoji.bullettrain_front{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f685.png);}
.terminal-output .emoji.train2,.cmd .emoji.train2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f686.png);}
.terminal-output .emoji.metro,.cmd .emoji.metro{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f687.png);}
.terminal-output .emoji.light_rail,.cmd .emoji.light_rail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f688.png);}
.terminal-output .emoji.station,.cmd .emoji.station{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f689.png);}
.terminal-output .emoji.tram,.cmd .emoji.tram{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68a.png);}
.terminal-output .emoji.train,.cmd .emoji.train{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68b.png);}
.terminal-output .emoji.bus,.cmd .emoji.bus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68c.png);}
.terminal-output .emoji.oncoming_bus,.cmd .emoji.oncoming_bus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68d.png);}
.terminal-output .emoji.trolleybus,.cmd .emoji.trolleybus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68e.png);}
.terminal-output .emoji.busstop,.cmd .emoji.busstop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f68f.png);}
.terminal-output .emoji.minibus,.cmd .emoji.minibus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f690.png);}
.terminal-output .emoji.ambulance,.cmd .emoji.ambulance{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f691.png);}
.terminal-output .emoji.fire_engine,.cmd .emoji.fire_engine{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f692.png);}
.terminal-output .emoji.police_car,.cmd .emoji.police_car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f693.png);}
.terminal-output .emoji.oncoming_police_car,.cmd .emoji.oncoming_police_car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f694.png);}
.terminal-output .emoji.taxi,.cmd .emoji.taxi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f695.png);}
.terminal-output .emoji.oncoming_taxi,.cmd .emoji.oncoming_taxi{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f696.png);}
.terminal-output .emoji.car,.cmd .emoji.car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f697.png);}
.terminal-output .emoji.oncoming_automobile,.cmd .emoji.oncoming_automobile{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f698.png);}
.terminal-output .emoji.blue_car,.cmd .emoji.blue_car{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f699.png);}
.terminal-output .emoji.truck,.cmd .emoji.truck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69a.png);}
.terminal-output .emoji.articulated_lorry,.cmd .emoji.articulated_lorry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69b.png);}
.terminal-output .emoji.tractor,.cmd .emoji.tractor{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69c.png);}
.terminal-output .emoji.monorail,.cmd .emoji.monorail{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69d.png);}
.terminal-output .emoji.mountain_railway,.cmd .emoji.mountain_railway{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69e.png);}
.terminal-output .emoji.suspension_railway,.cmd .emoji.suspension_railway{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f69f.png);}
.terminal-output .emoji.mountain_cableway,.cmd .emoji.mountain_cableway{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a0.png);}
.terminal-output .emoji.aerial_tramway,.cmd .emoji.aerial_tramway{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a1.png);}
.terminal-output .emoji.ship,.cmd .emoji.ship{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a2.png);}
.terminal-output .emoji.woman-rowing-boat,.cmd .emoji.woman-rowing-boat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-rowing-boat-var-0,.cmd .emoji.woman-rowing-boat-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-rowing-boat-var-1,.cmd .emoji.woman-rowing-boat-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-rowing-boat-var-2,.cmd .emoji.woman-rowing-boat-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-rowing-boat-var-3,.cmd .emoji.woman-rowing-boat-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-rowing-boat-var-4,.cmd .emoji.woman-rowing-boat-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-rowing-boat,.cmd .emoji.man-rowing-boat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-200d-2642-fe0f.png);}
.terminal-output .emoji.man-rowing-boat-var-0,.cmd .emoji.man-rowing-boat-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-rowing-boat-var-1,.cmd .emoji.man-rowing-boat-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-rowing-boat-var-2,.cmd .emoji.man-rowing-boat-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-rowing-boat-var-3,.cmd .emoji.man-rowing-boat-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-rowing-boat-var-4,.cmd .emoji.man-rowing-boat-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.rowboat,.cmd .emoji.rowboat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3.png);}
.terminal-output .emoji.rowboat-var-0,.cmd .emoji.rowboat-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fb.png);}
.terminal-output .emoji.rowboat-var-1,.cmd .emoji.rowboat-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fc.png);}
.terminal-output .emoji.rowboat-var-2,.cmd .emoji.rowboat-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fd.png);}
.terminal-output .emoji.rowboat-var-3,.cmd .emoji.rowboat-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3fe.png);}
.terminal-output .emoji.rowboat-var-4,.cmd .emoji.rowboat-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a3-1f3ff.png);}
.terminal-output .emoji.speedboat,.cmd .emoji.speedboat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a4.png);}
.terminal-output .emoji.traffic_light,.cmd .emoji.traffic_light{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a5.png);}
.terminal-output .emoji.vertical_traffic_light,.cmd .emoji.vertical_traffic_light{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a6.png);}
.terminal-output .emoji.construction,.cmd .emoji.construction{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a7.png);}
.terminal-output .emoji.rotating_light,.cmd .emoji.rotating_light{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a8.png);}
.terminal-output .emoji.triangular_flag_on_post,.cmd .emoji.triangular_flag_on_post{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6a9.png);}
.terminal-output .emoji.door,.cmd .emoji.door{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6aa.png);}
.terminal-output .emoji.no_entry_sign,.cmd .emoji.no_entry_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ab.png);}
.terminal-output .emoji.smoking,.cmd .emoji.smoking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ac.png);}
.terminal-output .emoji.no_smoking,.cmd .emoji.no_smoking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ad.png);}
.terminal-output .emoji.put_litter_in_its_place,.cmd .emoji.put_litter_in_its_place{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ae.png);}
.terminal-output .emoji.do_not_litter,.cmd .emoji.do_not_litter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6af.png);}
.terminal-output .emoji.potable_water,.cmd .emoji.potable_water{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b0.png);}
.terminal-output .emoji.non-potable_water,.cmd .emoji.non-potable_water{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b1.png);}
.terminal-output .emoji.bike,.cmd .emoji.bike{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b2.png);}
.terminal-output .emoji.no_bicycles,.cmd .emoji.no_bicycles{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b3.png);}
.terminal-output .emoji.woman-biking,.cmd .emoji.woman-biking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-biking-var-0,.cmd .emoji.woman-biking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-biking-var-1,.cmd .emoji.woman-biking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-biking-var-2,.cmd .emoji.woman-biking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-biking-var-3,.cmd .emoji.woman-biking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-biking-var-4,.cmd .emoji.woman-biking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-biking,.cmd .emoji.man-biking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-200d-2642-fe0f.png);}
.terminal-output .emoji.man-biking-var-0,.cmd .emoji.man-biking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-biking-var-1,.cmd .emoji.man-biking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-biking-var-2,.cmd .emoji.man-biking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-biking-var-3,.cmd .emoji.man-biking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-biking-var-4,.cmd .emoji.man-biking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.bicyclist,.cmd .emoji.bicyclist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4.png);}
.terminal-output .emoji.bicyclist-var-0,.cmd .emoji.bicyclist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fb.png);}
.terminal-output .emoji.bicyclist-var-1,.cmd .emoji.bicyclist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fc.png);}
.terminal-output .emoji.bicyclist-var-2,.cmd .emoji.bicyclist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fd.png);}
.terminal-output .emoji.bicyclist-var-3,.cmd .emoji.bicyclist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3fe.png);}
.terminal-output .emoji.bicyclist-var-4,.cmd .emoji.bicyclist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b4-1f3ff.png);}
.terminal-output .emoji.woman-mountain-biking,.cmd .emoji.woman-mountain-biking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-mountain-biking-var-0,.cmd .emoji.woman-mountain-biking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-mountain-biking-var-1,.cmd .emoji.woman-mountain-biking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-mountain-biking-var-2,.cmd .emoji.woman-mountain-biking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-mountain-biking-var-3,.cmd .emoji.woman-mountain-biking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-mountain-biking-var-4,.cmd .emoji.woman-mountain-biking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-mountain-biking,.cmd .emoji.man-mountain-biking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-200d-2642-fe0f.png);}
.terminal-output .emoji.man-mountain-biking-var-0,.cmd .emoji.man-mountain-biking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-mountain-biking-var-1,.cmd .emoji.man-mountain-biking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-mountain-biking-var-2,.cmd .emoji.man-mountain-biking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-mountain-biking-var-3,.cmd .emoji.man-mountain-biking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-mountain-biking-var-4,.cmd .emoji.man-mountain-biking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.mountain_bicyclist,.cmd .emoji.mountain_bicyclist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5.png);}
.terminal-output .emoji.mountain_bicyclist-var-0,.cmd .emoji.mountain_bicyclist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fb.png);}
.terminal-output .emoji.mountain_bicyclist-var-1,.cmd .emoji.mountain_bicyclist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fc.png);}
.terminal-output .emoji.mountain_bicyclist-var-2,.cmd .emoji.mountain_bicyclist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fd.png);}
.terminal-output .emoji.mountain_bicyclist-var-3,.cmd .emoji.mountain_bicyclist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3fe.png);}
.terminal-output .emoji.mountain_bicyclist-var-4,.cmd .emoji.mountain_bicyclist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b5-1f3ff.png);}
.terminal-output .emoji.woman-walking,.cmd .emoji.woman-walking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-walking-var-0,.cmd .emoji.woman-walking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-walking-var-1,.cmd .emoji.woman-walking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-walking-var-2,.cmd .emoji.woman-walking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-walking-var-3,.cmd .emoji.woman-walking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-walking-var-4,.cmd .emoji.woman-walking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-walking,.cmd .emoji.man-walking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-200d-2642-fe0f.png);}
.terminal-output .emoji.man-walking-var-0,.cmd .emoji.man-walking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-walking-var-1,.cmd .emoji.man-walking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-walking-var-2,.cmd .emoji.man-walking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-walking-var-3,.cmd .emoji.man-walking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-walking-var-4,.cmd .emoji.man-walking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.walking,.cmd .emoji.walking{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6.png);}
.terminal-output .emoji.walking-var-0,.cmd .emoji.walking-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fb.png);}
.terminal-output .emoji.walking-var-1,.cmd .emoji.walking-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fc.png);}
.terminal-output .emoji.walking-var-2,.cmd .emoji.walking-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fd.png);}
.terminal-output .emoji.walking-var-3,.cmd .emoji.walking-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3fe.png);}
.terminal-output .emoji.walking-var-4,.cmd .emoji.walking-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b6-1f3ff.png);}
.terminal-output .emoji.no_pedestrians,.cmd .emoji.no_pedestrians{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b7.png);}
.terminal-output .emoji.children_crossing,.cmd .emoji.children_crossing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b8.png);}
.terminal-output .emoji.mens,.cmd .emoji.mens{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6b9.png);}
.terminal-output .emoji.womens,.cmd .emoji.womens{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ba.png);}
.terminal-output .emoji.restroom,.cmd .emoji.restroom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6bb.png);}
.terminal-output .emoji.baby_symbol,.cmd .emoji.baby_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6bc.png);}
.terminal-output .emoji.toilet,.cmd .emoji.toilet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6bd.png);}
.terminal-output .emoji.wc,.cmd .emoji.wc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6be.png);}
.terminal-output .emoji.shower,.cmd .emoji.shower{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6bf.png);}
.terminal-output .emoji.bath,.cmd .emoji.bath{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0.png);}
.terminal-output .emoji.bath-var-0,.cmd .emoji.bath-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0-1f3fb.png);}
.terminal-output .emoji.bath-var-1,.cmd .emoji.bath-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0-1f3fc.png);}
.terminal-output .emoji.bath-var-2,.cmd .emoji.bath-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0-1f3fd.png);}
.terminal-output .emoji.bath-var-3,.cmd .emoji.bath-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0-1f3fe.png);}
.terminal-output .emoji.bath-var-4,.cmd .emoji.bath-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c0-1f3ff.png);}
.terminal-output .emoji.bathtub,.cmd .emoji.bathtub{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c1.png);}
.terminal-output .emoji.passport_control,.cmd .emoji.passport_control{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c2.png);}
.terminal-output .emoji.customs,.cmd .emoji.customs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c3.png);}
.terminal-output .emoji.baggage_claim,.cmd .emoji.baggage_claim{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c4.png);}
.terminal-output .emoji.left_luggage,.cmd .emoji.left_luggage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6c5.png);}
.terminal-output .emoji.couch_and_lamp,.cmd .emoji.couch_and_lamp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cb-fe0f.png);}
.terminal-output .emoji.sleeping_accommodation,.cmd .emoji.sleeping_accommodation{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc.png);}
.terminal-output .emoji.sleeping_accommodation-var-0,.cmd .emoji.sleeping_accommodation-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc-1f3fb.png);}
.terminal-output .emoji.sleeping_accommodation-var-1,.cmd .emoji.sleeping_accommodation-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc-1f3fc.png);}
.terminal-output .emoji.sleeping_accommodation-var-2,.cmd .emoji.sleeping_accommodation-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc-1f3fd.png);}
.terminal-output .emoji.sleeping_accommodation-var-3,.cmd .emoji.sleeping_accommodation-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc-1f3fe.png);}
.terminal-output .emoji.sleeping_accommodation-var-4,.cmd .emoji.sleeping_accommodation-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cc-1f3ff.png);}
.terminal-output .emoji.shopping_bags,.cmd .emoji.shopping_bags{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cd-fe0f.png);}
.terminal-output .emoji.bellhop_bell,.cmd .emoji.bellhop_bell{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ce-fe0f.png);}
.terminal-output .emoji.bed,.cmd .emoji.bed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6cf-fe0f.png);}
.terminal-output .emoji.place_of_worship,.cmd .emoji.place_of_worship{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d0.png);}
.terminal-output .emoji.octagonal_sign,.cmd .emoji.octagonal_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d1.png);}
.terminal-output .emoji.shopping_trolley,.cmd .emoji.shopping_trolley{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d2.png);}
.terminal-output .emoji.hindu_temple,.cmd .emoji.hindu_temple{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d5.png);}
.terminal-output .emoji.hut,.cmd .emoji.hut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d6.png);}
.terminal-output .emoji.elevator,.cmd .emoji.elevator{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6d7.png);}
.terminal-output .emoji.playground_slide,.cmd .emoji.playground_slide{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6dd.png);}
.terminal-output .emoji.wheel,.cmd .emoji.wheel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6de.png);}
.terminal-output .emoji.ring_buoy,.cmd .emoji.ring_buoy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6df.png);}
.terminal-output .emoji.hammer_and_wrench,.cmd .emoji.hammer_and_wrench{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e0-fe0f.png);}
.terminal-output .emoji.shield,.cmd .emoji.shield{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e1-fe0f.png);}
.terminal-output .emoji.oil_drum,.cmd .emoji.oil_drum{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e2-fe0f.png);}
.terminal-output .emoji.motorway,.cmd .emoji.motorway{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e3-fe0f.png);}
.terminal-output .emoji.railway_track,.cmd .emoji.railway_track{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e4-fe0f.png);}
.terminal-output .emoji.motor_boat,.cmd .emoji.motor_boat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e5-fe0f.png);}
.terminal-output .emoji.small_airplane,.cmd .emoji.small_airplane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6e9-fe0f.png);}
.terminal-output .emoji.airplane_departure,.cmd .emoji.airplane_departure{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6eb.png);}
.terminal-output .emoji.airplane_arriving,.cmd .emoji.airplane_arriving{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6ec.png);}
.terminal-output .emoji.satellite,.cmd .emoji.satellite{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f0-fe0f.png);}
.terminal-output .emoji.passenger_ship,.cmd .emoji.passenger_ship{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f3-fe0f.png);}
.terminal-output .emoji.scooter,.cmd .emoji.scooter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f4.png);}
.terminal-output .emoji.motor_scooter,.cmd .emoji.motor_scooter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f5.png);}
.terminal-output .emoji.canoe,.cmd .emoji.canoe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f6.png);}
.terminal-output .emoji.sled,.cmd .emoji.sled{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f7.png);}
.terminal-output .emoji.flying_saucer,.cmd .emoji.flying_saucer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f8.png);}
.terminal-output .emoji.skateboard,.cmd .emoji.skateboard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6f9.png);}
.terminal-output .emoji.auto_rickshaw,.cmd .emoji.auto_rickshaw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6fa.png);}
.terminal-output .emoji.pickup_truck,.cmd .emoji.pickup_truck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6fb.png);}
.terminal-output .emoji.roller_skate,.cmd .emoji.roller_skate{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f6fc.png);}
.terminal-output .emoji.large_orange_circle,.cmd .emoji.large_orange_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e0.png);}
.terminal-output .emoji.large_yellow_circle,.cmd .emoji.large_yellow_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e1.png);}
.terminal-output .emoji.large_green_circle,.cmd .emoji.large_green_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e2.png);}
.terminal-output .emoji.large_purple_circle,.cmd .emoji.large_purple_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e3.png);}
.terminal-output .emoji.large_brown_circle,.cmd .emoji.large_brown_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e4.png);}
.terminal-output .emoji.large_red_square,.cmd .emoji.large_red_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e5.png);}
.terminal-output .emoji.large_blue_square,.cmd .emoji.large_blue_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e6.png);}
.terminal-output .emoji.large_orange_square,.cmd .emoji.large_orange_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e7.png);}
.terminal-output .emoji.large_yellow_square,.cmd .emoji.large_yellow_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e8.png);}
.terminal-output .emoji.large_green_square,.cmd .emoji.large_green_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7e9.png);}
.terminal-output .emoji.large_purple_square,.cmd .emoji.large_purple_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7ea.png);}
.terminal-output .emoji.large_brown_square,.cmd .emoji.large_brown_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7eb.png);}
.terminal-output .emoji.heavy_equals_sign,.cmd .emoji.heavy_equals_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f7f0.png);}
.terminal-output .emoji.pinched_fingers,.cmd .emoji.pinched_fingers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c.png);}
.terminal-output .emoji.pinched_fingers-var-0,.cmd .emoji.pinched_fingers-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c-1f3fb.png);}
.terminal-output .emoji.pinched_fingers-var-1,.cmd .emoji.pinched_fingers-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c-1f3fc.png);}
.terminal-output .emoji.pinched_fingers-var-2,.cmd .emoji.pinched_fingers-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c-1f3fd.png);}
.terminal-output .emoji.pinched_fingers-var-3,.cmd .emoji.pinched_fingers-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c-1f3fe.png);}
.terminal-output .emoji.pinched_fingers-var-4,.cmd .emoji.pinched_fingers-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90c-1f3ff.png);}
.terminal-output .emoji.white_heart,.cmd .emoji.white_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90d.png);}
.terminal-output .emoji.brown_heart,.cmd .emoji.brown_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90e.png);}
.terminal-output .emoji.pinching_hand,.cmd .emoji.pinching_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f.png);}
.terminal-output .emoji.pinching_hand-var-0,.cmd .emoji.pinching_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f-1f3fb.png);}
.terminal-output .emoji.pinching_hand-var-1,.cmd .emoji.pinching_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f-1f3fc.png);}
.terminal-output .emoji.pinching_hand-var-2,.cmd .emoji.pinching_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f-1f3fd.png);}
.terminal-output .emoji.pinching_hand-var-3,.cmd .emoji.pinching_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f-1f3fe.png);}
.terminal-output .emoji.pinching_hand-var-4,.cmd .emoji.pinching_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f90f-1f3ff.png);}
.terminal-output .emoji.zipper_mouth_face,.cmd .emoji.zipper_mouth_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f910.png);}
.terminal-output .emoji.money_mouth_face,.cmd .emoji.money_mouth_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f911.png);}
.terminal-output .emoji.face_with_thermometer,.cmd .emoji.face_with_thermometer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f912.png);}
.terminal-output .emoji.nerd_face,.cmd .emoji.nerd_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f913.png);}
.terminal-output .emoji.thinking_face,.cmd .emoji.thinking_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f914.png);}
.terminal-output .emoji.face_with_head_bandage,.cmd .emoji.face_with_head_bandage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f915.png);}
.terminal-output .emoji.robot_face,.cmd .emoji.robot_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f916.png);}
.terminal-output .emoji.hugging_face,.cmd .emoji.hugging_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f917.png);}
.terminal-output .emoji.the_horns,.cmd .emoji.the_horns{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918.png);}
.terminal-output .emoji.the_horns-var-0,.cmd .emoji.the_horns-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918-1f3fb.png);}
.terminal-output .emoji.the_horns-var-1,.cmd .emoji.the_horns-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918-1f3fc.png);}
.terminal-output .emoji.the_horns-var-2,.cmd .emoji.the_horns-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918-1f3fd.png);}
.terminal-output .emoji.the_horns-var-3,.cmd .emoji.the_horns-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918-1f3fe.png);}
.terminal-output .emoji.the_horns-var-4,.cmd .emoji.the_horns-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f918-1f3ff.png);}
.terminal-output .emoji.call_me_hand,.cmd .emoji.call_me_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919.png);}
.terminal-output .emoji.call_me_hand-var-0,.cmd .emoji.call_me_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919-1f3fb.png);}
.terminal-output .emoji.call_me_hand-var-1,.cmd .emoji.call_me_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919-1f3fc.png);}
.terminal-output .emoji.call_me_hand-var-2,.cmd .emoji.call_me_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919-1f3fd.png);}
.terminal-output .emoji.call_me_hand-var-3,.cmd .emoji.call_me_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919-1f3fe.png);}
.terminal-output .emoji.call_me_hand-var-4,.cmd .emoji.call_me_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f919-1f3ff.png);}
.terminal-output .emoji.raised_back_of_hand,.cmd .emoji.raised_back_of_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a.png);}
.terminal-output .emoji.raised_back_of_hand-var-0,.cmd .emoji.raised_back_of_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a-1f3fb.png);}
.terminal-output .emoji.raised_back_of_hand-var-1,.cmd .emoji.raised_back_of_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a-1f3fc.png);}
.terminal-output .emoji.raised_back_of_hand-var-2,.cmd .emoji.raised_back_of_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a-1f3fd.png);}
.terminal-output .emoji.raised_back_of_hand-var-3,.cmd .emoji.raised_back_of_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a-1f3fe.png);}
.terminal-output .emoji.raised_back_of_hand-var-4,.cmd .emoji.raised_back_of_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91a-1f3ff.png);}
.terminal-output .emoji.left-facing_fist,.cmd .emoji.left-facing_fist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b.png);}
.terminal-output .emoji.left-facing_fist-var-0,.cmd .emoji.left-facing_fist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b-1f3fb.png);}
.terminal-output .emoji.left-facing_fist-var-1,.cmd .emoji.left-facing_fist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b-1f3fc.png);}
.terminal-output .emoji.left-facing_fist-var-2,.cmd .emoji.left-facing_fist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b-1f3fd.png);}
.terminal-output .emoji.left-facing_fist-var-3,.cmd .emoji.left-facing_fist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b-1f3fe.png);}
.terminal-output .emoji.left-facing_fist-var-4,.cmd .emoji.left-facing_fist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91b-1f3ff.png);}
.terminal-output .emoji.right-facing_fist,.cmd .emoji.right-facing_fist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c.png);}
.terminal-output .emoji.right-facing_fist-var-0,.cmd .emoji.right-facing_fist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c-1f3fb.png);}
.terminal-output .emoji.right-facing_fist-var-1,.cmd .emoji.right-facing_fist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c-1f3fc.png);}
.terminal-output .emoji.right-facing_fist-var-2,.cmd .emoji.right-facing_fist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c-1f3fd.png);}
.terminal-output .emoji.right-facing_fist-var-3,.cmd .emoji.right-facing_fist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c-1f3fe.png);}
.terminal-output .emoji.right-facing_fist-var-4,.cmd .emoji.right-facing_fist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91c-1f3ff.png);}
.terminal-output .emoji.handshake,.cmd .emoji.handshake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d.png);}
.terminal-output .emoji.handshake-var-0,.cmd .emoji.handshake-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d-1f3fb.png);}
.terminal-output .emoji.handshake-var-1,.cmd .emoji.handshake-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d-1f3fc.png);}
.terminal-output .emoji.handshake-var-2,.cmd .emoji.handshake-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d-1f3fd.png);}
.terminal-output .emoji.handshake-var-3,.cmd .emoji.handshake-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d-1f3fe.png);}
.terminal-output .emoji.handshake-var-4,.cmd .emoji.handshake-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91d-1f3ff.png);}
.terminal-output .emoji.handshake-var-5,.cmd .emoji.handshake-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fb-200d-1faf2-1f3fc.png);}
.terminal-output .emoji.handshake-var-6,.cmd .emoji.handshake-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fb-200d-1faf2-1f3fd.png);}
.terminal-output .emoji.handshake-var-7,.cmd .emoji.handshake-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fb-200d-1faf2-1f3fe.png);}
.terminal-output .emoji.handshake-var-8,.cmd .emoji.handshake-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fb-200d-1faf2-1f3ff.png);}
.terminal-output .emoji.handshake-var-9,.cmd .emoji.handshake-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fc-200d-1faf2-1f3fb.png);}
.terminal-output .emoji.handshake-var-10,.cmd .emoji.handshake-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fc-200d-1faf2-1f3fd.png);}
.terminal-output .emoji.handshake-var-11,.cmd .emoji.handshake-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fc-200d-1faf2-1f3fe.png);}
.terminal-output .emoji.handshake-var-12,.cmd .emoji.handshake-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fc-200d-1faf2-1f3ff.png);}
.terminal-output .emoji.handshake-var-13,.cmd .emoji.handshake-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fd-200d-1faf2-1f3fb.png);}
.terminal-output .emoji.handshake-var-14,.cmd .emoji.handshake-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fd-200d-1faf2-1f3fc.png);}
.terminal-output .emoji.handshake-var-15,.cmd .emoji.handshake-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fd-200d-1faf2-1f3fe.png);}
.terminal-output .emoji.handshake-var-16,.cmd .emoji.handshake-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fd-200d-1faf2-1f3ff.png);}
.terminal-output .emoji.handshake-var-17,.cmd .emoji.handshake-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fe-200d-1faf2-1f3fb.png);}
.terminal-output .emoji.handshake-var-18,.cmd .emoji.handshake-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fe-200d-1faf2-1f3fc.png);}
.terminal-output .emoji.handshake-var-19,.cmd .emoji.handshake-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fe-200d-1faf2-1f3fd.png);}
.terminal-output .emoji.handshake-var-20,.cmd .emoji.handshake-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fe-200d-1faf2-1f3ff.png);}
.terminal-output .emoji.handshake-var-21,.cmd .emoji.handshake-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3ff-200d-1faf2-1f3fb.png);}
.terminal-output .emoji.handshake-var-22,.cmd .emoji.handshake-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3ff-200d-1faf2-1f3fc.png);}
.terminal-output .emoji.handshake-var-23,.cmd .emoji.handshake-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3ff-200d-1faf2-1f3fd.png);}
.terminal-output .emoji.handshake-var-24,.cmd .emoji.handshake-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3ff-200d-1faf2-1f3fe.png);}
.terminal-output .emoji.crossed_fingers,.cmd .emoji.crossed_fingers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e.png);}
.terminal-output .emoji.crossed_fingers-var-0,.cmd .emoji.crossed_fingers-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e-1f3fb.png);}
.terminal-output .emoji.crossed_fingers-var-1,.cmd .emoji.crossed_fingers-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e-1f3fc.png);}
.terminal-output .emoji.crossed_fingers-var-2,.cmd .emoji.crossed_fingers-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e-1f3fd.png);}
.terminal-output .emoji.crossed_fingers-var-3,.cmd .emoji.crossed_fingers-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e-1f3fe.png);}
.terminal-output .emoji.crossed_fingers-var-4,.cmd .emoji.crossed_fingers-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91e-1f3ff.png);}
.terminal-output .emoji.i_love_you_hand_sign,.cmd .emoji.i_love_you_hand_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f.png);}
.terminal-output .emoji.i_love_you_hand_sign-var-0,.cmd .emoji.i_love_you_hand_sign-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f-1f3fb.png);}
.terminal-output .emoji.i_love_you_hand_sign-var-1,.cmd .emoji.i_love_you_hand_sign-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f-1f3fc.png);}
.terminal-output .emoji.i_love_you_hand_sign-var-2,.cmd .emoji.i_love_you_hand_sign-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f-1f3fd.png);}
.terminal-output .emoji.i_love_you_hand_sign-var-3,.cmd .emoji.i_love_you_hand_sign-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f-1f3fe.png);}
.terminal-output .emoji.i_love_you_hand_sign-var-4,.cmd .emoji.i_love_you_hand_sign-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f91f-1f3ff.png);}
.terminal-output .emoji.face_with_cowboy_hat,.cmd .emoji.face_with_cowboy_hat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f920.png);}
.terminal-output .emoji.clown_face,.cmd .emoji.clown_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f921.png);}
.terminal-output .emoji.nauseated_face,.cmd .emoji.nauseated_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f922.png);}
.terminal-output .emoji.rolling_on_the_floor_laughing,.cmd .emoji.rolling_on_the_floor_laughing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f923.png);}
.terminal-output .emoji.drooling_face,.cmd .emoji.drooling_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f924.png);}
.terminal-output .emoji.lying_face,.cmd .emoji.lying_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f925.png);}
.terminal-output .emoji.woman-facepalming,.cmd .emoji.woman-facepalming{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-facepalming-var-0,.cmd .emoji.woman-facepalming-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-facepalming-var-1,.cmd .emoji.woman-facepalming-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-facepalming-var-2,.cmd .emoji.woman-facepalming-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-facepalming-var-3,.cmd .emoji.woman-facepalming-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-facepalming-var-4,.cmd .emoji.woman-facepalming-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-facepalming,.cmd .emoji.man-facepalming{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-200d-2642-fe0f.png);}
.terminal-output .emoji.man-facepalming-var-0,.cmd .emoji.man-facepalming-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-facepalming-var-1,.cmd .emoji.man-facepalming-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-facepalming-var-2,.cmd .emoji.man-facepalming-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-facepalming-var-3,.cmd .emoji.man-facepalming-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-facepalming-var-4,.cmd .emoji.man-facepalming-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.face_palm,.cmd .emoji.face_palm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926.png);}
.terminal-output .emoji.face_palm-var-0,.cmd .emoji.face_palm-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fb.png);}
.terminal-output .emoji.face_palm-var-1,.cmd .emoji.face_palm-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fc.png);}
.terminal-output .emoji.face_palm-var-2,.cmd .emoji.face_palm-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fd.png);}
.terminal-output .emoji.face_palm-var-3,.cmd .emoji.face_palm-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3fe.png);}
.terminal-output .emoji.face_palm-var-4,.cmd .emoji.face_palm-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f926-1f3ff.png);}
.terminal-output .emoji.sneezing_face,.cmd .emoji.sneezing_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f927.png);}
.terminal-output .emoji.face_with_raised_eyebrow,.cmd .emoji.face_with_raised_eyebrow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f928.png);}
.terminal-output .emoji.star-struck,.cmd .emoji.star-struck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f929.png);}
.terminal-output .emoji.zany_face,.cmd .emoji.zany_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92a.png);}
.terminal-output .emoji.shushing_face,.cmd .emoji.shushing_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92b.png);}
.terminal-output .emoji.face_with_symbols_on_mouth,.cmd .emoji.face_with_symbols_on_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92c.png);}
.terminal-output .emoji.face_with_hand_over_mouth,.cmd .emoji.face_with_hand_over_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92d.png);}
.terminal-output .emoji.face_vomiting,.cmd .emoji.face_vomiting{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92e.png);}
.terminal-output .emoji.exploding_head,.cmd .emoji.exploding_head{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f92f.png);}
.terminal-output .emoji.pregnant_woman,.cmd .emoji.pregnant_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930.png);}
.terminal-output .emoji.pregnant_woman-var-0,.cmd .emoji.pregnant_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930-1f3fb.png);}
.terminal-output .emoji.pregnant_woman-var-1,.cmd .emoji.pregnant_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930-1f3fc.png);}
.terminal-output .emoji.pregnant_woman-var-2,.cmd .emoji.pregnant_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930-1f3fd.png);}
.terminal-output .emoji.pregnant_woman-var-3,.cmd .emoji.pregnant_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930-1f3fe.png);}
.terminal-output .emoji.pregnant_woman-var-4,.cmd .emoji.pregnant_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f930-1f3ff.png);}
.terminal-output .emoji.breast-feeding,.cmd .emoji.breast-feeding{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931.png);}
.terminal-output .emoji.breast-feeding-var-0,.cmd .emoji.breast-feeding-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931-1f3fb.png);}
.terminal-output .emoji.breast-feeding-var-1,.cmd .emoji.breast-feeding-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931-1f3fc.png);}
.terminal-output .emoji.breast-feeding-var-2,.cmd .emoji.breast-feeding-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931-1f3fd.png);}
.terminal-output .emoji.breast-feeding-var-3,.cmd .emoji.breast-feeding-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931-1f3fe.png);}
.terminal-output .emoji.breast-feeding-var-4,.cmd .emoji.breast-feeding-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f931-1f3ff.png);}
.terminal-output .emoji.palms_up_together,.cmd .emoji.palms_up_together{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932.png);}
.terminal-output .emoji.palms_up_together-var-0,.cmd .emoji.palms_up_together-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932-1f3fb.png);}
.terminal-output .emoji.palms_up_together-var-1,.cmd .emoji.palms_up_together-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932-1f3fc.png);}
.terminal-output .emoji.palms_up_together-var-2,.cmd .emoji.palms_up_together-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932-1f3fd.png);}
.terminal-output .emoji.palms_up_together-var-3,.cmd .emoji.palms_up_together-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932-1f3fe.png);}
.terminal-output .emoji.palms_up_together-var-4,.cmd .emoji.palms_up_together-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f932-1f3ff.png);}
.terminal-output .emoji.selfie,.cmd .emoji.selfie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933.png);}
.terminal-output .emoji.selfie-var-0,.cmd .emoji.selfie-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933-1f3fb.png);}
.terminal-output .emoji.selfie-var-1,.cmd .emoji.selfie-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933-1f3fc.png);}
.terminal-output .emoji.selfie-var-2,.cmd .emoji.selfie-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933-1f3fd.png);}
.terminal-output .emoji.selfie-var-3,.cmd .emoji.selfie-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933-1f3fe.png);}
.terminal-output .emoji.selfie-var-4,.cmd .emoji.selfie-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f933-1f3ff.png);}
.terminal-output .emoji.prince,.cmd .emoji.prince{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934.png);}
.terminal-output .emoji.prince-var-0,.cmd .emoji.prince-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934-1f3fb.png);}
.terminal-output .emoji.prince-var-1,.cmd .emoji.prince-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934-1f3fc.png);}
.terminal-output .emoji.prince-var-2,.cmd .emoji.prince-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934-1f3fd.png);}
.terminal-output .emoji.prince-var-3,.cmd .emoji.prince-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934-1f3fe.png);}
.terminal-output .emoji.prince-var-4,.cmd .emoji.prince-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f934-1f3ff.png);}
.terminal-output .emoji.woman_in_tuxedo,.cmd .emoji.woman_in_tuxedo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_tuxedo-var-0,.cmd .emoji.woman_in_tuxedo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_tuxedo-var-1,.cmd .emoji.woman_in_tuxedo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_tuxedo-var-2,.cmd .emoji.woman_in_tuxedo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_tuxedo-var-3,.cmd .emoji.woman_in_tuxedo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_tuxedo-var-4,.cmd .emoji.woman_in_tuxedo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo,.cmd .emoji.man_in_tuxedo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo-var-0,.cmd .emoji.man_in_tuxedo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo-var-1,.cmd .emoji.man_in_tuxedo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo-var-2,.cmd .emoji.man_in_tuxedo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo-var-3,.cmd .emoji.man_in_tuxedo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_tuxedo-var-4,.cmd .emoji.man_in_tuxedo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_in_tuxedo,.cmd .emoji.person_in_tuxedo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935.png);}
.terminal-output .emoji.person_in_tuxedo-var-0,.cmd .emoji.person_in_tuxedo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fb.png);}
.terminal-output .emoji.person_in_tuxedo-var-1,.cmd .emoji.person_in_tuxedo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fc.png);}
.terminal-output .emoji.person_in_tuxedo-var-2,.cmd .emoji.person_in_tuxedo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fd.png);}
.terminal-output .emoji.person_in_tuxedo-var-3,.cmd .emoji.person_in_tuxedo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3fe.png);}
.terminal-output .emoji.person_in_tuxedo-var-4,.cmd .emoji.person_in_tuxedo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f935-1f3ff.png);}
.terminal-output .emoji.mrs_claus,.cmd .emoji.mrs_claus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936.png);}
.terminal-output .emoji.mrs_claus-var-0,.cmd .emoji.mrs_claus-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936-1f3fb.png);}
.terminal-output .emoji.mrs_claus-var-1,.cmd .emoji.mrs_claus-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936-1f3fc.png);}
.terminal-output .emoji.mrs_claus-var-2,.cmd .emoji.mrs_claus-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936-1f3fd.png);}
.terminal-output .emoji.mrs_claus-var-3,.cmd .emoji.mrs_claus-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936-1f3fe.png);}
.terminal-output .emoji.mrs_claus-var-4,.cmd .emoji.mrs_claus-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f936-1f3ff.png);}
.terminal-output .emoji.woman-shrugging,.cmd .emoji.woman-shrugging{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-shrugging-var-0,.cmd .emoji.woman-shrugging-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-shrugging-var-1,.cmd .emoji.woman-shrugging-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-shrugging-var-2,.cmd .emoji.woman-shrugging-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-shrugging-var-3,.cmd .emoji.woman-shrugging-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-shrugging-var-4,.cmd .emoji.woman-shrugging-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-shrugging,.cmd .emoji.man-shrugging{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-200d-2642-fe0f.png);}
.terminal-output .emoji.man-shrugging-var-0,.cmd .emoji.man-shrugging-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-shrugging-var-1,.cmd .emoji.man-shrugging-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-shrugging-var-2,.cmd .emoji.man-shrugging-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-shrugging-var-3,.cmd .emoji.man-shrugging-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-shrugging-var-4,.cmd .emoji.man-shrugging-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.shrug,.cmd .emoji.shrug{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937.png);}
.terminal-output .emoji.shrug-var-0,.cmd .emoji.shrug-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fb.png);}
.terminal-output .emoji.shrug-var-1,.cmd .emoji.shrug-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fc.png);}
.terminal-output .emoji.shrug-var-2,.cmd .emoji.shrug-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fd.png);}
.terminal-output .emoji.shrug-var-3,.cmd .emoji.shrug-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3fe.png);}
.terminal-output .emoji.shrug-var-4,.cmd .emoji.shrug-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f937-1f3ff.png);}
.terminal-output .emoji.woman-cartwheeling,.cmd .emoji.woman-cartwheeling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-cartwheeling-var-0,.cmd .emoji.woman-cartwheeling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-cartwheeling-var-1,.cmd .emoji.woman-cartwheeling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-cartwheeling-var-2,.cmd .emoji.woman-cartwheeling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-cartwheeling-var-3,.cmd .emoji.woman-cartwheeling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-cartwheeling-var-4,.cmd .emoji.woman-cartwheeling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-cartwheeling,.cmd .emoji.man-cartwheeling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-200d-2642-fe0f.png);}
.terminal-output .emoji.man-cartwheeling-var-0,.cmd .emoji.man-cartwheeling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-cartwheeling-var-1,.cmd .emoji.man-cartwheeling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-cartwheeling-var-2,.cmd .emoji.man-cartwheeling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-cartwheeling-var-3,.cmd .emoji.man-cartwheeling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-cartwheeling-var-4,.cmd .emoji.man-cartwheeling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_doing_cartwheel,.cmd .emoji.person_doing_cartwheel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938.png);}
.terminal-output .emoji.person_doing_cartwheel-var-0,.cmd .emoji.person_doing_cartwheel-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fb.png);}
.terminal-output .emoji.person_doing_cartwheel-var-1,.cmd .emoji.person_doing_cartwheel-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fc.png);}
.terminal-output .emoji.person_doing_cartwheel-var-2,.cmd .emoji.person_doing_cartwheel-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fd.png);}
.terminal-output .emoji.person_doing_cartwheel-var-3,.cmd .emoji.person_doing_cartwheel-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3fe.png);}
.terminal-output .emoji.person_doing_cartwheel-var-4,.cmd .emoji.person_doing_cartwheel-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f938-1f3ff.png);}
.terminal-output .emoji.woman-juggling,.cmd .emoji.woman-juggling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-juggling-var-0,.cmd .emoji.woman-juggling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-juggling-var-1,.cmd .emoji.woman-juggling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-juggling-var-2,.cmd .emoji.woman-juggling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-juggling-var-3,.cmd .emoji.woman-juggling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-juggling-var-4,.cmd .emoji.woman-juggling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-juggling,.cmd .emoji.man-juggling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-200d-2642-fe0f.png);}
.terminal-output .emoji.man-juggling-var-0,.cmd .emoji.man-juggling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-juggling-var-1,.cmd .emoji.man-juggling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-juggling-var-2,.cmd .emoji.man-juggling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-juggling-var-3,.cmd .emoji.man-juggling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-juggling-var-4,.cmd .emoji.man-juggling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.juggling,.cmd .emoji.juggling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939.png);}
.terminal-output .emoji.juggling-var-0,.cmd .emoji.juggling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fb.png);}
.terminal-output .emoji.juggling-var-1,.cmd .emoji.juggling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fc.png);}
.terminal-output .emoji.juggling-var-2,.cmd .emoji.juggling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fd.png);}
.terminal-output .emoji.juggling-var-3,.cmd .emoji.juggling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3fe.png);}
.terminal-output .emoji.juggling-var-4,.cmd .emoji.juggling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f939-1f3ff.png);}
.terminal-output .emoji.fencer,.cmd .emoji.fencer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93a.png);}
.terminal-output .emoji.woman-wrestling,.cmd .emoji.woman-wrestling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93c-200d-2640-fe0f.png);}
.terminal-output .emoji.man-wrestling,.cmd .emoji.man-wrestling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93c-200d-2642-fe0f.png);}
.terminal-output .emoji.wrestlers,.cmd .emoji.wrestlers{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93c.png);}
.terminal-output .emoji.woman-playing-water-polo,.cmd .emoji.woman-playing-water-polo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-water-polo-var-0,.cmd .emoji.woman-playing-water-polo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-water-polo-var-1,.cmd .emoji.woman-playing-water-polo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-water-polo-var-2,.cmd .emoji.woman-playing-water-polo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-water-polo-var-3,.cmd .emoji.woman-playing-water-polo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-water-polo-var-4,.cmd .emoji.woman-playing-water-polo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo,.cmd .emoji.man-playing-water-polo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo-var-0,.cmd .emoji.man-playing-water-polo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo-var-1,.cmd .emoji.man-playing-water-polo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo-var-2,.cmd .emoji.man-playing-water-polo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo-var-3,.cmd .emoji.man-playing-water-polo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-water-polo-var-4,.cmd .emoji.man-playing-water-polo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.water_polo,.cmd .emoji.water_polo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d.png);}
.terminal-output .emoji.water_polo-var-0,.cmd .emoji.water_polo-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fb.png);}
.terminal-output .emoji.water_polo-var-1,.cmd .emoji.water_polo-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fc.png);}
.terminal-output .emoji.water_polo-var-2,.cmd .emoji.water_polo-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fd.png);}
.terminal-output .emoji.water_polo-var-3,.cmd .emoji.water_polo-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3fe.png);}
.terminal-output .emoji.water_polo-var-4,.cmd .emoji.water_polo-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93d-1f3ff.png);}
.terminal-output .emoji.woman-playing-handball,.cmd .emoji.woman-playing-handball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-handball-var-0,.cmd .emoji.woman-playing-handball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-handball-var-1,.cmd .emoji.woman-playing-handball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-handball-var-2,.cmd .emoji.woman-playing-handball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-handball-var-3,.cmd .emoji.woman-playing-handball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-playing-handball-var-4,.cmd .emoji.woman-playing-handball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-playing-handball,.cmd .emoji.man-playing-handball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-handball-var-0,.cmd .emoji.man-playing-handball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-handball-var-1,.cmd .emoji.man-playing-handball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-handball-var-2,.cmd .emoji.man-playing-handball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-handball-var-3,.cmd .emoji.man-playing-handball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-playing-handball-var-4,.cmd .emoji.man-playing-handball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.handball,.cmd .emoji.handball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e.png);}
.terminal-output .emoji.handball-var-0,.cmd .emoji.handball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fb.png);}
.terminal-output .emoji.handball-var-1,.cmd .emoji.handball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fc.png);}
.terminal-output .emoji.handball-var-2,.cmd .emoji.handball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fd.png);}
.terminal-output .emoji.handball-var-3,.cmd .emoji.handball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3fe.png);}
.terminal-output .emoji.handball-var-4,.cmd .emoji.handball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93e-1f3ff.png);}
.terminal-output .emoji.diving_mask,.cmd .emoji.diving_mask{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f93f.png);}
.terminal-output .emoji.wilted_flower,.cmd .emoji.wilted_flower{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f940.png);}
.terminal-output .emoji.drum_with_drumsticks,.cmd .emoji.drum_with_drumsticks{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f941.png);}
.terminal-output .emoji.clinking_glasses,.cmd .emoji.clinking_glasses{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f942.png);}
.terminal-output .emoji.tumbler_glass,.cmd .emoji.tumbler_glass{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f943.png);}
.terminal-output .emoji.spoon,.cmd .emoji.spoon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f944.png);}
.terminal-output .emoji.goal_net,.cmd .emoji.goal_net{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f945.png);}
.terminal-output .emoji.first_place_medal,.cmd .emoji.first_place_medal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f947.png);}
.terminal-output .emoji.second_place_medal,.cmd .emoji.second_place_medal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f948.png);}
.terminal-output .emoji.third_place_medal,.cmd .emoji.third_place_medal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f949.png);}
.terminal-output .emoji.boxing_glove,.cmd .emoji.boxing_glove{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94a.png);}
.terminal-output .emoji.martial_arts_uniform,.cmd .emoji.martial_arts_uniform{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94b.png);}
.terminal-output .emoji.curling_stone,.cmd .emoji.curling_stone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94c.png);}
.terminal-output .emoji.lacrosse,.cmd .emoji.lacrosse{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94d.png);}
.terminal-output .emoji.softball,.cmd .emoji.softball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94e.png);}
.terminal-output .emoji.flying_disc,.cmd .emoji.flying_disc{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f94f.png);}
.terminal-output .emoji.croissant,.cmd .emoji.croissant{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f950.png);}
.terminal-output .emoji.avocado,.cmd .emoji.avocado{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f951.png);}
.terminal-output .emoji.cucumber,.cmd .emoji.cucumber{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f952.png);}
.terminal-output .emoji.bacon,.cmd .emoji.bacon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f953.png);}
.terminal-output .emoji.potato,.cmd .emoji.potato{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f954.png);}
.terminal-output .emoji.carrot,.cmd .emoji.carrot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f955.png);}
.terminal-output .emoji.baguette_bread,.cmd .emoji.baguette_bread{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f956.png);}
.terminal-output .emoji.green_salad,.cmd .emoji.green_salad{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f957.png);}
.terminal-output .emoji.shallow_pan_of_food,.cmd .emoji.shallow_pan_of_food{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f958.png);}
.terminal-output .emoji.stuffed_flatbread,.cmd .emoji.stuffed_flatbread{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f959.png);}
.terminal-output .emoji.egg,.cmd .emoji.egg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95a.png);}
.terminal-output .emoji.glass_of_milk,.cmd .emoji.glass_of_milk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95b.png);}
.terminal-output .emoji.peanuts,.cmd .emoji.peanuts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95c.png);}
.terminal-output .emoji.kiwifruit,.cmd .emoji.kiwifruit{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95d.png);}
.terminal-output .emoji.pancakes,.cmd .emoji.pancakes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95e.png);}
.terminal-output .emoji.dumpling,.cmd .emoji.dumpling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f95f.png);}
.terminal-output .emoji.fortune_cookie,.cmd .emoji.fortune_cookie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f960.png);}
.terminal-output .emoji.takeout_box,.cmd .emoji.takeout_box{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f961.png);}
.terminal-output .emoji.chopsticks,.cmd .emoji.chopsticks{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f962.png);}
.terminal-output .emoji.bowl_with_spoon,.cmd .emoji.bowl_with_spoon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f963.png);}
.terminal-output .emoji.cup_with_straw,.cmd .emoji.cup_with_straw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f964.png);}
.terminal-output .emoji.coconut,.cmd .emoji.coconut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f965.png);}
.terminal-output .emoji.broccoli,.cmd .emoji.broccoli{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f966.png);}
.terminal-output .emoji.pie,.cmd .emoji.pie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f967.png);}
.terminal-output .emoji.pretzel,.cmd .emoji.pretzel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f968.png);}
.terminal-output .emoji.cut_of_meat,.cmd .emoji.cut_of_meat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f969.png);}
.terminal-output .emoji.sandwich,.cmd .emoji.sandwich{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96a.png);}
.terminal-output .emoji.canned_food,.cmd .emoji.canned_food{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96b.png);}
.terminal-output .emoji.leafy_green,.cmd .emoji.leafy_green{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96c.png);}
.terminal-output .emoji.mango,.cmd .emoji.mango{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96d.png);}
.terminal-output .emoji.moon_cake,.cmd .emoji.moon_cake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96e.png);}
.terminal-output .emoji.bagel,.cmd .emoji.bagel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f96f.png);}
.terminal-output .emoji.smiling_face_with_3_hearts,.cmd .emoji.smiling_face_with_3_hearts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f970.png);}
.terminal-output .emoji.yawning_face,.cmd .emoji.yawning_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f971.png);}
.terminal-output .emoji.smiling_face_with_tear,.cmd .emoji.smiling_face_with_tear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f972.png);}
.terminal-output .emoji.partying_face,.cmd .emoji.partying_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f973.png);}
.terminal-output .emoji.woozy_face,.cmd .emoji.woozy_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f974.png);}
.terminal-output .emoji.hot_face,.cmd .emoji.hot_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f975.png);}
.terminal-output .emoji.cold_face,.cmd .emoji.cold_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f976.png);}
.terminal-output .emoji.ninja,.cmd .emoji.ninja{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977.png);}
.terminal-output .emoji.ninja-var-0,.cmd .emoji.ninja-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977-1f3fb.png);}
.terminal-output .emoji.ninja-var-1,.cmd .emoji.ninja-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977-1f3fc.png);}
.terminal-output .emoji.ninja-var-2,.cmd .emoji.ninja-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977-1f3fd.png);}
.terminal-output .emoji.ninja-var-3,.cmd .emoji.ninja-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977-1f3fe.png);}
.terminal-output .emoji.ninja-var-4,.cmd .emoji.ninja-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f977-1f3ff.png);}
.terminal-output .emoji.disguised_face,.cmd .emoji.disguised_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f978.png);}
.terminal-output .emoji.face_holding_back_tears,.cmd .emoji.face_holding_back_tears{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f979.png);}
.terminal-output .emoji.pleading_face,.cmd .emoji.pleading_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97a.png);}
.terminal-output .emoji.sari,.cmd .emoji.sari{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97b.png);}
.terminal-output .emoji.lab_coat,.cmd .emoji.lab_coat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97c.png);}
.terminal-output .emoji.goggles,.cmd .emoji.goggles{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97d.png);}
.terminal-output .emoji.hiking_boot,.cmd .emoji.hiking_boot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97e.png);}
.terminal-output .emoji.womans_flat_shoe,.cmd .emoji.womans_flat_shoe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f97f.png);}
.terminal-output .emoji.crab,.cmd .emoji.crab{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f980.png);}
.terminal-output .emoji.lion_face,.cmd .emoji.lion_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f981.png);}
.terminal-output .emoji.scorpion,.cmd .emoji.scorpion{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f982.png);}
.terminal-output .emoji.turkey,.cmd .emoji.turkey{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f983.png);}
.terminal-output .emoji.unicorn_face,.cmd .emoji.unicorn_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f984.png);}
.terminal-output .emoji.eagle,.cmd .emoji.eagle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f985.png);}
.terminal-output .emoji.duck,.cmd .emoji.duck{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f986.png);}
.terminal-output .emoji.bat,.cmd .emoji.bat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f987.png);}
.terminal-output .emoji.shark,.cmd .emoji.shark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f988.png);}
.terminal-output .emoji.owl,.cmd .emoji.owl{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f989.png);}
.terminal-output .emoji.fox_face,.cmd .emoji.fox_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98a.png);}
.terminal-output .emoji.butterfly,.cmd .emoji.butterfly{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98b.png);}
.terminal-output .emoji.deer,.cmd .emoji.deer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98c.png);}
.terminal-output .emoji.gorilla,.cmd .emoji.gorilla{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98d.png);}
.terminal-output .emoji.lizard,.cmd .emoji.lizard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98e.png);}
.terminal-output .emoji.rhinoceros,.cmd .emoji.rhinoceros{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f98f.png);}
.terminal-output .emoji.shrimp,.cmd .emoji.shrimp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f990.png);}
.terminal-output .emoji.squid,.cmd .emoji.squid{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f991.png);}
.terminal-output .emoji.giraffe_face,.cmd .emoji.giraffe_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f992.png);}
.terminal-output .emoji.zebra_face,.cmd .emoji.zebra_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f993.png);}
.terminal-output .emoji.hedgehog,.cmd .emoji.hedgehog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f994.png);}
.terminal-output .emoji.sauropod,.cmd .emoji.sauropod{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f995.png);}
.terminal-output .emoji.t-rex,.cmd .emoji.t-rex{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f996.png);}
.terminal-output .emoji.cricket,.cmd .emoji.cricket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f997.png);}
.terminal-output .emoji.kangaroo,.cmd .emoji.kangaroo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f998.png);}
.terminal-output .emoji.llama,.cmd .emoji.llama{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f999.png);}
.terminal-output .emoji.peacock,.cmd .emoji.peacock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99a.png);}
.terminal-output .emoji.hippopotamus,.cmd .emoji.hippopotamus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99b.png);}
.terminal-output .emoji.parrot,.cmd .emoji.parrot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99c.png);}
.terminal-output .emoji.raccoon,.cmd .emoji.raccoon{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99d.png);}
.terminal-output .emoji.lobster,.cmd .emoji.lobster{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99e.png);}
.terminal-output .emoji.mosquito,.cmd .emoji.mosquito{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f99f.png);}
.terminal-output .emoji.microbe,.cmd .emoji.microbe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a0.png);}
.terminal-output .emoji.badger,.cmd .emoji.badger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a1.png);}
.terminal-output .emoji.swan,.cmd .emoji.swan{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a2.png);}
.terminal-output .emoji.mammoth,.cmd .emoji.mammoth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a3.png);}
.terminal-output .emoji.dodo,.cmd .emoji.dodo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a4.png);}
.terminal-output .emoji.sloth,.cmd .emoji.sloth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a5.png);}
.terminal-output .emoji.otter,.cmd .emoji.otter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a6.png);}
.terminal-output .emoji.orangutan,.cmd .emoji.orangutan{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a7.png);}
.terminal-output .emoji.skunk,.cmd .emoji.skunk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a8.png);}
.terminal-output .emoji.flamingo,.cmd .emoji.flamingo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9a9.png);}
.terminal-output .emoji.oyster,.cmd .emoji.oyster{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9aa.png);}
.terminal-output .emoji.beaver,.cmd .emoji.beaver{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ab.png);}
.terminal-output .emoji.bison,.cmd .emoji.bison{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ac.png);}
.terminal-output .emoji.seal,.cmd .emoji.seal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ad.png);}
.terminal-output .emoji.guide_dog,.cmd .emoji.guide_dog{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ae.png);}
.terminal-output .emoji.probing_cane,.cmd .emoji.probing_cane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9af.png);}
.terminal-output .emoji.bone,.cmd .emoji.bone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b4.png);}
.terminal-output .emoji.leg,.cmd .emoji.leg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5.png);}
.terminal-output .emoji.leg-var-0,.cmd .emoji.leg-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5-1f3fb.png);}
.terminal-output .emoji.leg-var-1,.cmd .emoji.leg-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5-1f3fc.png);}
.terminal-output .emoji.leg-var-2,.cmd .emoji.leg-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5-1f3fd.png);}
.terminal-output .emoji.leg-var-3,.cmd .emoji.leg-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5-1f3fe.png);}
.terminal-output .emoji.leg-var-4,.cmd .emoji.leg-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b5-1f3ff.png);}
.terminal-output .emoji.foot,.cmd .emoji.foot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6.png);}
.terminal-output .emoji.foot-var-0,.cmd .emoji.foot-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6-1f3fb.png);}
.terminal-output .emoji.foot-var-1,.cmd .emoji.foot-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6-1f3fc.png);}
.terminal-output .emoji.foot-var-2,.cmd .emoji.foot-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6-1f3fd.png);}
.terminal-output .emoji.foot-var-3,.cmd .emoji.foot-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6-1f3fe.png);}
.terminal-output .emoji.foot-var-4,.cmd .emoji.foot-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b6-1f3ff.png);}
.terminal-output .emoji.tooth,.cmd .emoji.tooth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b7.png);}
.terminal-output .emoji.female_superhero,.cmd .emoji.female_superhero{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-200d-2640-fe0f.png);}
.terminal-output .emoji.female_superhero-var-0,.cmd .emoji.female_superhero-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_superhero-var-1,.cmd .emoji.female_superhero-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_superhero-var-2,.cmd .emoji.female_superhero-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_superhero-var-3,.cmd .emoji.female_superhero-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_superhero-var-4,.cmd .emoji.female_superhero-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_superhero,.cmd .emoji.male_superhero{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-200d-2642-fe0f.png);}
.terminal-output .emoji.male_superhero-var-0,.cmd .emoji.male_superhero-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_superhero-var-1,.cmd .emoji.male_superhero-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_superhero-var-2,.cmd .emoji.male_superhero-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_superhero-var-3,.cmd .emoji.male_superhero-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_superhero-var-4,.cmd .emoji.male_superhero-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.superhero,.cmd .emoji.superhero{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8.png);}
.terminal-output .emoji.superhero-var-0,.cmd .emoji.superhero-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fb.png);}
.terminal-output .emoji.superhero-var-1,.cmd .emoji.superhero-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fc.png);}
.terminal-output .emoji.superhero-var-2,.cmd .emoji.superhero-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fd.png);}
.terminal-output .emoji.superhero-var-3,.cmd .emoji.superhero-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3fe.png);}
.terminal-output .emoji.superhero-var-4,.cmd .emoji.superhero-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b8-1f3ff.png);}
.terminal-output .emoji.female_supervillain,.cmd .emoji.female_supervillain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-200d-2640-fe0f.png);}
.terminal-output .emoji.female_supervillain-var-0,.cmd .emoji.female_supervillain-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_supervillain-var-1,.cmd .emoji.female_supervillain-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_supervillain-var-2,.cmd .emoji.female_supervillain-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_supervillain-var-3,.cmd .emoji.female_supervillain-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_supervillain-var-4,.cmd .emoji.female_supervillain-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_supervillain,.cmd .emoji.male_supervillain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-200d-2642-fe0f.png);}
.terminal-output .emoji.male_supervillain-var-0,.cmd .emoji.male_supervillain-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_supervillain-var-1,.cmd .emoji.male_supervillain-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_supervillain-var-2,.cmd .emoji.male_supervillain-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_supervillain-var-3,.cmd .emoji.male_supervillain-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_supervillain-var-4,.cmd .emoji.male_supervillain-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.supervillain,.cmd .emoji.supervillain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9.png);}
.terminal-output .emoji.supervillain-var-0,.cmd .emoji.supervillain-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fb.png);}
.terminal-output .emoji.supervillain-var-1,.cmd .emoji.supervillain-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fc.png);}
.terminal-output .emoji.supervillain-var-2,.cmd .emoji.supervillain-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fd.png);}
.terminal-output .emoji.supervillain-var-3,.cmd .emoji.supervillain-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3fe.png);}
.terminal-output .emoji.supervillain-var-4,.cmd .emoji.supervillain-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9b9-1f3ff.png);}
.terminal-output .emoji.safety_vest,.cmd .emoji.safety_vest{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ba.png);}
.terminal-output .emoji.ear_with_hearing_aid,.cmd .emoji.ear_with_hearing_aid{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb.png);}
.terminal-output .emoji.ear_with_hearing_aid-var-0,.cmd .emoji.ear_with_hearing_aid-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb-1f3fb.png);}
.terminal-output .emoji.ear_with_hearing_aid-var-1,.cmd .emoji.ear_with_hearing_aid-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb-1f3fc.png);}
.terminal-output .emoji.ear_with_hearing_aid-var-2,.cmd .emoji.ear_with_hearing_aid-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb-1f3fd.png);}
.terminal-output .emoji.ear_with_hearing_aid-var-3,.cmd .emoji.ear_with_hearing_aid-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb-1f3fe.png);}
.terminal-output .emoji.ear_with_hearing_aid-var-4,.cmd .emoji.ear_with_hearing_aid-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bb-1f3ff.png);}
.terminal-output .emoji.motorized_wheelchair,.cmd .emoji.motorized_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bc.png);}
.terminal-output .emoji.manual_wheelchair,.cmd .emoji.manual_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bd.png);}
.terminal-output .emoji.mechanical_arm,.cmd .emoji.mechanical_arm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9be.png);}
.terminal-output .emoji.mechanical_leg,.cmd .emoji.mechanical_leg{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9bf.png);}
.terminal-output .emoji.cheese_wedge,.cmd .emoji.cheese_wedge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c0.png);}
.terminal-output .emoji.cupcake,.cmd .emoji.cupcake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c1.png);}
.terminal-output .emoji.salt,.cmd .emoji.salt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c2.png);}
.terminal-output .emoji.beverage_box,.cmd .emoji.beverage_box{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c3.png);}
.terminal-output .emoji.garlic,.cmd .emoji.garlic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c4.png);}
.terminal-output .emoji.onion,.cmd .emoji.onion{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c5.png);}
.terminal-output .emoji.falafel,.cmd .emoji.falafel{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c6.png);}
.terminal-output .emoji.waffle,.cmd .emoji.waffle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c7.png);}
.terminal-output .emoji.butter,.cmd .emoji.butter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c8.png);}
.terminal-output .emoji.mate_drink,.cmd .emoji.mate_drink{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9c9.png);}
.terminal-output .emoji.ice_cube,.cmd .emoji.ice_cube{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ca.png);}
.terminal-output .emoji.bubble_tea,.cmd .emoji.bubble_tea{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cb.png);}
.terminal-output .emoji.troll,.cmd .emoji.troll{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cc.png);}
.terminal-output .emoji.woman_standing,.cmd .emoji.woman_standing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_standing-var-0,.cmd .emoji.woman_standing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_standing-var-1,.cmd .emoji.woman_standing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_standing-var-2,.cmd .emoji.woman_standing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_standing-var-3,.cmd .emoji.woman_standing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_standing-var-4,.cmd .emoji.woman_standing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_standing,.cmd .emoji.man_standing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_standing-var-0,.cmd .emoji.man_standing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_standing-var-1,.cmd .emoji.man_standing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_standing-var-2,.cmd .emoji.man_standing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_standing-var-3,.cmd .emoji.man_standing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_standing-var-4,.cmd .emoji.man_standing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.standing_person,.cmd .emoji.standing_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd.png);}
.terminal-output .emoji.standing_person-var-0,.cmd .emoji.standing_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fb.png);}
.terminal-output .emoji.standing_person-var-1,.cmd .emoji.standing_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fc.png);}
.terminal-output .emoji.standing_person-var-2,.cmd .emoji.standing_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fd.png);}
.terminal-output .emoji.standing_person-var-3,.cmd .emoji.standing_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3fe.png);}
.terminal-output .emoji.standing_person-var-4,.cmd .emoji.standing_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cd-1f3ff.png);}
.terminal-output .emoji.woman_kneeling,.cmd .emoji.woman_kneeling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_kneeling-var-0,.cmd .emoji.woman_kneeling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_kneeling-var-1,.cmd .emoji.woman_kneeling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_kneeling-var-2,.cmd .emoji.woman_kneeling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_kneeling-var-3,.cmd .emoji.woman_kneeling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_kneeling-var-4,.cmd .emoji.woman_kneeling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_kneeling,.cmd .emoji.man_kneeling{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-200d-2642-fe0f.png);}
.terminal-output .emoji.man_kneeling-var-0,.cmd .emoji.man_kneeling-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_kneeling-var-1,.cmd .emoji.man_kneeling-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_kneeling-var-2,.cmd .emoji.man_kneeling-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_kneeling-var-3,.cmd .emoji.man_kneeling-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_kneeling-var-4,.cmd .emoji.man_kneeling-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.kneeling_person,.cmd .emoji.kneeling_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce.png);}
.terminal-output .emoji.kneeling_person-var-0,.cmd .emoji.kneeling_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fb.png);}
.terminal-output .emoji.kneeling_person-var-1,.cmd .emoji.kneeling_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fc.png);}
.terminal-output .emoji.kneeling_person-var-2,.cmd .emoji.kneeling_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fd.png);}
.terminal-output .emoji.kneeling_person-var-3,.cmd .emoji.kneeling_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3fe.png);}
.terminal-output .emoji.kneeling_person-var-4,.cmd .emoji.kneeling_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ce-1f3ff.png);}
.terminal-output .emoji.deaf_woman,.cmd .emoji.deaf_woman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_woman-var-0,.cmd .emoji.deaf_woman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_woman-var-1,.cmd .emoji.deaf_woman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_woman-var-2,.cmd .emoji.deaf_woman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_woman-var-3,.cmd .emoji.deaf_woman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_woman-var-4,.cmd .emoji.deaf_woman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.deaf_man,.cmd .emoji.deaf_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_man-var-0,.cmd .emoji.deaf_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_man-var-1,.cmd .emoji.deaf_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_man-var-2,.cmd .emoji.deaf_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_man-var-3,.cmd .emoji.deaf_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_man-var-4,.cmd .emoji.deaf_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.deaf_person,.cmd .emoji.deaf_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf.png);}
.terminal-output .emoji.deaf_person-var-0,.cmd .emoji.deaf_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fb.png);}
.terminal-output .emoji.deaf_person-var-1,.cmd .emoji.deaf_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fc.png);}
.terminal-output .emoji.deaf_person-var-2,.cmd .emoji.deaf_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fd.png);}
.terminal-output .emoji.deaf_person-var-3,.cmd .emoji.deaf_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3fe.png);}
.terminal-output .emoji.deaf_person-var-4,.cmd .emoji.deaf_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9cf-1f3ff.png);}
.terminal-output .emoji.face_with_monocle,.cmd .emoji.face_with_monocle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d0.png);}
.terminal-output .emoji.farmer,.cmd .emoji.farmer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f33e.png);}
.terminal-output .emoji.farmer-var-0,.cmd .emoji.farmer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f33e.png);}
.terminal-output .emoji.farmer-var-1,.cmd .emoji.farmer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f33e.png);}
.terminal-output .emoji.farmer-var-2,.cmd .emoji.farmer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f33e.png);}
.terminal-output .emoji.farmer-var-3,.cmd .emoji.farmer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f33e.png);}
.terminal-output .emoji.farmer-var-4,.cmd .emoji.farmer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f33e.png);}
.terminal-output .emoji.cook,.cmd .emoji.cook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f373.png);}
.terminal-output .emoji.cook-var-0,.cmd .emoji.cook-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f373.png);}
.terminal-output .emoji.cook-var-1,.cmd .emoji.cook-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f373.png);}
.terminal-output .emoji.cook-var-2,.cmd .emoji.cook-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f373.png);}
.terminal-output .emoji.cook-var-3,.cmd .emoji.cook-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f373.png);}
.terminal-output .emoji.cook-var-4,.cmd .emoji.cook-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f373.png);}
.terminal-output .emoji.person_feeding_baby,.cmd .emoji.person_feeding_baby{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f37c.png);}
.terminal-output .emoji.person_feeding_baby-var-0,.cmd .emoji.person_feeding_baby-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f37c.png);}
.terminal-output .emoji.person_feeding_baby-var-1,.cmd .emoji.person_feeding_baby-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f37c.png);}
.terminal-output .emoji.person_feeding_baby-var-2,.cmd .emoji.person_feeding_baby-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f37c.png);}
.terminal-output .emoji.person_feeding_baby-var-3,.cmd .emoji.person_feeding_baby-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f37c.png);}
.terminal-output .emoji.person_feeding_baby-var-4,.cmd .emoji.person_feeding_baby-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f37c.png);}
.terminal-output .emoji.mx_claus,.cmd .emoji.mx_claus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f384.png);}
.terminal-output .emoji.mx_claus-var-0,.cmd .emoji.mx_claus-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f384.png);}
.terminal-output .emoji.mx_claus-var-1,.cmd .emoji.mx_claus-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f384.png);}
.terminal-output .emoji.mx_claus-var-2,.cmd .emoji.mx_claus-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f384.png);}
.terminal-output .emoji.mx_claus-var-3,.cmd .emoji.mx_claus-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f384.png);}
.terminal-output .emoji.mx_claus-var-4,.cmd .emoji.mx_claus-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f384.png);}
.terminal-output .emoji.student,.cmd .emoji.student{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f393.png);}
.terminal-output .emoji.student-var-0,.cmd .emoji.student-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f393.png);}
.terminal-output .emoji.student-var-1,.cmd .emoji.student-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f393.png);}
.terminal-output .emoji.student-var-2,.cmd .emoji.student-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f393.png);}
.terminal-output .emoji.student-var-3,.cmd .emoji.student-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f393.png);}
.terminal-output .emoji.student-var-4,.cmd .emoji.student-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f393.png);}
.terminal-output .emoji.singer,.cmd .emoji.singer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f3a4.png);}
.terminal-output .emoji.singer-var-0,.cmd .emoji.singer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f3a4.png);}
.terminal-output .emoji.singer-var-1,.cmd .emoji.singer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f3a4.png);}
.terminal-output .emoji.singer-var-2,.cmd .emoji.singer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f3a4.png);}
.terminal-output .emoji.singer-var-3,.cmd .emoji.singer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f3a4.png);}
.terminal-output .emoji.singer-var-4,.cmd .emoji.singer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f3a4.png);}
.terminal-output .emoji.artist,.cmd .emoji.artist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f3a8.png);}
.terminal-output .emoji.artist-var-0,.cmd .emoji.artist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f3a8.png);}
.terminal-output .emoji.artist-var-1,.cmd .emoji.artist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f3a8.png);}
.terminal-output .emoji.artist-var-2,.cmd .emoji.artist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f3a8.png);}
.terminal-output .emoji.artist-var-3,.cmd .emoji.artist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f3a8.png);}
.terminal-output .emoji.artist-var-4,.cmd .emoji.artist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f3a8.png);}
.terminal-output .emoji.teacher,.cmd .emoji.teacher{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f3eb.png);}
.terminal-output .emoji.teacher-var-0,.cmd .emoji.teacher-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f3eb.png);}
.terminal-output .emoji.teacher-var-1,.cmd .emoji.teacher-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f3eb.png);}
.terminal-output .emoji.teacher-var-2,.cmd .emoji.teacher-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f3eb.png);}
.terminal-output .emoji.teacher-var-3,.cmd .emoji.teacher-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f3eb.png);}
.terminal-output .emoji.teacher-var-4,.cmd .emoji.teacher-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f3eb.png);}
.terminal-output .emoji.factory_worker,.cmd .emoji.factory_worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f3ed.png);}
.terminal-output .emoji.factory_worker-var-0,.cmd .emoji.factory_worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f3ed.png);}
.terminal-output .emoji.factory_worker-var-1,.cmd .emoji.factory_worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f3ed.png);}
.terminal-output .emoji.factory_worker-var-2,.cmd .emoji.factory_worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f3ed.png);}
.terminal-output .emoji.factory_worker-var-3,.cmd .emoji.factory_worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f3ed.png);}
.terminal-output .emoji.factory_worker-var-4,.cmd .emoji.factory_worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f3ed.png);}
.terminal-output .emoji.technologist,.cmd .emoji.technologist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f4bb.png);}
.terminal-output .emoji.technologist-var-0,.cmd .emoji.technologist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f4bb.png);}
.terminal-output .emoji.technologist-var-1,.cmd .emoji.technologist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f4bb.png);}
.terminal-output .emoji.technologist-var-2,.cmd .emoji.technologist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f4bb.png);}
.terminal-output .emoji.technologist-var-3,.cmd .emoji.technologist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f4bb.png);}
.terminal-output .emoji.technologist-var-4,.cmd .emoji.technologist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f4bb.png);}
.terminal-output .emoji.office_worker,.cmd .emoji.office_worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f4bc.png);}
.terminal-output .emoji.office_worker-var-0,.cmd .emoji.office_worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f4bc.png);}
.terminal-output .emoji.office_worker-var-1,.cmd .emoji.office_worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f4bc.png);}
.terminal-output .emoji.office_worker-var-2,.cmd .emoji.office_worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f4bc.png);}
.terminal-output .emoji.office_worker-var-3,.cmd .emoji.office_worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f4bc.png);}
.terminal-output .emoji.office_worker-var-4,.cmd .emoji.office_worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f4bc.png);}
.terminal-output .emoji.mechanic,.cmd .emoji.mechanic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f527.png);}
.terminal-output .emoji.mechanic-var-0,.cmd .emoji.mechanic-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f527.png);}
.terminal-output .emoji.mechanic-var-1,.cmd .emoji.mechanic-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f527.png);}
.terminal-output .emoji.mechanic-var-2,.cmd .emoji.mechanic-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f527.png);}
.terminal-output .emoji.mechanic-var-3,.cmd .emoji.mechanic-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f527.png);}
.terminal-output .emoji.mechanic-var-4,.cmd .emoji.mechanic-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f527.png);}
.terminal-output .emoji.scientist,.cmd .emoji.scientist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f52c.png);}
.terminal-output .emoji.scientist-var-0,.cmd .emoji.scientist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f52c.png);}
.terminal-output .emoji.scientist-var-1,.cmd .emoji.scientist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f52c.png);}
.terminal-output .emoji.scientist-var-2,.cmd .emoji.scientist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f52c.png);}
.terminal-output .emoji.scientist-var-3,.cmd .emoji.scientist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f52c.png);}
.terminal-output .emoji.scientist-var-4,.cmd .emoji.scientist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f52c.png);}
.terminal-output .emoji.astronaut,.cmd .emoji.astronaut{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f680.png);}
.terminal-output .emoji.astronaut-var-0,.cmd .emoji.astronaut-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f680.png);}
.terminal-output .emoji.astronaut-var-1,.cmd .emoji.astronaut-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f680.png);}
.terminal-output .emoji.astronaut-var-2,.cmd .emoji.astronaut-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f680.png);}
.terminal-output .emoji.astronaut-var-3,.cmd .emoji.astronaut-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f680.png);}
.terminal-output .emoji.astronaut-var-4,.cmd .emoji.astronaut-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f680.png);}
.terminal-output .emoji.firefighter,.cmd .emoji.firefighter{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f692.png);}
.terminal-output .emoji.firefighter-var-0,.cmd .emoji.firefighter-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f692.png);}
.terminal-output .emoji.firefighter-var-1,.cmd .emoji.firefighter-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f692.png);}
.terminal-output .emoji.firefighter-var-2,.cmd .emoji.firefighter-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f692.png);}
.terminal-output .emoji.firefighter-var-3,.cmd .emoji.firefighter-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f692.png);}
.terminal-output .emoji.firefighter-var-4,.cmd .emoji.firefighter-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f692.png);}
.terminal-output .emoji.people_holding_hands,.cmd .emoji.people_holding_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f91d-200d-1f9d1.png);}
.terminal-output .emoji.people_holding_hands-var-0,.cmd .emoji.people_holding_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.people_holding_hands-var-1,.cmd .emoji.people_holding_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.people_holding_hands-var-2,.cmd .emoji.people_holding_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.people_holding_hands-var-3,.cmd .emoji.people_holding_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.people_holding_hands-var-4,.cmd .emoji.people_holding_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.people_holding_hands-var-5,.cmd .emoji.people_holding_hands-var-5{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.people_holding_hands-var-6,.cmd .emoji.people_holding_hands-var-6{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.people_holding_hands-var-7,.cmd .emoji.people_holding_hands-var-7{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.people_holding_hands-var-8,.cmd .emoji.people_holding_hands-var-8{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.people_holding_hands-var-9,.cmd .emoji.people_holding_hands-var-9{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.people_holding_hands-var-10,.cmd .emoji.people_holding_hands-var-10{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.people_holding_hands-var-11,.cmd .emoji.people_holding_hands-var-11{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.people_holding_hands-var-12,.cmd .emoji.people_holding_hands-var-12{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.people_holding_hands-var-13,.cmd .emoji.people_holding_hands-var-13{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.people_holding_hands-var-14,.cmd .emoji.people_holding_hands-var-14{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.people_holding_hands-var-15,.cmd .emoji.people_holding_hands-var-15{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.people_holding_hands-var-16,.cmd .emoji.people_holding_hands-var-16{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.people_holding_hands-var-17,.cmd .emoji.people_holding_hands-var-17{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.people_holding_hands-var-18,.cmd .emoji.people_holding_hands-var-18{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.people_holding_hands-var-19,.cmd .emoji.people_holding_hands-var-19{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.people_holding_hands-var-20,.cmd .emoji.people_holding_hands-var-20{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fb.png);}
.terminal-output .emoji.people_holding_hands-var-21,.cmd .emoji.people_holding_hands-var-21{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fc.png);}
.terminal-output .emoji.people_holding_hands-var-22,.cmd .emoji.people_holding_hands-var-22{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fd.png);}
.terminal-output .emoji.people_holding_hands-var-23,.cmd .emoji.people_holding_hands-var-23{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fe.png);}
.terminal-output .emoji.people_holding_hands-var-24,.cmd .emoji.people_holding_hands-var-24{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3ff.png);}
.terminal-output .emoji.person_with_probing_cane,.cmd .emoji.person_with_probing_cane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9af.png);}
.terminal-output .emoji.person_with_probing_cane-var-0,.cmd .emoji.person_with_probing_cane-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9af.png);}
.terminal-output .emoji.person_with_probing_cane-var-1,.cmd .emoji.person_with_probing_cane-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9af.png);}
.terminal-output .emoji.person_with_probing_cane-var-2,.cmd .emoji.person_with_probing_cane-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9af.png);}
.terminal-output .emoji.person_with_probing_cane-var-3,.cmd .emoji.person_with_probing_cane-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9af.png);}
.terminal-output .emoji.person_with_probing_cane-var-4,.cmd .emoji.person_with_probing_cane-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9af.png);}
.terminal-output .emoji.red_haired_person,.cmd .emoji.red_haired_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_person-var-0,.cmd .emoji.red_haired_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_person-var-1,.cmd .emoji.red_haired_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_person-var-2,.cmd .emoji.red_haired_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_person-var-3,.cmd .emoji.red_haired_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9b0.png);}
.terminal-output .emoji.red_haired_person-var-4,.cmd .emoji.red_haired_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9b0.png);}
.terminal-output .emoji.curly_haired_person,.cmd .emoji.curly_haired_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_person-var-0,.cmd .emoji.curly_haired_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_person-var-1,.cmd .emoji.curly_haired_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_person-var-2,.cmd .emoji.curly_haired_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_person-var-3,.cmd .emoji.curly_haired_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9b1.png);}
.terminal-output .emoji.curly_haired_person-var-4,.cmd .emoji.curly_haired_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9b1.png);}
.terminal-output .emoji.bald_person,.cmd .emoji.bald_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9b2.png);}
.terminal-output .emoji.bald_person-var-0,.cmd .emoji.bald_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9b2.png);}
.terminal-output .emoji.bald_person-var-1,.cmd .emoji.bald_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9b2.png);}
.terminal-output .emoji.bald_person-var-2,.cmd .emoji.bald_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9b2.png);}
.terminal-output .emoji.bald_person-var-3,.cmd .emoji.bald_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9b2.png);}
.terminal-output .emoji.bald_person-var-4,.cmd .emoji.bald_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9b2.png);}
.terminal-output .emoji.white_haired_person,.cmd .emoji.white_haired_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_person-var-0,.cmd .emoji.white_haired_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_person-var-1,.cmd .emoji.white_haired_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_person-var-2,.cmd .emoji.white_haired_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_person-var-3,.cmd .emoji.white_haired_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9b3.png);}
.terminal-output .emoji.white_haired_person-var-4,.cmd .emoji.white_haired_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9b3.png);}
.terminal-output .emoji.person_in_motorized_wheelchair,.cmd .emoji.person_in_motorized_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9bc.png);}
.terminal-output .emoji.person_in_motorized_wheelchair-var-0,.cmd .emoji.person_in_motorized_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9bc.png);}
.terminal-output .emoji.person_in_motorized_wheelchair-var-1,.cmd .emoji.person_in_motorized_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9bc.png);}
.terminal-output .emoji.person_in_motorized_wheelchair-var-2,.cmd .emoji.person_in_motorized_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9bc.png);}
.terminal-output .emoji.person_in_motorized_wheelchair-var-3,.cmd .emoji.person_in_motorized_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9bc.png);}
.terminal-output .emoji.person_in_motorized_wheelchair-var-4,.cmd .emoji.person_in_motorized_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9bc.png);}
.terminal-output .emoji.person_in_manual_wheelchair,.cmd .emoji.person_in_manual_wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-1f9bd.png);}
.terminal-output .emoji.person_in_manual_wheelchair-var-0,.cmd .emoji.person_in_manual_wheelchair-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-1f9bd.png);}
.terminal-output .emoji.person_in_manual_wheelchair-var-1,.cmd .emoji.person_in_manual_wheelchair-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-1f9bd.png);}
.terminal-output .emoji.person_in_manual_wheelchair-var-2,.cmd .emoji.person_in_manual_wheelchair-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-1f9bd.png);}
.terminal-output .emoji.person_in_manual_wheelchair-var-3,.cmd .emoji.person_in_manual_wheelchair-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-1f9bd.png);}
.terminal-output .emoji.person_in_manual_wheelchair-var-4,.cmd .emoji.person_in_manual_wheelchair-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-1f9bd.png);}
.terminal-output .emoji.health_worker,.cmd .emoji.health_worker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-2695-fe0f.png);}
.terminal-output .emoji.health_worker-var-0,.cmd .emoji.health_worker-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2695-fe0f.png);}
.terminal-output .emoji.health_worker-var-1,.cmd .emoji.health_worker-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2695-fe0f.png);}
.terminal-output .emoji.health_worker-var-2,.cmd .emoji.health_worker-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2695-fe0f.png);}
.terminal-output .emoji.health_worker-var-3,.cmd .emoji.health_worker-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2695-fe0f.png);}
.terminal-output .emoji.health_worker-var-4,.cmd .emoji.health_worker-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2695-fe0f.png);}
.terminal-output .emoji.judge,.cmd .emoji.judge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-2696-fe0f.png);}
.terminal-output .emoji.judge-var-0,.cmd .emoji.judge-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2696-fe0f.png);}
.terminal-output .emoji.judge-var-1,.cmd .emoji.judge-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2696-fe0f.png);}
.terminal-output .emoji.judge-var-2,.cmd .emoji.judge-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2696-fe0f.png);}
.terminal-output .emoji.judge-var-3,.cmd .emoji.judge-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2696-fe0f.png);}
.terminal-output .emoji.judge-var-4,.cmd .emoji.judge-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2696-fe0f.png);}
.terminal-output .emoji.pilot,.cmd .emoji.pilot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-200d-2708-fe0f.png);}
.terminal-output .emoji.pilot-var-0,.cmd .emoji.pilot-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb-200d-2708-fe0f.png);}
.terminal-output .emoji.pilot-var-1,.cmd .emoji.pilot-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc-200d-2708-fe0f.png);}
.terminal-output .emoji.pilot-var-2,.cmd .emoji.pilot-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd-200d-2708-fe0f.png);}
.terminal-output .emoji.pilot-var-3,.cmd .emoji.pilot-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe-200d-2708-fe0f.png);}
.terminal-output .emoji.pilot-var-4,.cmd .emoji.pilot-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff-200d-2708-fe0f.png);}
.terminal-output .emoji.adult,.cmd .emoji.adult{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1.png);}
.terminal-output .emoji.adult-var-0,.cmd .emoji.adult-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fb.png);}
.terminal-output .emoji.adult-var-1,.cmd .emoji.adult-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fc.png);}
.terminal-output .emoji.adult-var-2,.cmd .emoji.adult-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fd.png);}
.terminal-output .emoji.adult-var-3,.cmd .emoji.adult-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3fe.png);}
.terminal-output .emoji.adult-var-4,.cmd .emoji.adult-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d1-1f3ff.png);}
.terminal-output .emoji.child,.cmd .emoji.child{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2.png);}
.terminal-output .emoji.child-var-0,.cmd .emoji.child-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2-1f3fb.png);}
.terminal-output .emoji.child-var-1,.cmd .emoji.child-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2-1f3fc.png);}
.terminal-output .emoji.child-var-2,.cmd .emoji.child-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2-1f3fd.png);}
.terminal-output .emoji.child-var-3,.cmd .emoji.child-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2-1f3fe.png);}
.terminal-output .emoji.child-var-4,.cmd .emoji.child-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d2-1f3ff.png);}
.terminal-output .emoji.older_adult,.cmd .emoji.older_adult{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3.png);}
.terminal-output .emoji.older_adult-var-0,.cmd .emoji.older_adult-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3-1f3fb.png);}
.terminal-output .emoji.older_adult-var-1,.cmd .emoji.older_adult-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3-1f3fc.png);}
.terminal-output .emoji.older_adult-var-2,.cmd .emoji.older_adult-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3-1f3fd.png);}
.terminal-output .emoji.older_adult-var-3,.cmd .emoji.older_adult-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3-1f3fe.png);}
.terminal-output .emoji.older_adult-var-4,.cmd .emoji.older_adult-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d3-1f3ff.png);}
.terminal-output .emoji.woman_with_beard,.cmd .emoji.woman_with_beard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_beard-var-0,.cmd .emoji.woman_with_beard-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_beard-var-1,.cmd .emoji.woman_with_beard-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_beard-var-2,.cmd .emoji.woman_with_beard-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_beard-var-3,.cmd .emoji.woman_with_beard-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_with_beard-var-4,.cmd .emoji.woman_with_beard-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_with_beard,.cmd .emoji.man_with_beard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_beard-var-0,.cmd .emoji.man_with_beard-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_beard-var-1,.cmd .emoji.man_with_beard-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_beard-var-2,.cmd .emoji.man_with_beard-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_beard-var-3,.cmd .emoji.man_with_beard-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_with_beard-var-4,.cmd .emoji.man_with_beard-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.bearded_person,.cmd .emoji.bearded_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4.png);}
.terminal-output .emoji.bearded_person-var-0,.cmd .emoji.bearded_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fb.png);}
.terminal-output .emoji.bearded_person-var-1,.cmd .emoji.bearded_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fc.png);}
.terminal-output .emoji.bearded_person-var-2,.cmd .emoji.bearded_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fd.png);}
.terminal-output .emoji.bearded_person-var-3,.cmd .emoji.bearded_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3fe.png);}
.terminal-output .emoji.bearded_person-var-4,.cmd .emoji.bearded_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d4-1f3ff.png);}
.terminal-output .emoji.person_with_headscarf,.cmd .emoji.person_with_headscarf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5.png);}
.terminal-output .emoji.person_with_headscarf-var-0,.cmd .emoji.person_with_headscarf-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5-1f3fb.png);}
.terminal-output .emoji.person_with_headscarf-var-1,.cmd .emoji.person_with_headscarf-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5-1f3fc.png);}
.terminal-output .emoji.person_with_headscarf-var-2,.cmd .emoji.person_with_headscarf-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5-1f3fd.png);}
.terminal-output .emoji.person_with_headscarf-var-3,.cmd .emoji.person_with_headscarf-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5-1f3fe.png);}
.terminal-output .emoji.person_with_headscarf-var-4,.cmd .emoji.person_with_headscarf-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d5-1f3ff.png);}
.terminal-output .emoji.woman_in_steamy_room,.cmd .emoji.woman_in_steamy_room{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_steamy_room-var-0,.cmd .emoji.woman_in_steamy_room-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_steamy_room-var-1,.cmd .emoji.woman_in_steamy_room-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_steamy_room-var-2,.cmd .emoji.woman_in_steamy_room-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_steamy_room-var-3,.cmd .emoji.woman_in_steamy_room-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_steamy_room-var-4,.cmd .emoji.woman_in_steamy_room-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room,.cmd .emoji.man_in_steamy_room{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room-var-0,.cmd .emoji.man_in_steamy_room-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room-var-1,.cmd .emoji.man_in_steamy_room-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room-var-2,.cmd .emoji.man_in_steamy_room-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room-var-3,.cmd .emoji.man_in_steamy_room-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_steamy_room-var-4,.cmd .emoji.man_in_steamy_room-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_in_steamy_room,.cmd .emoji.person_in_steamy_room{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6.png);}
.terminal-output .emoji.person_in_steamy_room-var-0,.cmd .emoji.person_in_steamy_room-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fb.png);}
.terminal-output .emoji.person_in_steamy_room-var-1,.cmd .emoji.person_in_steamy_room-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fc.png);}
.terminal-output .emoji.person_in_steamy_room-var-2,.cmd .emoji.person_in_steamy_room-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fd.png);}
.terminal-output .emoji.person_in_steamy_room-var-3,.cmd .emoji.person_in_steamy_room-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3fe.png);}
.terminal-output .emoji.person_in_steamy_room-var-4,.cmd .emoji.person_in_steamy_room-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d6-1f3ff.png);}
.terminal-output .emoji.woman_climbing,.cmd .emoji.woman_climbing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_climbing-var-0,.cmd .emoji.woman_climbing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_climbing-var-1,.cmd .emoji.woman_climbing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_climbing-var-2,.cmd .emoji.woman_climbing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_climbing-var-3,.cmd .emoji.woman_climbing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_climbing-var-4,.cmd .emoji.woman_climbing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_climbing,.cmd .emoji.man_climbing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-200d-2642-fe0f.png);}
.terminal-output .emoji.man_climbing-var-0,.cmd .emoji.man_climbing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_climbing-var-1,.cmd .emoji.man_climbing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_climbing-var-2,.cmd .emoji.man_climbing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_climbing-var-3,.cmd .emoji.man_climbing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_climbing-var-4,.cmd .emoji.man_climbing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_climbing,.cmd .emoji.person_climbing{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7.png);}
.terminal-output .emoji.person_climbing-var-0,.cmd .emoji.person_climbing-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fb.png);}
.terminal-output .emoji.person_climbing-var-1,.cmd .emoji.person_climbing-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fc.png);}
.terminal-output .emoji.person_climbing-var-2,.cmd .emoji.person_climbing-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fd.png);}
.terminal-output .emoji.person_climbing-var-3,.cmd .emoji.person_climbing-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3fe.png);}
.terminal-output .emoji.person_climbing-var-4,.cmd .emoji.person_climbing-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d7-1f3ff.png);}
.terminal-output .emoji.woman_in_lotus_position,.cmd .emoji.woman_in_lotus_position{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_lotus_position-var-0,.cmd .emoji.woman_in_lotus_position-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_lotus_position-var-1,.cmd .emoji.woman_in_lotus_position-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_lotus_position-var-2,.cmd .emoji.woman_in_lotus_position-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_lotus_position-var-3,.cmd .emoji.woman_in_lotus_position-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman_in_lotus_position-var-4,.cmd .emoji.woman_in_lotus_position-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position,.cmd .emoji.man_in_lotus_position{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position-var-0,.cmd .emoji.man_in_lotus_position-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position-var-1,.cmd .emoji.man_in_lotus_position-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position-var-2,.cmd .emoji.man_in_lotus_position-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position-var-3,.cmd .emoji.man_in_lotus_position-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man_in_lotus_position-var-4,.cmd .emoji.man_in_lotus_position-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_in_lotus_position,.cmd .emoji.person_in_lotus_position{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8.png);}
.terminal-output .emoji.person_in_lotus_position-var-0,.cmd .emoji.person_in_lotus_position-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fb.png);}
.terminal-output .emoji.person_in_lotus_position-var-1,.cmd .emoji.person_in_lotus_position-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fc.png);}
.terminal-output .emoji.person_in_lotus_position-var-2,.cmd .emoji.person_in_lotus_position-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fd.png);}
.terminal-output .emoji.person_in_lotus_position-var-3,.cmd .emoji.person_in_lotus_position-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3fe.png);}
.terminal-output .emoji.person_in_lotus_position-var-4,.cmd .emoji.person_in_lotus_position-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d8-1f3ff.png);}
.terminal-output .emoji.female_mage,.cmd .emoji.female_mage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-200d-2640-fe0f.png);}
.terminal-output .emoji.female_mage-var-0,.cmd .emoji.female_mage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_mage-var-1,.cmd .emoji.female_mage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_mage-var-2,.cmd .emoji.female_mage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_mage-var-3,.cmd .emoji.female_mage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_mage-var-4,.cmd .emoji.female_mage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_mage,.cmd .emoji.male_mage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-200d-2642-fe0f.png);}
.terminal-output .emoji.male_mage-var-0,.cmd .emoji.male_mage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_mage-var-1,.cmd .emoji.male_mage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_mage-var-2,.cmd .emoji.male_mage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_mage-var-3,.cmd .emoji.male_mage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_mage-var-4,.cmd .emoji.male_mage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.mage,.cmd .emoji.mage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9.png);}
.terminal-output .emoji.mage-var-0,.cmd .emoji.mage-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fb.png);}
.terminal-output .emoji.mage-var-1,.cmd .emoji.mage-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fc.png);}
.terminal-output .emoji.mage-var-2,.cmd .emoji.mage-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fd.png);}
.terminal-output .emoji.mage-var-3,.cmd .emoji.mage-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3fe.png);}
.terminal-output .emoji.mage-var-4,.cmd .emoji.mage-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9d9-1f3ff.png);}
.terminal-output .emoji.female_fairy,.cmd .emoji.female_fairy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-200d-2640-fe0f.png);}
.terminal-output .emoji.female_fairy-var-0,.cmd .emoji.female_fairy-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_fairy-var-1,.cmd .emoji.female_fairy-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_fairy-var-2,.cmd .emoji.female_fairy-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_fairy-var-3,.cmd .emoji.female_fairy-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_fairy-var-4,.cmd .emoji.female_fairy-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_fairy,.cmd .emoji.male_fairy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-200d-2642-fe0f.png);}
.terminal-output .emoji.male_fairy-var-0,.cmd .emoji.male_fairy-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_fairy-var-1,.cmd .emoji.male_fairy-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_fairy-var-2,.cmd .emoji.male_fairy-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_fairy-var-3,.cmd .emoji.male_fairy-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_fairy-var-4,.cmd .emoji.male_fairy-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.fairy,.cmd .emoji.fairy{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da.png);}
.terminal-output .emoji.fairy-var-0,.cmd .emoji.fairy-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fb.png);}
.terminal-output .emoji.fairy-var-1,.cmd .emoji.fairy-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fc.png);}
.terminal-output .emoji.fairy-var-2,.cmd .emoji.fairy-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fd.png);}
.terminal-output .emoji.fairy-var-3,.cmd .emoji.fairy-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3fe.png);}
.terminal-output .emoji.fairy-var-4,.cmd .emoji.fairy-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9da-1f3ff.png);}
.terminal-output .emoji.female_vampire,.cmd .emoji.female_vampire{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-200d-2640-fe0f.png);}
.terminal-output .emoji.female_vampire-var-0,.cmd .emoji.female_vampire-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_vampire-var-1,.cmd .emoji.female_vampire-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_vampire-var-2,.cmd .emoji.female_vampire-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_vampire-var-3,.cmd .emoji.female_vampire-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_vampire-var-4,.cmd .emoji.female_vampire-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_vampire,.cmd .emoji.male_vampire{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-200d-2642-fe0f.png);}
.terminal-output .emoji.male_vampire-var-0,.cmd .emoji.male_vampire-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_vampire-var-1,.cmd .emoji.male_vampire-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_vampire-var-2,.cmd .emoji.male_vampire-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_vampire-var-3,.cmd .emoji.male_vampire-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_vampire-var-4,.cmd .emoji.male_vampire-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.vampire,.cmd .emoji.vampire{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db.png);}
.terminal-output .emoji.vampire-var-0,.cmd .emoji.vampire-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fb.png);}
.terminal-output .emoji.vampire-var-1,.cmd .emoji.vampire-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fc.png);}
.terminal-output .emoji.vampire-var-2,.cmd .emoji.vampire-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fd.png);}
.terminal-output .emoji.vampire-var-3,.cmd .emoji.vampire-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3fe.png);}
.terminal-output .emoji.vampire-var-4,.cmd .emoji.vampire-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9db-1f3ff.png);}
.terminal-output .emoji.mermaid,.cmd .emoji.mermaid{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-200d-2640-fe0f.png);}
.terminal-output .emoji.mermaid-var-0,.cmd .emoji.mermaid-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.mermaid-var-1,.cmd .emoji.mermaid-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.mermaid-var-2,.cmd .emoji.mermaid-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.mermaid-var-3,.cmd .emoji.mermaid-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.mermaid-var-4,.cmd .emoji.mermaid-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.merman,.cmd .emoji.merman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-200d-2642-fe0f.png);}
.terminal-output .emoji.merman-var-0,.cmd .emoji.merman-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.merman-var-1,.cmd .emoji.merman-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.merman-var-2,.cmd .emoji.merman-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.merman-var-3,.cmd .emoji.merman-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.merman-var-4,.cmd .emoji.merman-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.merperson,.cmd .emoji.merperson{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc.png);}
.terminal-output .emoji.merperson-var-0,.cmd .emoji.merperson-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fb.png);}
.terminal-output .emoji.merperson-var-1,.cmd .emoji.merperson-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fc.png);}
.terminal-output .emoji.merperson-var-2,.cmd .emoji.merperson-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fd.png);}
.terminal-output .emoji.merperson-var-3,.cmd .emoji.merperson-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3fe.png);}
.terminal-output .emoji.merperson-var-4,.cmd .emoji.merperson-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dc-1f3ff.png);}
.terminal-output .emoji.female_elf,.cmd .emoji.female_elf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_elf-var-0,.cmd .emoji.female_elf-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.female_elf-var-1,.cmd .emoji.female_elf-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.female_elf-var-2,.cmd .emoji.female_elf-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.female_elf-var-3,.cmd .emoji.female_elf-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.female_elf-var-4,.cmd .emoji.female_elf-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.male_elf,.cmd .emoji.male_elf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_elf-var-0,.cmd .emoji.male_elf-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.male_elf-var-1,.cmd .emoji.male_elf-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.male_elf-var-2,.cmd .emoji.male_elf-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.male_elf-var-3,.cmd .emoji.male_elf-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.male_elf-var-4,.cmd .emoji.male_elf-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.elf,.cmd .emoji.elf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd.png);}
.terminal-output .emoji.elf-var-0,.cmd .emoji.elf-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fb.png);}
.terminal-output .emoji.elf-var-1,.cmd .emoji.elf-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fc.png);}
.terminal-output .emoji.elf-var-2,.cmd .emoji.elf-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fd.png);}
.terminal-output .emoji.elf-var-3,.cmd .emoji.elf-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3fe.png);}
.terminal-output .emoji.elf-var-4,.cmd .emoji.elf-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9dd-1f3ff.png);}
.terminal-output .emoji.female_genie,.cmd .emoji.female_genie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9de-200d-2640-fe0f.png);}
.terminal-output .emoji.male_genie,.cmd .emoji.male_genie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9de-200d-2642-fe0f.png);}
.terminal-output .emoji.genie,.cmd .emoji.genie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9de.png);}
.terminal-output .emoji.female_zombie,.cmd .emoji.female_zombie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9df-200d-2640-fe0f.png);}
.terminal-output .emoji.male_zombie,.cmd .emoji.male_zombie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9df-200d-2642-fe0f.png);}
.terminal-output .emoji.zombie,.cmd .emoji.zombie{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9df.png);}
.terminal-output .emoji.brain,.cmd .emoji.brain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e0.png);}
.terminal-output .emoji.orange_heart,.cmd .emoji.orange_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e1.png);}
.terminal-output .emoji.billed_cap,.cmd .emoji.billed_cap{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e2.png);}
.terminal-output .emoji.scarf,.cmd .emoji.scarf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e3.png);}
.terminal-output .emoji.gloves,.cmd .emoji.gloves{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e4.png);}
.terminal-output .emoji.coat,.cmd .emoji.coat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e5.png);}
.terminal-output .emoji.socks,.cmd .emoji.socks{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e6.png);}
.terminal-output .emoji.red_envelope,.cmd .emoji.red_envelope{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e7.png);}
.terminal-output .emoji.firecracker,.cmd .emoji.firecracker{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e8.png);}
.terminal-output .emoji.jigsaw,.cmd .emoji.jigsaw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9e9.png);}
.terminal-output .emoji.test_tube,.cmd .emoji.test_tube{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ea.png);}
.terminal-output .emoji.petri_dish,.cmd .emoji.petri_dish{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9eb.png);}
.terminal-output .emoji.dna,.cmd .emoji.dna{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ec.png);}
.terminal-output .emoji.compass,.cmd .emoji.compass{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ed.png);}
.terminal-output .emoji.abacus,.cmd .emoji.abacus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ee.png);}
.terminal-output .emoji.fire_extinguisher,.cmd .emoji.fire_extinguisher{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ef.png);}
.terminal-output .emoji.toolbox,.cmd .emoji.toolbox{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f0.png);}
.terminal-output .emoji.bricks,.cmd .emoji.bricks{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f1.png);}
.terminal-output .emoji.magnet,.cmd .emoji.magnet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f2.png);}
.terminal-output .emoji.luggage,.cmd .emoji.luggage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f3.png);}
.terminal-output .emoji.lotion_bottle,.cmd .emoji.lotion_bottle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f4.png);}
.terminal-output .emoji.thread,.cmd .emoji.thread{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f5.png);}
.terminal-output .emoji.yarn,.cmd .emoji.yarn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f6.png);}
.terminal-output .emoji.safety_pin,.cmd .emoji.safety_pin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f7.png);}
.terminal-output .emoji.teddy_bear,.cmd .emoji.teddy_bear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f8.png);}
.terminal-output .emoji.broom,.cmd .emoji.broom{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9f9.png);}
.terminal-output .emoji.basket,.cmd .emoji.basket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9fa.png);}
.terminal-output .emoji.roll_of_paper,.cmd .emoji.roll_of_paper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9fb.png);}
.terminal-output .emoji.soap,.cmd .emoji.soap{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9fc.png);}
.terminal-output .emoji.sponge,.cmd .emoji.sponge{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9fd.png);}
.terminal-output .emoji.receipt,.cmd .emoji.receipt{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9fe.png);}
.terminal-output .emoji.nazar_amulet,.cmd .emoji.nazar_amulet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1f9ff.png);}
.terminal-output .emoji.ballet_shoes,.cmd .emoji.ballet_shoes{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa70.png);}
.terminal-output .emoji.one-piece_swimsuit,.cmd .emoji.one-piece_swimsuit{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa71.png);}
.terminal-output .emoji.briefs,.cmd .emoji.briefs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa72.png);}
.terminal-output .emoji.shorts,.cmd .emoji.shorts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa73.png);}
.terminal-output .emoji.thong_sandal,.cmd .emoji.thong_sandal{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa74.png);}
.terminal-output .emoji.drop_of_blood,.cmd .emoji.drop_of_blood{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa78.png);}
.terminal-output .emoji.adhesive_bandage,.cmd .emoji.adhesive_bandage{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa79.png);}
.terminal-output .emoji.stethoscope,.cmd .emoji.stethoscope{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa7a.png);}
.terminal-output .emoji.x-ray,.cmd .emoji.x-ray{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa7b.png);}
.terminal-output .emoji.crutch,.cmd .emoji.crutch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa7c.png);}
.terminal-output .emoji.yo-yo,.cmd .emoji.yo-yo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa80.png);}
.terminal-output .emoji.kite,.cmd .emoji.kite{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa81.png);}
.terminal-output .emoji.parachute,.cmd .emoji.parachute{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa82.png);}
.terminal-output .emoji.boomerang,.cmd .emoji.boomerang{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa83.png);}
.terminal-output .emoji.magic_wand,.cmd .emoji.magic_wand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa84.png);}
.terminal-output .emoji.pinata,.cmd .emoji.pinata{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa85.png);}
.terminal-output .emoji.nesting_dolls,.cmd .emoji.nesting_dolls{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa86.png);}
.terminal-output .emoji.ringed_planet,.cmd .emoji.ringed_planet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa90.png);}
.terminal-output .emoji.chair,.cmd .emoji.chair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa91.png);}
.terminal-output .emoji.razor,.cmd .emoji.razor{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa92.png);}
.terminal-output .emoji.axe,.cmd .emoji.axe{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa93.png);}
.terminal-output .emoji.diya_lamp,.cmd .emoji.diya_lamp{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa94.png);}
.terminal-output .emoji.banjo,.cmd .emoji.banjo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa95.png);}
.terminal-output .emoji.military_helmet,.cmd .emoji.military_helmet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa96.png);}
.terminal-output .emoji.accordion,.cmd .emoji.accordion{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa97.png);}
.terminal-output .emoji.long_drum,.cmd .emoji.long_drum{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa98.png);}
.terminal-output .emoji.coin,.cmd .emoji.coin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa99.png);}
.terminal-output .emoji.carpentry_saw,.cmd .emoji.carpentry_saw{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9a.png);}
.terminal-output .emoji.screwdriver,.cmd .emoji.screwdriver{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9b.png);}
.terminal-output .emoji.ladder,.cmd .emoji.ladder{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9c.png);}
.terminal-output .emoji.hook,.cmd .emoji.hook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9d.png);}
.terminal-output .emoji.mirror,.cmd .emoji.mirror{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9e.png);}
.terminal-output .emoji.window,.cmd .emoji.window{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fa9f.png);}
.terminal-output .emoji.plunger,.cmd .emoji.plunger{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa0.png);}
.terminal-output .emoji.sewing_needle,.cmd .emoji.sewing_needle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa1.png);}
.terminal-output .emoji.knot,.cmd .emoji.knot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa2.png);}
.terminal-output .emoji.bucket,.cmd .emoji.bucket{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa3.png);}
.terminal-output .emoji.mouse_trap,.cmd .emoji.mouse_trap{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa4.png);}
.terminal-output .emoji.toothbrush,.cmd .emoji.toothbrush{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa5.png);}
.terminal-output .emoji.headstone,.cmd .emoji.headstone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa6.png);}
.terminal-output .emoji.placard,.cmd .emoji.placard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa7.png);}
.terminal-output .emoji.rock,.cmd .emoji.rock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa8.png);}
.terminal-output .emoji.mirror_ball,.cmd .emoji.mirror_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faa9.png);}
.terminal-output .emoji.identification_card,.cmd .emoji.identification_card{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faaa.png);}
.terminal-output .emoji.low_battery,.cmd .emoji.low_battery{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faab.png);}
.terminal-output .emoji.hamsa,.cmd .emoji.hamsa{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faac.png);}
.terminal-output .emoji.fly,.cmd .emoji.fly{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab0.png);}
.terminal-output .emoji.worm,.cmd .emoji.worm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab1.png);}
.terminal-output .emoji.beetle,.cmd .emoji.beetle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab2.png);}
.terminal-output .emoji.cockroach,.cmd .emoji.cockroach{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab3.png);}
.terminal-output .emoji.potted_plant,.cmd .emoji.potted_plant{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab4.png);}
.terminal-output .emoji.wood,.cmd .emoji.wood{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab5.png);}
.terminal-output .emoji.feather,.cmd .emoji.feather{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab6.png);}
.terminal-output .emoji.lotus,.cmd .emoji.lotus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab7.png);}
.terminal-output .emoji.coral,.cmd .emoji.coral{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab8.png);}
.terminal-output .emoji.empty_nest,.cmd .emoji.empty_nest{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fab9.png);}
.terminal-output .emoji.nest_with_eggs,.cmd .emoji.nest_with_eggs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faba.png);}
.terminal-output .emoji.anatomical_heart,.cmd .emoji.anatomical_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac0.png);}
.terminal-output .emoji.lungs,.cmd .emoji.lungs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac1.png);}
.terminal-output .emoji.people_hugging,.cmd .emoji.people_hugging{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac2.png);}
.terminal-output .emoji.pregnant_man,.cmd .emoji.pregnant_man{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3.png);}
.terminal-output .emoji.pregnant_man-var-0,.cmd .emoji.pregnant_man-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3-1f3fb.png);}
.terminal-output .emoji.pregnant_man-var-1,.cmd .emoji.pregnant_man-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3-1f3fc.png);}
.terminal-output .emoji.pregnant_man-var-2,.cmd .emoji.pregnant_man-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3-1f3fd.png);}
.terminal-output .emoji.pregnant_man-var-3,.cmd .emoji.pregnant_man-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3-1f3fe.png);}
.terminal-output .emoji.pregnant_man-var-4,.cmd .emoji.pregnant_man-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac3-1f3ff.png);}
.terminal-output .emoji.pregnant_person,.cmd .emoji.pregnant_person{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4.png);}
.terminal-output .emoji.pregnant_person-var-0,.cmd .emoji.pregnant_person-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4-1f3fb.png);}
.terminal-output .emoji.pregnant_person-var-1,.cmd .emoji.pregnant_person-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4-1f3fc.png);}
.terminal-output .emoji.pregnant_person-var-2,.cmd .emoji.pregnant_person-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4-1f3fd.png);}
.terminal-output .emoji.pregnant_person-var-3,.cmd .emoji.pregnant_person-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4-1f3fe.png);}
.terminal-output .emoji.pregnant_person-var-4,.cmd .emoji.pregnant_person-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac4-1f3ff.png);}
.terminal-output .emoji.person_with_crown,.cmd .emoji.person_with_crown{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5.png);}
.terminal-output .emoji.person_with_crown-var-0,.cmd .emoji.person_with_crown-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5-1f3fb.png);}
.terminal-output .emoji.person_with_crown-var-1,.cmd .emoji.person_with_crown-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5-1f3fc.png);}
.terminal-output .emoji.person_with_crown-var-2,.cmd .emoji.person_with_crown-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5-1f3fd.png);}
.terminal-output .emoji.person_with_crown-var-3,.cmd .emoji.person_with_crown-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5-1f3fe.png);}
.terminal-output .emoji.person_with_crown-var-4,.cmd .emoji.person_with_crown-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fac5-1f3ff.png);}
.terminal-output .emoji.blueberries,.cmd .emoji.blueberries{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad0.png);}
.terminal-output .emoji.bell_pepper,.cmd .emoji.bell_pepper{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad1.png);}
.terminal-output .emoji.olive,.cmd .emoji.olive{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad2.png);}
.terminal-output .emoji.flatbread,.cmd .emoji.flatbread{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad3.png);}
.terminal-output .emoji.tamale,.cmd .emoji.tamale{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad4.png);}
.terminal-output .emoji.fondue,.cmd .emoji.fondue{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad5.png);}
.terminal-output .emoji.teapot,.cmd .emoji.teapot{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad6.png);}
.terminal-output .emoji.pouring_liquid,.cmd .emoji.pouring_liquid{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad7.png);}
.terminal-output .emoji.beans,.cmd .emoji.beans{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad8.png);}
.terminal-output .emoji.jar,.cmd .emoji.jar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fad9.png);}
.terminal-output .emoji.melting_face,.cmd .emoji.melting_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae0.png);}
.terminal-output .emoji.saluting_face,.cmd .emoji.saluting_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae1.png);}
.terminal-output .emoji.face_with_open_eyes_and_hand_over_mouth,.cmd .emoji.face_with_open_eyes_and_hand_over_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae2.png);}
.terminal-output .emoji.face_with_peeking_eye,.cmd .emoji.face_with_peeking_eye{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae3.png);}
.terminal-output .emoji.face_with_diagonal_mouth,.cmd .emoji.face_with_diagonal_mouth{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae4.png);}
.terminal-output .emoji.dotted_line_face,.cmd .emoji.dotted_line_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae5.png);}
.terminal-output .emoji.biting_lip,.cmd .emoji.biting_lip{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae6.png);}
.terminal-output .emoji.bubbles,.cmd .emoji.bubbles{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1fae7.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed,.cmd .emoji.hand_with_index_finger_and_thumb_crossed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed-var-0,.cmd .emoji.hand_with_index_finger_and_thumb_crossed-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0-1f3fb.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed-var-1,.cmd .emoji.hand_with_index_finger_and_thumb_crossed-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0-1f3fc.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed-var-2,.cmd .emoji.hand_with_index_finger_and_thumb_crossed-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0-1f3fd.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed-var-3,.cmd .emoji.hand_with_index_finger_and_thumb_crossed-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0-1f3fe.png);}
.terminal-output .emoji.hand_with_index_finger_and_thumb_crossed-var-4,.cmd .emoji.hand_with_index_finger_and_thumb_crossed-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf0-1f3ff.png);}
.terminal-output .emoji.rightwards_hand,.cmd .emoji.rightwards_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1.png);}
.terminal-output .emoji.rightwards_hand-var-0,.cmd .emoji.rightwards_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fb.png);}
.terminal-output .emoji.rightwards_hand-var-1,.cmd .emoji.rightwards_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fc.png);}
.terminal-output .emoji.rightwards_hand-var-2,.cmd .emoji.rightwards_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fd.png);}
.terminal-output .emoji.rightwards_hand-var-3,.cmd .emoji.rightwards_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3fe.png);}
.terminal-output .emoji.rightwards_hand-var-4,.cmd .emoji.rightwards_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf1-1f3ff.png);}
.terminal-output .emoji.leftwards_hand,.cmd .emoji.leftwards_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2.png);}
.terminal-output .emoji.leftwards_hand-var-0,.cmd .emoji.leftwards_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2-1f3fb.png);}
.terminal-output .emoji.leftwards_hand-var-1,.cmd .emoji.leftwards_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2-1f3fc.png);}
.terminal-output .emoji.leftwards_hand-var-2,.cmd .emoji.leftwards_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2-1f3fd.png);}
.terminal-output .emoji.leftwards_hand-var-3,.cmd .emoji.leftwards_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2-1f3fe.png);}
.terminal-output .emoji.leftwards_hand-var-4,.cmd .emoji.leftwards_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf2-1f3ff.png);}
.terminal-output .emoji.palm_down_hand,.cmd .emoji.palm_down_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3.png);}
.terminal-output .emoji.palm_down_hand-var-0,.cmd .emoji.palm_down_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3-1f3fb.png);}
.terminal-output .emoji.palm_down_hand-var-1,.cmd .emoji.palm_down_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3-1f3fc.png);}
.terminal-output .emoji.palm_down_hand-var-2,.cmd .emoji.palm_down_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3-1f3fd.png);}
.terminal-output .emoji.palm_down_hand-var-3,.cmd .emoji.palm_down_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3-1f3fe.png);}
.terminal-output .emoji.palm_down_hand-var-4,.cmd .emoji.palm_down_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf3-1f3ff.png);}
.terminal-output .emoji.palm_up_hand,.cmd .emoji.palm_up_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4.png);}
.terminal-output .emoji.palm_up_hand-var-0,.cmd .emoji.palm_up_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4-1f3fb.png);}
.terminal-output .emoji.palm_up_hand-var-1,.cmd .emoji.palm_up_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4-1f3fc.png);}
.terminal-output .emoji.palm_up_hand-var-2,.cmd .emoji.palm_up_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4-1f3fd.png);}
.terminal-output .emoji.palm_up_hand-var-3,.cmd .emoji.palm_up_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4-1f3fe.png);}
.terminal-output .emoji.palm_up_hand-var-4,.cmd .emoji.palm_up_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf4-1f3ff.png);}
.terminal-output .emoji.index_pointing_at_the_viewer,.cmd .emoji.index_pointing_at_the_viewer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5.png);}
.terminal-output .emoji.index_pointing_at_the_viewer-var-0,.cmd .emoji.index_pointing_at_the_viewer-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5-1f3fb.png);}
.terminal-output .emoji.index_pointing_at_the_viewer-var-1,.cmd .emoji.index_pointing_at_the_viewer-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5-1f3fc.png);}
.terminal-output .emoji.index_pointing_at_the_viewer-var-2,.cmd .emoji.index_pointing_at_the_viewer-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5-1f3fd.png);}
.terminal-output .emoji.index_pointing_at_the_viewer-var-3,.cmd .emoji.index_pointing_at_the_viewer-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5-1f3fe.png);}
.terminal-output .emoji.index_pointing_at_the_viewer-var-4,.cmd .emoji.index_pointing_at_the_viewer-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf5-1f3ff.png);}
.terminal-output .emoji.heart_hands,.cmd .emoji.heart_hands{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6.png);}
.terminal-output .emoji.heart_hands-var-0,.cmd .emoji.heart_hands-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6-1f3fb.png);}
.terminal-output .emoji.heart_hands-var-1,.cmd .emoji.heart_hands-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6-1f3fc.png);}
.terminal-output .emoji.heart_hands-var-2,.cmd .emoji.heart_hands-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6-1f3fd.png);}
.terminal-output .emoji.heart_hands-var-3,.cmd .emoji.heart_hands-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6-1f3fe.png);}
.terminal-output .emoji.heart_hands-var-4,.cmd .emoji.heart_hands-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/1faf6-1f3ff.png);}
.terminal-output .emoji.bangbang,.cmd .emoji.bangbang{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/203c-fe0f.png);}
.terminal-output .emoji.interrobang,.cmd .emoji.interrobang{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2049-fe0f.png);}
.terminal-output .emoji.tm,.cmd .emoji.tm{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2122-fe0f.png);}
.terminal-output .emoji.information_source,.cmd .emoji.information_source{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2139-fe0f.png);}
.terminal-output .emoji.left_right_arrow,.cmd .emoji.left_right_arrow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2194-fe0f.png);}
.terminal-output .emoji.arrow_up_down,.cmd .emoji.arrow_up_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2195-fe0f.png);}
.terminal-output .emoji.arrow_upper_left,.cmd .emoji.arrow_upper_left{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2196-fe0f.png);}
.terminal-output .emoji.arrow_upper_right,.cmd .emoji.arrow_upper_right{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2197-fe0f.png);}
.terminal-output .emoji.arrow_lower_right,.cmd .emoji.arrow_lower_right{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2198-fe0f.png);}
.terminal-output .emoji.arrow_lower_left,.cmd .emoji.arrow_lower_left{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2199-fe0f.png);}
.terminal-output .emoji.leftwards_arrow_with_hook,.cmd .emoji.leftwards_arrow_with_hook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/21a9-fe0f.png);}
.terminal-output .emoji.arrow_right_hook,.cmd .emoji.arrow_right_hook{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/21aa-fe0f.png);}
.terminal-output .emoji.watch,.cmd .emoji.watch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/231a.png);}
.terminal-output .emoji.hourglass,.cmd .emoji.hourglass{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/231b.png);}
.terminal-output .emoji.keyboard,.cmd .emoji.keyboard{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2328-fe0f.png);}
.terminal-output .emoji.eject,.cmd .emoji.eject{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23cf-fe0f.png);}
.terminal-output .emoji.fast_forward,.cmd .emoji.fast_forward{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23e9.png);}
.terminal-output .emoji.rewind,.cmd .emoji.rewind{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23ea.png);}
.terminal-output .emoji.arrow_double_up,.cmd .emoji.arrow_double_up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23eb.png);}
.terminal-output .emoji.arrow_double_down,.cmd .emoji.arrow_double_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23ec.png);}
.terminal-output .emoji.black_right_pointing_double_triangle_with_vertical_bar,.cmd .emoji.black_right_pointing_double_triangle_with_vertical_bar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23ed-fe0f.png);}
.terminal-output .emoji.black_left_pointing_double_triangle_with_vertical_bar,.cmd .emoji.black_left_pointing_double_triangle_with_vertical_bar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23ee-fe0f.png);}
.terminal-output .emoji.black_right_pointing_triangle_with_double_vertical_bar,.cmd .emoji.black_right_pointing_triangle_with_double_vertical_bar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23ef-fe0f.png);}
.terminal-output .emoji.alarm_clock,.cmd .emoji.alarm_clock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f0.png);}
.terminal-output .emoji.stopwatch,.cmd .emoji.stopwatch{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f1-fe0f.png);}
.terminal-output .emoji.timer_clock,.cmd .emoji.timer_clock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f2-fe0f.png);}
.terminal-output .emoji.hourglass_flowing_sand,.cmd .emoji.hourglass_flowing_sand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f3.png);}
.terminal-output .emoji.double_vertical_bar,.cmd .emoji.double_vertical_bar{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f8-fe0f.png);}
.terminal-output .emoji.black_square_for_stop,.cmd .emoji.black_square_for_stop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23f9-fe0f.png);}
.terminal-output .emoji.black_circle_for_record,.cmd .emoji.black_circle_for_record{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/23fa-fe0f.png);}
.terminal-output .emoji.m,.cmd .emoji.m{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/24c2-fe0f.png);}
.terminal-output .emoji.black_small_square,.cmd .emoji.black_small_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25aa-fe0f.png);}
.terminal-output .emoji.white_small_square,.cmd .emoji.white_small_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25ab-fe0f.png);}
.terminal-output .emoji.arrow_forward,.cmd .emoji.arrow_forward{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25b6-fe0f.png);}
.terminal-output .emoji.arrow_backward,.cmd .emoji.arrow_backward{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25c0-fe0f.png);}
.terminal-output .emoji.white_medium_square,.cmd .emoji.white_medium_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25fb-fe0f.png);}
.terminal-output .emoji.black_medium_square,.cmd .emoji.black_medium_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25fc-fe0f.png);}
.terminal-output .emoji.white_medium_small_square,.cmd .emoji.white_medium_small_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25fd.png);}
.terminal-output .emoji.black_medium_small_square,.cmd .emoji.black_medium_small_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/25fe.png);}
.terminal-output .emoji.sunny,.cmd .emoji.sunny{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2600-fe0f.png);}
.terminal-output .emoji.cloud,.cmd .emoji.cloud{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2601-fe0f.png);}
.terminal-output .emoji.umbrella,.cmd .emoji.umbrella{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2602-fe0f.png);}
.terminal-output .emoji.snowman,.cmd .emoji.snowman{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2603-fe0f.png);}
.terminal-output .emoji.comet,.cmd .emoji.comet{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2604-fe0f.png);}
.terminal-output .emoji.phone,.cmd .emoji.phone{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/260e-fe0f.png);}
.terminal-output .emoji.ballot_box_with_check,.cmd .emoji.ballot_box_with_check{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2611-fe0f.png);}
.terminal-output .emoji.umbrella_with_rain_drops,.cmd .emoji.umbrella_with_rain_drops{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2614.png);}
.terminal-output .emoji.coffee,.cmd .emoji.coffee{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2615.png);}
.terminal-output .emoji.shamrock,.cmd .emoji.shamrock{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2618-fe0f.png);}
.terminal-output .emoji.point_up,.cmd .emoji.point_up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-fe0f.png);}
.terminal-output .emoji.point_up-var-0,.cmd .emoji.point_up-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-1f3fb.png);}
.terminal-output .emoji.point_up-var-1,.cmd .emoji.point_up-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-1f3fc.png);}
.terminal-output .emoji.point_up-var-2,.cmd .emoji.point_up-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-1f3fd.png);}
.terminal-output .emoji.point_up-var-3,.cmd .emoji.point_up-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-1f3fe.png);}
.terminal-output .emoji.point_up-var-4,.cmd .emoji.point_up-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/261d-1f3ff.png);}
.terminal-output .emoji.skull_and_crossbones,.cmd .emoji.skull_and_crossbones{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2620-fe0f.png);}
.terminal-output .emoji.radioactive_sign,.cmd .emoji.radioactive_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2622-fe0f.png);}
.terminal-output .emoji.biohazard_sign,.cmd .emoji.biohazard_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2623-fe0f.png);}
.terminal-output .emoji.orthodox_cross,.cmd .emoji.orthodox_cross{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2626-fe0f.png);}
.terminal-output .emoji.star_and_crescent,.cmd .emoji.star_and_crescent{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/262a-fe0f.png);}
.terminal-output .emoji.peace_symbol,.cmd .emoji.peace_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/262e-fe0f.png);}
.terminal-output .emoji.yin_yang,.cmd .emoji.yin_yang{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/262f-fe0f.png);}
.terminal-output .emoji.wheel_of_dharma,.cmd .emoji.wheel_of_dharma{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2638-fe0f.png);}
.terminal-output .emoji.white_frowning_face,.cmd .emoji.white_frowning_face{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2639-fe0f.png);}
.terminal-output .emoji.relaxed,.cmd .emoji.relaxed{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/263a-fe0f.png);}
.terminal-output .emoji.female_sign,.cmd .emoji.female_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2640-fe0f.png);}
.terminal-output .emoji.male_sign,.cmd .emoji.male_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2642-fe0f.png);}
.terminal-output .emoji.aries,.cmd .emoji.aries{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2648.png);}
.terminal-output .emoji.taurus,.cmd .emoji.taurus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2649.png);}
.terminal-output .emoji.gemini,.cmd .emoji.gemini{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264a.png);}
.terminal-output .emoji.cancer,.cmd .emoji.cancer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264b.png);}
.terminal-output .emoji.leo,.cmd .emoji.leo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264c.png);}
.terminal-output .emoji.virgo,.cmd .emoji.virgo{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264d.png);}
.terminal-output .emoji.libra,.cmd .emoji.libra{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264e.png);}
.terminal-output .emoji.scorpius,.cmd .emoji.scorpius{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/264f.png);}
.terminal-output .emoji.sagittarius,.cmd .emoji.sagittarius{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2650.png);}
.terminal-output .emoji.capricorn,.cmd .emoji.capricorn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2651.png);}
.terminal-output .emoji.aquarius,.cmd .emoji.aquarius{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2652.png);}
.terminal-output .emoji.pisces,.cmd .emoji.pisces{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2653.png);}
.terminal-output .emoji.chess_pawn,.cmd .emoji.chess_pawn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/265f-fe0f.png);}
.terminal-output .emoji.spades,.cmd .emoji.spades{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2660-fe0f.png);}
.terminal-output .emoji.clubs,.cmd .emoji.clubs{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2663-fe0f.png);}
.terminal-output .emoji.hearts,.cmd .emoji.hearts{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2665-fe0f.png);}
.terminal-output .emoji.diamonds,.cmd .emoji.diamonds{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2666-fe0f.png);}
.terminal-output .emoji.hotsprings,.cmd .emoji.hotsprings{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2668-fe0f.png);}
.terminal-output .emoji.recycle,.cmd .emoji.recycle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/267b-fe0f.png);}
.terminal-output .emoji.infinity,.cmd .emoji.infinity{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/267e-fe0f.png);}
.terminal-output .emoji.wheelchair,.cmd .emoji.wheelchair{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/267f.png);}
.terminal-output .emoji.hammer_and_pick,.cmd .emoji.hammer_and_pick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2692-fe0f.png);}
.terminal-output .emoji.anchor,.cmd .emoji.anchor{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2693.png);}
.terminal-output .emoji.crossed_swords,.cmd .emoji.crossed_swords{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2694-fe0f.png);}
.terminal-output .emoji.medical_symbol,.cmd .emoji.medical_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2695-fe0f.png);}
.terminal-output .emoji.scales,.cmd .emoji.scales{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2696-fe0f.png);}
.terminal-output .emoji.alembic,.cmd .emoji.alembic{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2697-fe0f.png);}
.terminal-output .emoji.gear,.cmd .emoji.gear{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2699-fe0f.png);}
.terminal-output .emoji.atom_symbol,.cmd .emoji.atom_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/269b-fe0f.png);}
.terminal-output .emoji.fleur_de_lis,.cmd .emoji.fleur_de_lis{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/269c-fe0f.png);}
.terminal-output .emoji.warning,.cmd .emoji.warning{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26a0-fe0f.png);}
.terminal-output .emoji.zap,.cmd .emoji.zap{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26a1.png);}
.terminal-output .emoji.transgender_symbol,.cmd .emoji.transgender_symbol{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26a7-fe0f.png);}
.terminal-output .emoji.white_circle,.cmd .emoji.white_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26aa.png);}
.terminal-output .emoji.black_circle,.cmd .emoji.black_circle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26ab.png);}
.terminal-output .emoji.coffin,.cmd .emoji.coffin{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26b0-fe0f.png);}
.terminal-output .emoji.funeral_urn,.cmd .emoji.funeral_urn{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26b1-fe0f.png);}
.terminal-output .emoji.soccer,.cmd .emoji.soccer{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26bd.png);}
.terminal-output .emoji.baseball,.cmd .emoji.baseball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26be.png);}
.terminal-output .emoji.snowman_without_snow,.cmd .emoji.snowman_without_snow{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26c4.png);}
.terminal-output .emoji.partly_sunny,.cmd .emoji.partly_sunny{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26c5.png);}
.terminal-output .emoji.thunder_cloud_and_rain,.cmd .emoji.thunder_cloud_and_rain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26c8-fe0f.png);}
.terminal-output .emoji.ophiuchus,.cmd .emoji.ophiuchus{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26ce.png);}
.terminal-output .emoji.pick,.cmd .emoji.pick{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26cf-fe0f.png);}
.terminal-output .emoji.helmet_with_white_cross,.cmd .emoji.helmet_with_white_cross{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26d1-fe0f.png);}
.terminal-output .emoji.chains,.cmd .emoji.chains{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26d3-fe0f.png);}
.terminal-output .emoji.no_entry,.cmd .emoji.no_entry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26d4.png);}
.terminal-output .emoji.shinto_shrine,.cmd .emoji.shinto_shrine{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26e9-fe0f.png);}
.terminal-output .emoji.church,.cmd .emoji.church{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26ea.png);}
.terminal-output .emoji.mountain,.cmd .emoji.mountain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f0-fe0f.png);}
.terminal-output .emoji.umbrella_on_ground,.cmd .emoji.umbrella_on_ground{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f1-fe0f.png);}
.terminal-output .emoji.fountain,.cmd .emoji.fountain{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f2.png);}
.terminal-output .emoji.golf,.cmd .emoji.golf{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f3.png);}
.terminal-output .emoji.ferry,.cmd .emoji.ferry{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f4-fe0f.png);}
.terminal-output .emoji.boat,.cmd .emoji.boat{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f5.png);}
.terminal-output .emoji.skier,.cmd .emoji.skier{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f7-fe0f.png);}
.terminal-output .emoji.ice_skate,.cmd .emoji.ice_skate{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f8-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball,.cmd .emoji.woman-bouncing-ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-fe0f-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball-var-0,.cmd .emoji.woman-bouncing-ball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fb-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball-var-1,.cmd .emoji.woman-bouncing-ball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fc-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball-var-2,.cmd .emoji.woman-bouncing-ball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fd-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball-var-3,.cmd .emoji.woman-bouncing-ball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fe-200d-2640-fe0f.png);}
.terminal-output .emoji.woman-bouncing-ball-var-4,.cmd .emoji.woman-bouncing-ball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3ff-200d-2640-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball,.cmd .emoji.man-bouncing-ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-fe0f-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball-var-0,.cmd .emoji.man-bouncing-ball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fb-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball-var-1,.cmd .emoji.man-bouncing-ball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fc-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball-var-2,.cmd .emoji.man-bouncing-ball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fd-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball-var-3,.cmd .emoji.man-bouncing-ball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fe-200d-2642-fe0f.png);}
.terminal-output .emoji.man-bouncing-ball-var-4,.cmd .emoji.man-bouncing-ball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3ff-200d-2642-fe0f.png);}
.terminal-output .emoji.person_with_ball,.cmd .emoji.person_with_ball{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-fe0f.png);}
.terminal-output .emoji.person_with_ball-var-0,.cmd .emoji.person_with_ball-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fb.png);}
.terminal-output .emoji.person_with_ball-var-1,.cmd .emoji.person_with_ball-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fc.png);}
.terminal-output .emoji.person_with_ball-var-2,.cmd .emoji.person_with_ball-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fd.png);}
.terminal-output .emoji.person_with_ball-var-3,.cmd .emoji.person_with_ball-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3fe.png);}
.terminal-output .emoji.person_with_ball-var-4,.cmd .emoji.person_with_ball-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26f9-1f3ff.png);}
.terminal-output .emoji.tent,.cmd .emoji.tent{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26fa.png);}
.terminal-output .emoji.fuelpump,.cmd .emoji.fuelpump{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/26fd.png);}
.terminal-output .emoji.scissors,.cmd .emoji.scissors{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2702-fe0f.png);}
.terminal-output .emoji.white_check_mark,.cmd .emoji.white_check_mark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2705.png);}
.terminal-output .emoji.airplane,.cmd .emoji.airplane{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2708-fe0f.png);}
.terminal-output .emoji.email,.cmd .emoji.email{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2709-fe0f.png);}
.terminal-output .emoji.fist,.cmd .emoji.fist{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a.png);}
.terminal-output .emoji.fist-var-0,.cmd .emoji.fist-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a-1f3fb.png);}
.terminal-output .emoji.fist-var-1,.cmd .emoji.fist-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a-1f3fc.png);}
.terminal-output .emoji.fist-var-2,.cmd .emoji.fist-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a-1f3fd.png);}
.terminal-output .emoji.fist-var-3,.cmd .emoji.fist-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a-1f3fe.png);}
.terminal-output .emoji.fist-var-4,.cmd .emoji.fist-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270a-1f3ff.png);}
.terminal-output .emoji.hand,.cmd .emoji.hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b.png);}
.terminal-output .emoji.hand-var-0,.cmd .emoji.hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b-1f3fb.png);}
.terminal-output .emoji.hand-var-1,.cmd .emoji.hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b-1f3fc.png);}
.terminal-output .emoji.hand-var-2,.cmd .emoji.hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b-1f3fd.png);}
.terminal-output .emoji.hand-var-3,.cmd .emoji.hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b-1f3fe.png);}
.terminal-output .emoji.hand-var-4,.cmd .emoji.hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270b-1f3ff.png);}
.terminal-output .emoji.v,.cmd .emoji.v{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-fe0f.png);}
.terminal-output .emoji.v-var-0,.cmd .emoji.v-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-1f3fb.png);}
.terminal-output .emoji.v-var-1,.cmd .emoji.v-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-1f3fc.png);}
.terminal-output .emoji.v-var-2,.cmd .emoji.v-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-1f3fd.png);}
.terminal-output .emoji.v-var-3,.cmd .emoji.v-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-1f3fe.png);}
.terminal-output .emoji.v-var-4,.cmd .emoji.v-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270c-1f3ff.png);}
.terminal-output .emoji.writing_hand,.cmd .emoji.writing_hand{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-fe0f.png);}
.terminal-output .emoji.writing_hand-var-0,.cmd .emoji.writing_hand-var-0{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-1f3fb.png);}
.terminal-output .emoji.writing_hand-var-1,.cmd .emoji.writing_hand-var-1{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-1f3fc.png);}
.terminal-output .emoji.writing_hand-var-2,.cmd .emoji.writing_hand-var-2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-1f3fd.png);}
.terminal-output .emoji.writing_hand-var-3,.cmd .emoji.writing_hand-var-3{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-1f3fe.png);}
.terminal-output .emoji.writing_hand-var-4,.cmd .emoji.writing_hand-var-4{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270d-1f3ff.png);}
.terminal-output .emoji.pencil2,.cmd .emoji.pencil2{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/270f-fe0f.png);}
.terminal-output .emoji.black_nib,.cmd .emoji.black_nib{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2712-fe0f.png);}
.terminal-output .emoji.heavy_check_mark,.cmd .emoji.heavy_check_mark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2714-fe0f.png);}
.terminal-output .emoji.heavy_multiplication_x,.cmd .emoji.heavy_multiplication_x{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2716-fe0f.png);}
.terminal-output .emoji.latin_cross,.cmd .emoji.latin_cross{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/271d-fe0f.png);}
.terminal-output .emoji.star_of_david,.cmd .emoji.star_of_david{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2721-fe0f.png);}
.terminal-output .emoji.sparkles,.cmd .emoji.sparkles{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2728.png);}
.terminal-output .emoji.eight_spoked_asterisk,.cmd .emoji.eight_spoked_asterisk{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2733-fe0f.png);}
.terminal-output .emoji.eight_pointed_black_star,.cmd .emoji.eight_pointed_black_star{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2734-fe0f.png);}
.terminal-output .emoji.snowflake,.cmd .emoji.snowflake{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2744-fe0f.png);}
.terminal-output .emoji.sparkle,.cmd .emoji.sparkle{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2747-fe0f.png);}
.terminal-output .emoji.x,.cmd .emoji.x{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/274c.png);}
.terminal-output .emoji.negative_squared_cross_mark,.cmd .emoji.negative_squared_cross_mark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/274e.png);}
.terminal-output .emoji.question,.cmd .emoji.question{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2753.png);}
.terminal-output .emoji.grey_question,.cmd .emoji.grey_question{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2754.png);}
.terminal-output .emoji.grey_exclamation,.cmd .emoji.grey_exclamation{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2755.png);}
.terminal-output .emoji.exclamation,.cmd .emoji.exclamation{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2757.png);}
.terminal-output .emoji.heavy_heart_exclamation_mark_ornament,.cmd .emoji.heavy_heart_exclamation_mark_ornament{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2763-fe0f.png);}
.terminal-output .emoji.heart_on_fire,.cmd .emoji.heart_on_fire{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2764-fe0f-200d-1f525.png);}
.terminal-output .emoji.mending_heart,.cmd .emoji.mending_heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2764-fe0f-200d-1fa79.png);}
.terminal-output .emoji.heart,.cmd .emoji.heart{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2764-fe0f.png);}
.terminal-output .emoji.heavy_plus_sign,.cmd .emoji.heavy_plus_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2795.png);}
.terminal-output .emoji.heavy_minus_sign,.cmd .emoji.heavy_minus_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2796.png);}
.terminal-output .emoji.heavy_division_sign,.cmd .emoji.heavy_division_sign{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2797.png);}
.terminal-output .emoji.arrow_right,.cmd .emoji.arrow_right{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/27a1-fe0f.png);}
.terminal-output .emoji.curly_loop,.cmd .emoji.curly_loop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/27b0.png);}
.terminal-output .emoji.loop,.cmd .emoji.loop{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/27bf.png);}
.terminal-output .emoji.arrow_heading_up,.cmd .emoji.arrow_heading_up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2934-fe0f.png);}
.terminal-output .emoji.arrow_heading_down,.cmd .emoji.arrow_heading_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2935-fe0f.png);}
.terminal-output .emoji.arrow_left,.cmd .emoji.arrow_left{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b05-fe0f.png);}
.terminal-output .emoji.arrow_up,.cmd .emoji.arrow_up{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b06-fe0f.png);}
.terminal-output .emoji.arrow_down,.cmd .emoji.arrow_down{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b07-fe0f.png);}
.terminal-output .emoji.black_large_square,.cmd .emoji.black_large_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b1b.png);}
.terminal-output .emoji.white_large_square,.cmd .emoji.white_large_square{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b1c.png);}
.terminal-output .emoji.star,.cmd .emoji.star{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b50.png);}
.terminal-output .emoji.o,.cmd .emoji.o{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/2b55.png);}
.terminal-output .emoji.wavy_dash,.cmd .emoji.wavy_dash{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/3030-fe0f.png);}
.terminal-output .emoji.part_alternation_mark,.cmd .emoji.part_alternation_mark{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/303d-fe0f.png);}
.terminal-output .emoji.congratulations,.cmd .emoji.congratulations{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/3297-fe0f.png);}
.terminal-output .emoji.secret,.cmd .emoji.secret{background-image:url(https://unpkg.com/emoji-datasource-twitter/img/twitter/64/3299-fe0f.png);}
